@@ -21,110 +21,7 @@
 	along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
 
-function pts_is_run_object($object)
-{
-	return pts_is_test($object) || pts_is_suite($object);
-}
-function pts_is_suite($object)
-{
-	$type = pts_testing_type($object);
-
-	return $type == "TYPE_TEST_SUITE" || $type == "TYPE_LOCAL_TEST_SUITE";
-}
-function pts_is_weighted_suite($object)
-{
-	$is_weighted_suite = false;
-
-	if(pts_is_suite($object))
-	{
-		$is_weighted_suite = pts_suite_read_xml($object, P_SUITE_WEIGHTED_BASE_FROM_TEST) != false;
-	}
-
-	return $is_weighted_suite;
-}
-function pts_is_virtual_suite($object)
-{
-	return pts_location_virtual_suite($object) != false;
-}
-function pts_is_test($object)
-{
-	$type = pts_testing_type($object);
-
-	return $type == "TYPE_TEST" || $type == "TYPE_LOCAL_TEST" || $type == "TYPE_BASE_TEST";
-}
-function pts_is_base_test($object)
-{
-	$type = pts_testing_type($object);
-
-	return $type == "TYPE_BASE_TEST";
-}
-function pts_is_test_result($identifier)
-{
-	return is_file(SAVE_RESULTS_DIR . $identifier . "/composite.xml");
-}
-function pts_is_test_result_directory($identifier)
-{
-	return is_dir(SAVE_RESULTS_DIR . $identifier);
-}
-function pts_validate_local_test_profile($identifier)
-{
-	if(is_file(($lp = XML_PROFILE_LOCAL_DIR . $identifier . ".xml")))
-	{
-		$valid = true;
-
-		if(is_file(($sp = XML_PROFILE_DIR . $identifier . ".xml")))
-		{
-			$lp_version = pts_test_read_xml($lp, P_TEST_PTSVERSION);
-			$sp_version = pts_test_read_xml($sp, P_TEST_PTSVERSION);
-
-			if(pts_version_newer($lp_version, $sp_version) == $sp_version)
-			{
-				// Standard test profile version newer than the local test profile version
-				$valid = false;
-
-				// Rename test profile since it's out of date
-				pts_rename($lp, XML_PROFILE_LOCAL_DIR . $identifier . ".xml.old");
-			}
-			
-		}
-	}
-	else
-	{
-		$valid = false;
-	}
-
-	return $valid;
-}
-function pts_validate_local_test_suite($identifier)
-{
-	if(is_file(($ls = XML_SUITE_LOCAL_DIR . $identifier . ".xml")))
-	{
-		$valid = true;
-
-		if(is_file(($ss = XML_SUITE_DIR . $identifier . ".xml")))
-		{
-			$ls_version = pts_test_read_xml($ls, P_SUITE_VERSION);
-			$ss_version = pts_test_read_xml($ss, P_SUITE_VERSION);
-
-			if(pts_version_newer($ls_version, $ss_version) == $ss_version)
-			{
-				// Standard test suite version newer than the local test suite version
-				$valid = false;
-
-				// Rename test suite since it's out of date
-				pts_rename($ls, XML_SUITE_LOCAL_DIR . $identifier . ".xml.old");
-			}
-			
-		}
-	}
-	else
-	{
-		$valid = false;
-	}
-
-	return $valid;
-}
-function pts_testing_type($identifier, $rewrite_cache = false)
+function pts_identifier_type($identifier, $rewrite_cache = false)
 {
 	// Determine type of test based on identifier
 	static $cache;
@@ -162,6 +59,94 @@ function pts_testing_type($identifier, $rewrite_cache = false)
 
 	return $cache[$identifier];
 }
+function pts_is_run_object($object)
+{
+	return pts_is_test($object) || pts_is_suite($object);
+}
+function pts_is_suite($object)
+{
+	$type = pts_identifier_type($object);
+
+	return $type == "TYPE_TEST_SUITE" || $type == "TYPE_LOCAL_TEST_SUITE";
+}
+function pts_is_virtual_suite($object)
+{
+	return pts_location_virtual_suite($object) != false;
+}
+function pts_is_test($object)
+{
+	$type = pts_identifier_type($object);
+
+	return $type == "TYPE_TEST" || $type == "TYPE_LOCAL_TEST" || $type == "TYPE_BASE_TEST";
+}
+function pts_is_base_test($object)
+{
+	$type = pts_identifier_type($object);
+
+	return $type == "TYPE_BASE_TEST";
+}
+function pts_is_test_result($identifier)
+{
+	return is_file(SAVE_RESULTS_DIR . $identifier . "/composite.xml");
+}
+function pts_validate_local_test_profile($identifier)
+{
+	if(is_file(($lp = XML_PROFILE_LOCAL_DIR . $identifier . ".xml")))
+	{
+		$valid = true;
+
+		if(is_file(($sp = XML_PROFILE_DIR . $identifier . ".xml")))
+		{
+			$lp_version = pts_test_read_xml($lp, P_TEST_PTSVERSION);
+			$sp_version = pts_test_read_xml($sp, P_TEST_PTSVERSION);
+
+			if(pts_version_newer($lp_version, $sp_version) == $sp_version)
+			{
+				// Standard test profile version newer than the local test profile version
+				$valid = false;
+
+				// Rename test profile since it's out of date
+				rename($lp, XML_PROFILE_LOCAL_DIR . $identifier . ".xml.old");
+			}
+			
+		}
+	}
+	else
+	{
+		$valid = false;
+	}
+
+	return $valid;
+}
+function pts_validate_local_test_suite($identifier)
+{
+	if(is_file(($ls = XML_SUITE_LOCAL_DIR . $identifier . ".xml")))
+	{
+		$valid = true;
+
+		if(is_file(($ss = XML_SUITE_DIR . $identifier . ".xml")))
+		{
+			$ls_version = pts_test_read_xml($ls, P_SUITE_VERSION);
+			$ss_version = pts_test_read_xml($ss, P_SUITE_VERSION);
+
+			if(pts_version_newer($ls_version, $ss_version) == $ss_version)
+			{
+				// Standard test suite version newer than the local test suite version
+				$valid = false;
+
+				// Rename test suite since it's out of date
+				rename($ls, XML_SUITE_LOCAL_DIR . $identifier . ".xml.old");
+			}
+			
+		}
+	}
+	else
+	{
+		$valid = false;
+	}
+
+	return $valid;
+}
 function pts_location_suite($identifier, $rewrite_cache = false)
 {
 	static $cache;
@@ -172,7 +157,7 @@ function pts_location_suite($identifier, $rewrite_cache = false)
 
 		if(pts_is_suite($identifier))
 		{
-			$type = pts_testing_type($identifier);
+			$type = pts_identifier_type($identifier);
 
 			switch($type)
 			{
@@ -227,7 +212,7 @@ function pts_location_virtual_suite($identifier)
 					break;
 				default:
 					// Check if object is a subsystem test type
-					foreach(pts_subsystem_test_types() as $type)
+					foreach(pts_types::subsystem_targets() as $type)
 					{
 						if(strtolower($type) == $identifier)
 						{
@@ -244,68 +229,6 @@ function pts_location_virtual_suite($identifier)
 
 	return $cache[$identifier];
 }
-function pts_location_test($identifier, $rewrite_cache = false)
-{
-	static $cache;
-
-	if(!isset($cache[$identifier]) || $rewrite_cache)
-	{
-		$location = false;
-
-		if(pts_is_test($identifier))
-		{
-			$type = pts_testing_type($identifier);
-
-			switch($type)
-			{
-				case "TYPE_TEST":
-					$location = XML_PROFILE_DIR . $identifier . ".xml";
-					break;
-				case "TYPE_LOCAL_TEST":
-					$location = XML_PROFILE_LOCAL_DIR . $identifier . ".xml";
-					break;
-				case "TYPE_BASE_TEST":
-					$location = XML_PROFILE_CTP_BASE_DIR . $identifier . ".xml";
-					break;
-			}
-		}
-
-		$cache[$identifier] = $location;
-	}
-
-	return $cache[$identifier];
-}
-function pts_location_test_resources($identifier, $rewrite_cache = false)
-{
-	static $cache;
-
-	if(!isset($cache[$identifier]) || $rewrite_cache)
-	{
-		$location = false;
-
-		if(pts_is_test($identifier))
-		{
-			$type = pts_testing_type($identifier);
-
-			if($type == "TYPE_LOCAL_TEST" && is_dir(TEST_RESOURCE_LOCAL_DIR . $identifier))
-			{
-				$location = TEST_RESOURCE_LOCAL_DIR . $identifier . "/";
-			}
-			else if($type == "TYPE_BASE_TEST" && is_dir(TEST_RESOURCE_CTP_BASE_DIR . $identifier))
-			{
-				$location = TEST_RESOURCE_CTP_BASE_DIR . $identifier . "/";
-			}
-			else if(is_dir(TEST_RESOURCE_DIR . $identifier))
-			{
-				$location = TEST_RESOURCE_DIR . $identifier . "/";
-			}
-		}
-
-		$cache[$identifier] = $location;
-	}
-
-	return $cache[$identifier];
-}
 function pts_test_extends_below($object)
 {
 	// Process Extensions / Cascading Test Profiles
@@ -343,7 +266,7 @@ function pts_contained_tests($objects, $include_extensions = false, $check_exten
 {
 	// Provide an array containing the location(s) of all test(s) for the supplied object name
 	$tests = array();
-	$objects = pts_to_array($objects);
+	$objects = pts_arrays::to_array($objects);
 
 	foreach($objects as &$object)
 	{
@@ -383,9 +306,9 @@ function pts_contained_tests($objects, $include_extensions = false, $check_exten
 				}
 			}
 		}
-		else if(pts_is_global_id($object)) // Object is a Phoronix Global file
+		else if(pts_global::is_global_id($object)) // Object is a Phoronix Global file
 		{
-			$xml_parser = new pts_results_tandem_XmlReader(pts_global_download_xml($object));
+			$xml_parser = new pts_results_tandem_XmlReader(pts_global::download_result_xml($object));
 
 			foreach($xml_parser->getXMLArrayValues(P_RESULTS_TEST_TESTNAME) as $test)
 			{
@@ -422,18 +345,18 @@ function pts_virtual_suite_tests($object)
 	switch($virtual_suite_type)
 	{
 		case "TYPE_VIRT_SUITE_SUBSYSTEM":
-			foreach(pts_supported_tests_array() as $test)
+			foreach(pts_tests::supported_tests() as $test)
 			{
-				$type = pts_test_read_xml($test, P_TEST_HARDWARE_TYPE);
+				$test_profile = new pts_test_profile($test);
 
-				if(strtolower($type) == $object && pts_test_supported($test))
+				if(strtolower($test_profile->get_test_hardware_type()) == $object && $test_profile->is_supported())
 				{
 					array_push($contained_tests, $test);
 				}
 			}
 			break;
 		case "TYPE_VIRT_SUITE_ALL":
-			foreach(pts_supported_tests_array() as $test)
+			foreach(pts_tests::supported_tests() as $test)
 			{
 				$result_format = pts_test_read_xml($test, P_TEST_RESULTFORMAT);
 				$test_license = pts_test_read_xml($test, P_TEST_LICENSE);
@@ -445,7 +368,7 @@ function pts_virtual_suite_tests($object)
 			}
 			break;
 		case "TYPE_VIRT_SUITE_INSTALLED_TESTS":
-			foreach(pts_installed_tests_array() as $test)
+			foreach(pts_tests::installed_tests() as $test)
 			{
 				$result_format = pts_test_read_xml($test, P_TEST_RESULTFORMAT);
 				$test_title = pts_test_read_xml($test, P_TEST_TITLE);
@@ -457,7 +380,7 @@ function pts_virtual_suite_tests($object)
 			}
 			break;
 		case "TYPE_VIRT_SUITE_FREE":
-			foreach(pts_supported_tests_array() as $test)
+			foreach(pts_tests::supported_tests() as $test)
 			{
 				$test_license = pts_test_read_xml($test, P_TEST_LICENSE);
 
@@ -468,13 +391,13 @@ function pts_virtual_suite_tests($object)
 			}
 			break;
 		case "TYPE_VIRT_PREV_TEST_IDENTIFIER":
-			foreach(pts_to_array(pts_read_assignment("PREV_TEST_IDENTIFIER")) as $test)
+			foreach(pts_arrays::to_array(pts_read_assignment("PREV_TEST_IDENTIFIER")) as $test)
 			{
 				array_push($contained_tests, $test);
 			}
 			break;
 		case "TYPE_VIRT_PREV_SAVE_IDENTIFIER":
-			foreach(pts_to_array(pts_read_assignment("PREV_SAVE_RESULTS_IDENTIFIER")) as $test)
+			foreach(pts_arrays::to_array(pts_read_assignment("PREV_SAVE_RESULTS_IDENTIFIER")) as $test)
 			{
 				array_push($contained_tests, $test);
 			}
@@ -488,6 +411,10 @@ function pts_virtual_suite_tests($object)
 
 	return $contained_tests;
 }
+function pts_test_installed($identifier)
+{
+	return is_file(TEST_ENV_DIR . $identifier . "/pts-install.xml");
+}
 function pts_find_result_file($file, $check_global = true)
 {
 	// PTS Find A Saved File
@@ -495,9 +422,10 @@ function pts_find_result_file($file, $check_global = true)
 	{
 		$USE_FILE = SAVE_RESULTS_DIR . $file . "/composite.xml";
 	}
-	else if($check_global && pts_is_global_id($file))
+	else if($check_global && pts_global::is_global_id($file))
 	{
-		$USE_FILE = pts_global_download_base_url() . $file;
+		pts_global::clone_global_result($file, false);
+		$USE_FILE = SAVE_RESULTS_DIR . $file . "/composite.xml";
 	}
 	else
 	{
@@ -506,16 +434,95 @@ function pts_find_result_file($file, $check_global = true)
 
 	return $USE_FILE;
 }
+function pts_suite_needs_updated_install($identifier)
+{
+	if(!pts_is_assignment("CACHE_SUITE_INSTALLED_" . strtoupper($identifier)))
+	{
+		$needs_update = false;
+
+		foreach(pts_contained_tests($identifier, true, true, true) as $test)
+		{
+			$installed_test = new pts_installed_test($test);
+
+			if(!pts_test_installed($test) || $installed_test->get_installed_system_identifier() != phodevi::system_id_string() || pts_is_assignment("PTS_FORCE_INSTALL"))
+			{
+				$needs_update = true;
+				break;
+			}
+		}
+
+		pts_set_assignment("CACHE_SUITE_INSTALLED_" . strtoupper($identifier), $needs_update);
+	}
+
+	return pts_read_assignment("CACHE_SUITE_INSTALLED_" . strtoupper($identifier));
+}
+function pts_test_needs_updated_install($identifier)
+{
+	$installed_test = new pts_installed_test($identifier);
+	$test_profile = new pts_test_profile($identifier);
+
+	// Checks if test needs updating
+	// || $installed_test->get_installed_system_identifier() != phodevi::system_id_string()
+	return !pts_test_installed($identifier) || !pts_strings::version_strings_comparable($test_profile->get_test_profile_version(), $installed_test->get_installed_version()) || $test_profile->get_installer_checksum() != $installed_test->get_installed_checksum() || pts_is_assignment("PTS_FORCE_INSTALL");
+}
+function pts_test_read_xml($identifier, $xml_option)
+{
+ 	$xml_parser = new pts_test_tandem_XmlReader($identifier);
+	return $xml_parser->getXMLValue($xml_option);
+}
+function pts_suite_read_xml($identifier, $xml_option)
+{
+ 	$xml_parser = new pts_suite_tandem_XmlReader($identifier);
+	return $xml_parser->getXMLValue($xml_option);
+}
+function pts_suite_read_xml_array($identifier, $xml_option)
+{
+ 	$xml_parser = new pts_suite_tandem_XmlReader($identifier);
+	return $xml_parser->getXMLArrayValues($xml_option);
+}
+function pts_version_newer($version_a, $version_b)
+{
+	$r_a = explode(".", $version_a);
+	$r_b = explode(".", $version_b);
+
+	$r_a = ($r_a[0] * 1000) + ($r_a[1] * 100) + $r_a[2];
+	$r_b = ($r_b[0] * 1000) + ($r_b[1] * 100) + $r_b[2];
+
+	return $r_a > $r_b ? $version_a : $version_b;
+}
+
+
+/*
 function pts_rebuild_test_type_cache($identifier)
 {
-	pts_testing_type($identifier, true);
-	pts_location_test($identifier, true);
-	pts_location_test_resources($identifier, true);
+	pts_identifier_type($identifier, true);
+	pts_tests::test_profile_location($identifier, true);
+	pts_tests::test_resources_location($identifier, true);
 }
 function pts_rebuild_suite_type_cache($identifier)
 {
-	pts_testing_type($identifier, true);
+	pts_identifier_type($identifier, true);
 	pts_location_suite($identifier, true);
 }
+function pts_available_base_tests_array()
+{
+	static $cache = null;
+
+	if($cache == null)
+	{
+		$base_tests = pts_file_io::glob(XML_PROFILE_CTP_BASE_DIR . "*.xml");
+		asort($base_tests);
+
+		foreach($base_tests as &$base_test)
+		{
+			$base_test = basename($base_test, ".xml");
+		}
+
+		$cache = $base_tests;
+	}
+
+	return $cache;
+}
+*/
 
 ?>
