@@ -21,6 +21,17 @@
 	along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
 
+function pts_array_with_key_to_2d($array)
+{
+	$array_2d = array();
+
+	foreach($array as $key => $value)
+	{
+		array_push($array_2d, array($key, $value));
+	}
+
+	return $array_2d;
+}
 function pts_gtk_add_menu($vbox, $menu)
 {
 	if($vbox instanceOf GtkBox)
@@ -43,7 +54,7 @@ function pts_gtk_add_menu($vbox, $menu)
 
 		pts_set_assignment("GTK_OBJ_MENU_" . $this_menu_identifier, $menu);
 
-		$sub_menu = pts_to_array($sub_menu);
+		$sub_menu = pts_arrays::to_array($sub_menu);
 		foreach(array_keys($sub_menu) as $key)
 		{
 			if($sub_menu[$key] == null)
@@ -148,7 +159,7 @@ function pts_gtk_table($headers, $data, $connect_to = null, $on_empty = null, $a
 
 	if(count($headers) == 2)
 	{
-		if($headers[0] == null && is_object($data[0][$i]))
+		if($headers[0] == null && is_object($data[0][1]))
 		{
 			$model = new GtkListStore(GObject::TYPE_OBJECT, GObject::TYPE_STRING);
 		}
@@ -186,7 +197,7 @@ function pts_gtk_table($headers, $data, $connect_to = null, $on_empty = null, $a
 	{
 		$values = array();
 
-		$data[$r] = pts_to_array($data[$r]);
+		$data[$r] = pts_arrays::to_array($data[$r]);
 		foreach(array_keys($data[$r]) as $c)
 		{
 			array_push($values, $data[$r][$c]);
@@ -292,15 +303,24 @@ function pts_gtk_selected_item($object)
 
 	return $model->get_value($iter, 0);
 }
+function pts_gtk_selected_rows($object)
+{
+	list($model, $rows) = $object->get_selected_rows();
+
+	return is_array($rows) ? $rows : array();
+}
 function pts_gtk_selected_items($object)
 {
 	list($model, $rows) = $object->get_selected_rows();
 	$return_items = array();
 
-	foreach($rows as $row)
+	if(is_array($rows))
 	{
-		$iter = $model->get_iter($row);
-		array_push($return_items, $model->get_value($iter, 0));
+		foreach($rows as $row)
+		{
+			$iter = $model->get_iter($row);
+			array_push($return_items, $model->get_value($iter, 0));
+		}
 	}
 
 	return $return_items;
@@ -340,7 +360,7 @@ function pts_gtk_fill_notebook_tab($vbox, $list_label, $list_function, $list_on_
 {
 	if(!pts_is_assignment("GTK_DYNAMIC_TAB_" . strtoupper($list_function)))
 	{
-		$list_label = pts_to_array($list_label);
+		$list_label = pts_arrays::to_array($list_label);
 		$tab_gtk_label = pts_gtk_table($list_label, call_user_func($list_function), $list_on_click, $on_empty_list);
 
 		foreach($vbox->get_children() as $child)
