@@ -23,7 +23,14 @@
 
 function pts_gui_installed_suites()
 {
-	$installed_suites = array_map("pts_suite_identifier_to_name", pts_installed_suites_array());
+	$installed_suites = array();
+
+	foreach(pts_suites::installed_suites() as $suite)
+	{
+		$test_suite = new pts_test_suite($suite);
+		array_push($installed_suites, $test_suite->get_title());
+	}
+
 	sort($installed_suites);
 
 	return $installed_suites;
@@ -83,7 +90,7 @@ function pts_gui_process_show_test($identifier, $dependency_limit, $downloads_li
 }
 function pts_gui_available_suites($to_show_types, $license_types = null, $dependency_limit = null, $downloads_limit = null)
 {
-	$test_suites = pts_supported_suites_array();
+	$test_suites = pts_suites::supported_suites();
 	$to_show_names = array();
 
 	foreach($test_suites as &$name)
@@ -95,20 +102,20 @@ function pts_gui_available_suites($to_show_types, $license_types = null, $depend
 		{
 			if(pts_gui_process_show_test($name, $dependency_limit, $downloads_limit, $license_types))
 			{
+				// For now show test identifier rather than $ts->get_title()
 				array_push($to_show_names, $name);
 			}
 		}
 	}
 
-	$test_suites = array_map("pts_suite_identifier_to_name", $to_show_names);
-	sort($test_suites);
+	sort($to_show_names);
 
-	return $test_suites;
+	return $to_show_names;
 }
 function pts_gui_installed_tests($to_show_types, $license_types)
 {
 	$installed_tests = array();
-	$installed = pts_installed_tests_array();
+	$installed = pts_tests::installed_tests();
 	$license_types = array_map("strtoupper", $license_types);
 
 	foreach($installed as &$test)
@@ -117,23 +124,22 @@ function pts_gui_installed_tests($to_show_types, $license_types)
 		$hw_type = $tp->get_test_hardware_type();
 		$license = $tp->get_license();
 
-		if((empty($hw_type) || in_array($hw_type, $to_show_types)) && (empty($license) || in_array($license, $license_types)) && $tp->get_test_title() != "")
+		if((empty($hw_type) || in_array($hw_type, $to_show_types)) && (empty($license) || in_array($license, $license_types)) && $tp->get_title() != "")
 		{
+			// test name is $tp->get_title()
 			array_push($installed_tests, $test);
 		}
 	}
 
-	$installed_tests = array_map("pts_test_identifier_to_name", $installed_tests);
 	sort($installed_tests);
 
 	return $installed_tests;
 }
 function pts_gui_available_tests($to_show_types, $license_types, $dependency_limit = null, $downloads_limit = null)
 {
-	$test_names = pts_supported_tests_array();
-	$to_show_names = array();
+	$test_names = array();
 
-	foreach($test_names as &$name)
+	foreach(pts_tests::supported_tests() as $name)
 	{
 		$tp = new pts_test_profile($name);
 		$hw_type = $tp->get_test_hardware_type();
@@ -142,12 +148,11 @@ function pts_gui_available_tests($to_show_types, $license_types, $dependency_lim
 		{
 			if(pts_gui_process_show_test($name, $dependency_limit, $downloads_limit, $license_types))
 			{
-				array_push($to_show_names, $name);
+				array_push($test_names, $name);
 			}
 		}
 	}
 
-	$test_names = array_map("pts_test_identifier_to_name", $to_show_names);
 	sort($test_names);
 
 	return $test_names;
@@ -156,7 +161,8 @@ function pts_test_download_files_locally_available($identifier)
 {
 	foreach(pts_contained_tests($identifier, true, true, false) as $name)
 	{
-		$test_object_downloads = pts_objects_test_downloads($name);
+		$test_object_downloads = pts_test_install_request::read_download_object_list($name);
+		$test_profile = new pts_test_profile($name);
 
 		foreach($test_object_downloads as &$download_package)
 		{
@@ -166,24 +172,19 @@ function pts_test_download_files_locally_available($identifier)
 			}
 		}
 
-		if(count($test_object_downloads) == 0 && !pts_is_base_test($name) && !is_file(pts_location_test_resources($name) . "install.sh") && !is_file(pts_location_test_resources($name) . "install.php"))
+		if(count($test_object_downloads) == 0 && !pts_is_base_test($name) && $test_profile->get_installer_checksum() == null)
 		{
 			$xml_parser = new pts_test_tandem_XmlReader($name);
 			$execute_binary = $xml_parser->getXMLValue(P_TEST_EXECUTABLE);
-			$execute_path = pts_trim_explode(",", $xml_parser->getXMLValue(P_TEST_POSSIBLEPATHS));
-			array_push($execute_path, TEST_ENV_DIR . $name . "/");
 
 			if(empty($execute_binary))
 			{
 				$execute_binary = $name;
 			}
 
-			foreach($execute_path as $path_check)
+			if(is_file(TEST_ENV_DIR . $name . "/" . $execute_binary))
 			{
-				if(is_file($path_check . execute_binary))
-				{
-					continue;
-				}
+				continue;
 			}
 
 			return false;
@@ -202,7 +203,7 @@ function pts_test_download_file_local($test_identifier, $download_name)
 	}
 	else
 	{
-		foreach(pts_test_download_cache_directories() as $download_cache)
+		foreach(pts_test_install_manager::download_cache_locations() as $download_cache)
 		{
 			if(is_file($download_cache . $download_name))
 			{
@@ -216,7 +217,7 @@ function pts_test_download_file_local($test_identifier, $download_name)
 }
 function pts_test_external_dependencies_satisfied($identifier)
 {
-	$missing_dependencies = pts_external_dependencies_missing();
+	$missing_dependencies = pts_external_dependencies::missing_dependency_names();
 
 	foreach(pts_contained_tests($identifier, true, true, false) as $name)
 	{
@@ -242,7 +243,7 @@ function pts_archive_result_directory($identifier, $save_to = null)
 
 	if(is_file(SAVE_RESULTS_DIR . $identifier . "/composite.xml"))
 	{
-		pts_compress(SAVE_RESULTS_DIR . $identifier . "/", $save_to);
+		pts_compression::compress_to_archive(SAVE_RESULTS_DIR . $identifier . "/", $save_to);
 	}
 }
 
