@@ -47,7 +47,7 @@ class gui_gtk_events extends pts_module_interface
 		if(!class_exists("gui_gtk"))
 		{
 			// The GTK interface isn't being used
-			return PTS_MODULE_UNLOAD;
+			return pts_module::MODULE_UNLOAD;
 		}
 	}
 
@@ -55,18 +55,19 @@ class gui_gtk_events extends pts_module_interface
 	// Installation Functions
 	//
 
-	public static function __pre_install_process($test_install_array)
+	public static function __pre_install_process(&$test_install_manager)
 	{
-		self::$test_install_count = count($test_install_array);
 		self::$test_install_pos = 0;
+		self::$test_install_count = $test_install_manager->tests_to_install_count();
 		self::$progress_window = new pts_gtk_advanced_progress_window("Phoronix Test Suite: Test Installation");
-		self::$progress_window->update_progress_bar(0, " ", 0, "Installing: " . pts_test_identifier_to_name($test_install_array[0]));
+		self::$progress_window->update_progress_bar(0, " ", 0, "Preparing Install Process");
 	}
 	public static function __pre_test_download($obj)
 	{
-		self::$test_install_current = pts_test_identifier_to_name($obj[0]);
+		$test_profile = new pts_test_profile($obj[0]);
+		self::$test_install_current = $test_profile->get_title();
 		self::$test_download_count = count($obj[1]);
-		self::$progress_window->update_progress_bar(0, "Downloading: " . $obj[1][0]->get_filename() . " (" . pts_trim_double($obj[1][0]->get_filesize() / 1048576, 1) . "MB)", self::$install_overall_percent, "Installing: " . self::$test_install_current);
+		self::$progress_window->update_progress_bar(0, "Downloading: " . $obj[1][0]->get_filename() . " (" . round($obj[1][0]->get_filesize() / 1048576, 1) . "MB)", self::$install_overall_percent, "Installing: " . self::$test_install_current);
 	}
 	public static function __interim_test_download($obj)
 	{
@@ -74,7 +75,7 @@ class gui_gtk_events extends pts_module_interface
 
 		if(isset($obj[1][self::$test_download_pos]))
 		{
-			self::$progress_window->update_progress_bar((self::$test_download_pos / self::$test_download_count) * 50, "Downloading: " . $obj[1][self::$test_download_pos]->get_filename() . " (" . pts_trim_double($obj[1][self::$test_download_pos]->get_filesize() / 1048576, 1) . "MB)", self::$install_overall_percent, "Installing: " . self::$test_install_current);
+			self::$progress_window->update_progress_bar((self::$test_download_pos / self::$test_download_count) * 50, "Downloading: " . $obj[1][self::$test_download_pos]->get_filename() . " (" . round($obj[1][self::$test_download_pos]->get_filesize() / 1048576, 1) . "MB)", self::$install_overall_percent, "Installing: " . self::$test_install_current);
 		}
 	}
 	public static function __pre_test_install($identifier)
@@ -103,7 +104,7 @@ class gui_gtk_events extends pts_module_interface
 
 		foreach($test_run_manager->get_tests_to_run() as $test_run_request)
 		{
-			array_push(self::$tests_remaining_to_run, $test_run_request->get_identifier());
+			array_push(self::$tests_remaining_to_run, $test_run_request->test_profile->get_identifier());
 		}
 
 		self::$test_run_pos = 0;
@@ -115,17 +116,17 @@ class gui_gtk_events extends pts_module_interface
 	public static function __pre_test_run($pts_test_result)
 	{
 		array_shift(self::$tests_remaining_to_run);
-		self::$progress_window->update_progress_bar(0, "<b>" . $pts_test_result->get_test_profile()->get_test_title() . "</b>" . ", Run " . ($pts_test_result->trial_run_count() + 1) . " of " . $pts_test_result->get_test_profile()->get_times_to_run(), (self::$test_run_pos / self::$test_run_count) * 100, self::test_run_position(1) . self::run_time_remaining($pts_test_result));
+		self::$progress_window->update_progress_bar(0, "<b>" . $pts_test_result->test_profile->get_title() . "</b>" . ", Run " . ($pts_test_result->test_result_buffer->get_count() + 1) . " of " . $pts_test_result->test_profile->get_times_to_run(), (self::$test_run_pos / self::$test_run_count) * 100, self::test_run_position(1) . self::run_time_remaining($pts_test_result));
 	}
 	public static function __interim_test_run($pts_test_result)
 	{
-		self::$progress_window->update_progress_bar(($pts_test_result->trial_run_count() / $pts_test_result->get_test_profile()->get_times_to_run()) * 100, "<b>" . $pts_test_result->get_test_profile()->get_test_title() . "</b>" . ", Run " . ($pts_test_result->trial_run_count() + 1) . " of " . $pts_test_result->get_test_profile()->get_times_to_run(), ((self::$test_run_pos + ($pts_test_result->trial_run_count() / $pts_test_result->get_test_profile()->get_times_to_run())) / self::$test_run_count) * 100, self::test_run_position(1) . self::run_time_remaining($pts_test_result));
+		self::$progress_window->update_progress_bar(($pts_test_result->test_result_buffer->get_count() / $pts_test_result->test_profile->get_times_to_run()) * 100, "<b>" . $pts_test_result->test_profile->get_title() . "</b>" . ", Run " . ($pts_test_result->test_result_buffer->get_count() + 1) . " of " . $pts_test_result->test_profile->get_times_to_run(), ((self::$test_run_pos + ($pts_test_result->test_result_buffer->get_count() / $pts_test_result->test_profile->get_times_to_run())) / self::$test_run_count) * 100, self::test_run_position(1) . self::run_time_remaining($pts_test_result));
 	}
 	public static function __post_test_run($pts_test_result)
 	{
 		self::$test_run_pos++;
 		self::run_time_remaining($pts_test_result);
-		self::$progress_window->update_progress_bar(100, "<b>" . $pts_test_result->get_test_profile()->get_test_title() . ":</b>" . " Run " . $pts_test_result->trial_run_count() . " of " . $pts_test_result->get_test_profile()->get_times_to_run(), (self::$test_run_pos / self::$test_run_count) * 100, self::test_run_position(0) . self::run_time_remaining($pts_test_result));
+		self::$progress_window->update_progress_bar(100, "<b>" . $pts_test_result->test_profile->get_title() . ":</b>" . " Run " . $pts_test_result->test_result_buffer->get_count() . " of " . $pts_test_result->test_profile->get_times_to_run(), (self::$test_run_pos / self::$test_run_count) * 100, self::test_run_position(0) . self::run_time_remaining($pts_test_result));
 	}
 	public static function __post_run_process()
 	{
@@ -146,17 +147,18 @@ class gui_gtk_events extends pts_module_interface
 
 		if(self::$test_run_count == $test_run_count)
 		{
-			$remaining_length = pts_estimated_run_time(self::$tests_remaining_to_run);
-			$estimated_length = pts_estimated_run_time($test_result->get_test_profile()->get_identifier());
+			$remaining_length = 0;
+			//$remaining_length = pts_estimated_run_time(self::$tests_remaining_to_run);
+			$estimated_length = $test_result->test_profile->get_estimated_run_time();
 
 			if($estimated_length > 1)
 			{
-				$remaining_length += $estimated_length * (($test_result->get_test_profile()->get_times_to_run() - $test_result->trial_run_count()) / $test_result->get_test_profile()->get_times_to_run());
+				$remaining_length += $estimated_length * (($test_result->test_profile->get_times_to_run() - $test_result->test_result_buffer->get_count()) / $test_result->test_profile->get_times_to_run());
 			}
 
 			if($remaining_length > 0)
 			{
-				return pts_format_time_string($remaining_length, "SECONDS", true) . " Remaining";
+				return pts_strings::format_time($remaining_length, "SECONDS", true) . " Remaining";
 				//self::$progress_window->update_secondary_label("Estimated Time Remaining: " . $time_remaining);
 			}
 		}
