@@ -20,36 +20,14 @@
 	along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
 
-define("M_PHOROMATIC_GEN_RESPONSE", "PhoronixTestSuite/Phoromatic/General/Response");
-define("M_PHOROMATIC_ID", "PhoronixTestSuite/Phoromatic/General/ID");
-define("M_PHOROMATIC_SYS_NAME", "PhoronixTestSuite/Phoromatic/General/SystemName");
-define("M_PHOROMATIC_UPLOAD_TO_GLOBAL", "PhoronixTestSuite/Phoromatic/General/UploadToGlobal");
-define("M_PHOROMATIC_UPLOAD_TEST_LOGS", "PhoronixTestSuite/Phoromatic/General/UploadTestLogs");
-define("M_PHOROMATIC_UPLOAD_SYSTEM_LOGS", "PhoronixTestSuite/Phoromatic/General/UploadSystemLogs");
-define("M_PHOROMATIC_ARCHIVE_RESULTS_LOCALLY", "PhoronixTestSuite/Phoromatic/General/ArchiveResultsLocally");
-define("M_PHOROMATIC_RUN_INSTALL_COMMAND", "PhoronixTestSuite/Phoromatic/General/RunInstallCommand");
-
-define("M_PHOROMATIC_SCHEDULE_TEST_TITLE", "PhoronixTestSuite/Phoromatic/Schedules/TestSchedule/Title");
-define("M_PHOROMATIC_SCHEDULE_TEST_DESCRIPTION", "PhoronixTestSuite/Phoromatic/Schedules/TestSchedule/Description");
-define("M_PHOROMATIC_SCHEDULE_TEST_ACTIVE_ON", "PhoronixTestSuite/Phoromatic/Schedules/TestSchedule/ActiveOn");
-define("M_PHOROMATIC_SCHEDULE_TEST_START", "PhoronixTestSuite/Phoromatic/Schedules/TestSchedule/RunAt");
-
-define("M_PHOROMATIC_RESPONSE_IDLE", "idle");
-define("M_PHOROMATIC_RESPONSE_EXIT", "exit");
-define("M_PHOROMATIC_RESPONSE_RUN_TEST", "benchmark");
-define("M_PHOROMATIC_RESPONSE_SERVER_MAINTENANCE", "server_maintenance");
-define("M_PHOROMATIC_RESPONSE_ERROR", "ERROR");
-define("M_PHOROMATIC_RESPONSE_TRUE", "TRUE");
-define("M_PHOROMATIC_RESPONSE_SETTING_DISABLED", "SETTING_DISABLED");
-
 class phoromatic extends pts_module_interface
 {
 	const module_name = "Phoromatic Client";
-	const module_version = "0.4.0";
+	const module_version = "0.6.1";
 	const module_description = "The Phoromatic client is used for connecting to a Phoromatic server (Phoromatic.com or a locally run server) to facilitate the automatic running of tests, generally across multiple test nodes in a routine manner. For more details visit http://www.phoromatic.com/";
 	const module_author = "Phoronix Media";
 
-	static $phoromatic_lock = null;
+	static $phoromatic_server_build = false;
 
 	static $phoromatic_host = null;
 	static $phoromatic_account = null;
@@ -65,20 +43,29 @@ class phoromatic extends pts_module_interface
 		return array(
 		new pts_module_option("remote_host", "Enter the URL to host", "HTTP_URL", "http://www.phoromatic.com/"),
 		new pts_module_option("remote_account", "Enter the account code", "ALPHA_NUMERIC"),
-		new pts_module_option("remote_verifier", "Enter the verification code", "ALPHA_NUMERIC")
+		new pts_module_option("remote_verifier", "Enter the verification code", "ALPHA_NUMERIC"),
+		new pts_module_option("system_description", "Enter a short (optional) description for this system", null, null, null, false)
 		);
 	}
 	public static function module_setup_validate($options)
 	{
 		if(substr($options["remote_host"], -14) != "phoromatic.php")
 		{
-			$options["remote_host"] = pts_add_trailing_slash($options["remote_host"]) . "phoromatic.php";
+			$options["remote_host"] = pts_strings::add_trailing_slash($options["remote_host"]) . "phoromatic.php";
 		}
 
-		$server_response = phoromatic::upload_to_remote_server(array("r" => "setup", "h" => pts_hw_string(),  "s" => pts_sw_string(),  "o" => phodevi::read_property("system", "hostname")),
-		$options["remote_host"], $options["remote_account"], $options["remote_verifier"]);
+		$server_response = phoromatic::upload_to_remote_server(array(
+			"r" => "setup",
+			"h" => phodevi::system_hardware(true),
+			"s" => phodevi::system_software(true),
+			"o" => phodevi::read_property("system", "hostname"),
+			"sys_desc" => $options["system_description"]
+			),
+			$options["remote_host"], $options["remote_account"], $options["remote_verifier"]);
 
-		$returned_id = pts_xml_read_single_value($server_response, M_PHOROMATIC_GEN_RESPONSE);
+		$returned_id = self::read_xml_value($server_response, M_PHOROMATIC_GEN_RESPONSE);
+
+		unset($options["system_description"]); // No reason to have this locally just pass it to the server
 
 		if(!empty($returned_id))
 		{
@@ -112,9 +99,9 @@ class phoromatic extends pts_module_interface
 
 	public static function user_start()
 	{
-		if(!pts_create_lock(PTS_USER_DIR . "phoromatic_lock", self::$phoromatic_lock))
+		if(pts_client::create_lock(PTS_USER_DIR . "phoromatic_lock") == false)
 		{
-			echo pts_string_header("Phoromatic is already running.");
+			pts_client::$display->generic_error("Phoromatic is already running.");
 			return false;
 		}
 		if(!phoromatic::phoromatic_setup_module())
@@ -137,8 +124,8 @@ class phoromatic extends pts_module_interface
 			return false;
 		}
 
-		pts_set_assignment("PHOROMATIC_UPLOAD_TEST_LOGS", pts_bool_question("Would you like to upload the test logs (y/N)?", false));
-		pts_set_assignment("PHOROMATIC_UPLOAD_SYSTEM_LOGS", pts_bool_question("Would you like to upload the system logs (y/N)?", false));
+		pts_set_assignment("PHOROMATIC_UPLOAD_TEST_LOGS", pts_user_io::prompt_bool_input("Would you like to upload the test logs", false));
+		pts_set_assignment("PHOROMATIC_UPLOAD_SYSTEM_LOGS", pts_user_io::prompt_bool_input("Would you like to upload the system logs", false));
 
 		phoromatic::upload_unscheduled_test_results($to_upload[0]);
 	}
@@ -160,14 +147,14 @@ class phoromatic extends pts_module_interface
 			"i" => $to_clone[0]
 			));
 
-		switch(pts_xml_read_single_value($server_response, M_PHOROMATIC_GEN_RESPONSE))
+		switch(self::read_xml_value($server_response, M_PHOROMATIC_GEN_RESPONSE))
 		{
 			case M_PHOROMATIC_RESPONSE_TRUE:
 				$identifier = "phoromatic-clone-" . str_replace(array('_', ':'), null, $to_clone[0]);
-				pts_save_result($identifier . "/composite.xml", $server_response); // TODO: regenerate the XML so that the Phoromatic response bits are not included
+				pts_client::save_test_result($identifier . "/composite.xml", $server_response); // TODO: regenerate the XML so that the Phoromatic response bits are not included
 				echo "\nResult Saved To: " . SAVE_RESULTS_DIR . $identifier . "/composite.xml\n\n";
 				pts_set_assignment_next("PREV_SAVE_RESULTS_IDENTIFIER", $identifier);
-				pts_display_web_browser(SAVE_RESULTS_DIR . $identifier . "/index.html");
+				pts_client::display_web_page(SAVE_RESULTS_DIR . $identifier . "/index.html");
 				break;
 			case M_PHOROMATIC_RESPONSE_SETTING_DISABLED:
 				echo "\nYou need to enable this support from your Phoromatic account web interface.\n";
@@ -197,7 +184,7 @@ class phoromatic extends pts_module_interface
 
 		if(count($schedule_titles) == 0)
 		{
-			echo "\nNo test schedules for this system were found on Phoromatic.\n";
+			echo "\nNo test schedules for this system were found on the Phoromatic Server.\n";
 		}
 		else
 		{
@@ -228,7 +215,7 @@ class phoromatic extends pts_module_interface
 
 		if(count($schedule_titles) == 0)
 		{
-			echo "\nNo test schedules for this system were found on Phoromatic.\n";
+			echo "\nNo test schedules for this system were found on the Phoromatic Server.\n";
 		}
 		else
 		{
@@ -291,24 +278,30 @@ class phoromatic extends pts_module_interface
 			if(is_file(SAVE_RESULTS_DIR . $save_identifier . "/composite.xml"))
 			{
 				phoromatic::update_system_status("Uploading Test Results");
-				$uploaded_test_results = phoromatic::upload_test_results($save_identifier);
+
+				$times_tried = 0;
+				do
+				{
+					if($times_tried > 0)
+					{
+						echo "\nConnection to server failed. Trying again in 60 seconds...\n";
+						sleep(60);
+					}
+
+					$uploaded_test_results = phoromatic::upload_test_results($save_identifier);
+					$times_tried++;
+				}
+				while(!$uploaded_test_results && $times_tried < 5);
 
 				if(!$uploaded_test_results)
 				{
-					"\nFailed to upload test results on first attempt. Trying again in 60 seconds...\n";
-					sleep(60);
-					$uploaded_test_results = phoromatic::upload_test_results($save_identifier);
-
-					if(!$uploaded_test_results)
-					{
-						echo "\nERROR OCCURRED IN UPLOADING RESULTS\n";
-						return false;
-					}
+					echo "Server connection failed. Exiting...\n";
+					return false;
 				}
 
 				if(!pts_read_assignment("PHOROMATIC_ARCHIVE_RESULTS"))
 				{
-					pts_remove_test_result_dir($save_identifier);
+					pts_client::remove_saved_result_file($save_identifier);
 				}
 			}
 		}
@@ -324,35 +317,44 @@ class phoromatic extends pts_module_interface
 
 		if(define("PHOROMATIC_START", true))
 		{
-			echo "\nRegistering Status With Phoromatic Server\n";
-			$update_sd = phoromatic::update_system_details();
+			echo "\nRegistering Status With Phoromatic Server @ " . date("H:i:s") . "\n";
+
+			$times_tried = 0;
+			do
+			{
+				if($times_tried > 0)
+				{
+					echo "\nConnection to server failed. Trying again in 60 seconds...\n";
+					sleep(60);
+				}
+
+				$update_sd = phoromatic::update_system_details();
+				$times_tried++;
+			}
+			while(!$update_sd && $times_tried < 5);
 
 			if(!$update_sd)
 			{
-				echo "\nConnection to server failed. Trying again in 60 seconds...\n";
-				sleep(60);
-
-				$update_sd = phoromatic::update_system_details();
-
-				if(!$update_sd)
-				{
-					echo "Server connection still failed. Exiting...\n";
-					return false;
-				}
+				echo "Server connection still failed. Exiting...\n";
+				return false;
 			}
 
-			$current_hw = pts_hw_string();
-			$current_sw = pts_sw_string();
+			$current_hw = phodevi::system_hardware(true);
+			$current_sw = phodevi::system_software(true);
+
+			echo "\nIdling 30 seconds for system to settle...\n";
+			sleep(30);
 		}
 
 		do
 		{
+			$exit_loop = false;
 			echo "\nChecking Status From Phoromatic Server @ " . date("H:i:s");
 
-			if($last_communication_minute == date("i") && $communication_attempts > 2)
+			if($last_communication_minute == date('i') && $communication_attempts > 2)
 			{
 				// Something is wrong, Phoromatic shouldn't be communicating with server more than three times a minute
-				$response = "forced_idle";
+				$response = M_PHOROMATIC_RESPONSE_IDLE;
 			}
 			else
 			{
@@ -375,7 +377,7 @@ class phoromatic extends pts_module_interface
 			switch($response)
 			{
 				case M_PHOROMATIC_RESPONSE_RUN_TEST:
-					$args_to_pass = array("AUTOMATED_MODE" => true);
+					$test_args = array("AUTOMATED_MODE" => true);
 
 					do
 					{
@@ -383,43 +385,58 @@ class phoromatic extends pts_module_interface
 					}
 					while(is_file(XML_SUITE_LOCAL_DIR . $suite_identifier . ".xml"));
 
-					$args_to_pass["AUTO_SAVE_NAME"] = date("Y-m-d H:i:s");
-					$args_to_pass["PHOROMATIC_TITLE"] = $xml_parser->getXMLValue(P_SUITE_TITLE);
-					$args_to_pass["PHOROMATIC_SCHEDULE_ID"] = $xml_parser->getXMLValue(M_PHOROMATIC_ID);
-					$args_to_pass["AUTO_TEST_RESULTS_IDENTIFIER"] = $xml_parser->getXMLValue(M_PHOROMATIC_SYS_NAME);
-					$args_to_pass["PHOROMATIC_UPLOAD_TEST_LOGS"] = pts_string_bool($xml_parser->getXMLValue(M_PHOROMATIC_UPLOAD_TEST_LOGS));
-					$args_to_pass["PHOROMATIC_UPLOAD_SYSTEM_LOGS"] = pts_string_bool($xml_parser->getXMLValue(M_PHOROMATIC_UPLOAD_SYSTEM_LOGS));
+					$test_args["AUTO_SAVE_NAME"] = date("Y-m-d H:i:s");
+					$test_args["PHOROMATIC_TITLE"] = $xml_parser->getXMLValue(P_SUITE_TITLE);
+					$test_args["PHOROMATIC_SCHEDULE_ID"] = $xml_parser->getXMLValue(M_PHOROMATIC_ID);
+					$test_args["AUTO_TEST_RESULTS_IDENTIFIER"] = $xml_parser->getXMLValue(M_PHOROMATIC_SYS_NAME);
+					$test_args["PHOROMATIC_UPLOAD_TEST_LOGS"] = pts_strings::string_bool($xml_parser->getXMLValue(M_PHOROMATIC_UPLOAD_TEST_LOGS));
+					$test_args["PHOROMATIC_UPLOAD_SYSTEM_LOGS"] = pts_strings::string_bool($xml_parser->getXMLValue(M_PHOROMATIC_UPLOAD_SYSTEM_LOGS));
+					$test_args["PHOROMATIC_TRIGGER"] = $xml_parser->getXMLValue(M_PHOROMATIC_TRIGGER);
 
-					if(pts_string_bool($xml_parser->getXMLValue(M_PHOROMATIC_UPLOAD_TO_GLOBAL, "FALSE")))
+					if(pts_strings::string_bool($xml_parser->getXMLValue(M_PHOROMATIC_UPLOAD_TO_GLOBAL, "FALSE")))
 					{
-						$args_to_pass["AUTO_UPLOAD_TO_GLOBAL"] = true;
+						$test_args["AUTO_UPLOAD_TO_GLOBAL"] = true;
 					}
 
-					if(pts_string_bool($xml_parser->getXMLValue(M_PHOROMATIC_ARCHIVE_RESULTS_LOCALLY, M_PHOROMATIC_RESPONSE_TRUE)))
+					if(pts_strings::string_bool($xml_parser->getXMLValue(M_PHOROMATIC_ARCHIVE_RESULTS_LOCALLY, M_PHOROMATIC_RESPONSE_TRUE)))
 					{
-						$args_to_pass["PHOROMATIC_ARCHIVE_RESULTS"] = true;
+						$test_args["PHOROMATIC_ARCHIVE_RESULTS"] = true;
 					}
 
 					file_put_contents(XML_SUITE_LOCAL_DIR . $suite_identifier . ".xml", $server_response);
 
-					if(pts_string_bool($xml_parser->getXMLValue(M_PHOROMATIC_RUN_INSTALL_COMMAND, M_PHOROMATIC_RESPONSE_TRUE)))
+					if(pts_strings::string_bool($xml_parser->getXMLValue(M_PHOROMATIC_RUN_INSTALL_COMMAND, M_PHOROMATIC_RESPONSE_TRUE)))
 					{
-						pts_run_option_next("install_test", $suite_identifier, array("AUTOMATED_MODE" => true));
+						phoromatic::set_user_context($xml_parser->getXMLValue(M_PHOROMATIC_SET_CONTEXT_PRE_INSTALL), $test_args["PHOROMATIC_TRIGGER"], $test_args["PHOROMATIC_SCHEDULE_ID"], "INSTALL");
+						pts_client::run_next("install_test", $suite_identifier, array("AUTOMATED_MODE" => true));
 					}
 
-					pts_run_option_next("run_test", $suite_identifier, $args_to_pass);
-					pts_run_option_next("phoromatic.user_system_return", $suite_identifier, $args_to_pass);
+					phoromatic::set_user_context($xml_parser->getXMLValue(M_PHOROMATIC_SET_CONTEXT_PRE_RUN), $test_args["PHOROMATIC_TRIGGER"], $test_args["PHOROMATIC_SCHEDULE_ID"], "INSTALL");
+					pts_client::run_next("run_test", $suite_identifier, $test_args);
+					pts_client::run_next("phoromatic.user_system_return", $suite_identifier, $test_args);
+					$exit_loop = true;
 					break;
 				case M_PHOROMATIC_RESPONSE_EXIT:
 					echo "\nPhoromatic received a remote command to exit.\n";
 					phoromatic::update_system_status("Exiting Phoromatic");
-					pts_release_lock(self::$phoromatic_lock, PTS_USER_DIR . "phoromatic_lock");
+					pts_client::release_lock(PTS_USER_DIR . "phoromatic_lock");
+					$exit_loop = true;
 					break;
 				case M_PHOROMATIC_RESPONSE_SERVER_MAINTENANCE:
 					// The Phoromatic server is down for maintenance, so don't bother updating system status and wait longer before checking back
 					echo "\nThe Phoromatic server is currently down for maintenance. Waiting for service to be restored.\n";
 					sleep((15 - (date("i") % 15)) * 60);
 					break;
+				case M_PHOROMATIC_RESPONSE_SHUTDOWN:
+					echo "\nShutting down the system.\n";
+					$exit_loop = true;
+					shell_exec("poweroff"); // Currently assuming root
+					break;
+				case M_PHOROMATIC_RESPONSE_REBOOT:
+					echo "\nRebooting the system.\n";
+					$exit_loop = true;
+					shell_exec("reboot"); // Currently assuming root
+					break;
 				case M_PHOROMATIC_RESPONSE_IDLE:
 				default:
 					phoromatic::update_system_status("Idling, Waiting For Task");
@@ -427,16 +444,18 @@ class phoromatic extends pts_module_interface
 					break;
 			}
 
-			if(pts_hw_string() != $current_hw || pts_sw_string() != $current_sw)
+			if(phodevi::system_hardware(true) != $current_hw || phodevi::system_software(true) != $current_sw)
 			{
 				// Hardware and/or software has changed while PTS/Phoromatic has been running, update the Phoromatic Server
 				echo "Updating Installed Hardware / Software With Phoromatic Server\n";
 				phoromatic::update_system_details();
-				$current_hw = pts_hw_string();
-				$current_sw = pts_sw_string();
+				$current_hw = phodevi::system_hardware(true);
+				$current_sw = phodevi::system_software(true);
 			}
 		}
-		while(!in_array($response, array(M_PHOROMATIC_RESPONSE_EXIT, M_PHOROMATIC_RESPONSE_RUN_TEST)));
+		while($exit_loop == false);
+
+		phoromatic::update_system_status("Offline");
 	}
 
 	//
@@ -466,21 +485,23 @@ class phoromatic extends pts_module_interface
 			return false;
 		}
 
-		phoromatic::update_system_status("Running " . $pts_test_result->get_test_profile()->get_identifier() . " For " . pts_read_assignment("PHOROMATIC_TITLE"));
+		// TODO: need a way to get the estimated time remaining from the test_run_manager so we can pass that back to the update_system_status parameter so server can read it
+
+		phoromatic::update_system_status("Running " . $pts_test_result->test_profile->get_identifier() . " For " . pts_read_assignment("PHOROMATIC_TITLE"));
 	}
 	public static function __event_user_error($user_error)
 	{
 		// Report PTS user error warnings to Phoromatic server
 		phoromatic::report_warning_to_phoromatic($user_error->get_error_string());
 	}
-	public static function __event_results_saved($result_identifier)
+	public static function __event_results_saved($test_run_manager)
 	{
-		if(pts_module_variable("AUTO_UPLOAD_RESULTS_TO_PHOROMATIC") && !pts_read_assignment("PHOROMATIC_TITLE") && pts_module::is_module_setup())
+		if(pts_module::read_variable("AUTO_UPLOAD_RESULTS_TO_PHOROMATIC") && !pts_read_assignment("PHOROMATIC_TITLE") && pts_module::is_module_setup())
 		{
 			pts_set_assignment("PHOROMATIC_UPLOAD_TEST_LOGS", true);
 			pts_set_assignment("PHOROMATIC_UPLOAD_SYSTEM_LOGS", true);
 
-			phoromatic::upload_unscheduled_test_results($result_identifier);
+			phoromatic::upload_unscheduled_test_results($test_run_manager->get_file_name());
 		}
 	}
 
@@ -488,23 +509,69 @@ class phoromatic extends pts_module_interface
 	// Other Functions
 	//
 
+	protected static function read_xml_value($file, $xml_option)
+	{
+	 	$xml_parser = new tandem_XmlReader($file);
+		return $xml_parser->getXMLValue($xml_option);
+	}
+	private static function set_user_context($context_script, $trigger, $schedule_id, $process)
+	{
+		if(!empty($context_script))
+		{
+			if(!is_executable($context_script))
+			{
+				if(($context_script = pts_client::executable_in_path($context_script)) == false || !is_executable($context_script))
+				{
+					return false;
+				}
+			}
+
+			$storage_path = pts_module::save_dir() . "memory.pt2so";
+			$storage_object = pts_storage_object::recover_from_file($storage_path);
+
+			// We check to see if the context was already set but the system rebooted or something in that script
+			if($storage_object == false)
+			{
+				$storage_object = new pts_storage_object(true, true);
+			}
+			else if($storage_object->read_object("last_set_context_trigger") == $trigger && $storage_object->read_object("last_set_context_schedule") == $schedule_id && $storage_object->read_object("last_set_context_process") == $process)
+			{
+				// If the script already ran once for this trigger, don't run it again
+				return false;
+			}
+
+			$storage_object->add_object("last_set_context_trigger", $trigger);
+			$storage_object->add_object("last_set_context_schedule", $schedule_id);
+			$storage_object->add_object("last_set_context_process", $process);
+			$storage_object->save_to_file($storage_path);
+
+			// Run the set context script
+			exec($context_script . ' ' . $trigger);
+
+			// Just simply return true for now, perhaps check exit code status and do something
+			return true;
+		}
+
+		return false;
+	}
 	protected static function update_system_details()
 	{
-		$server_response = phoromatic::upload_to_remote_server(array("r" => "update_system_details", "h" => pts_hw_string(), "s" => pts_sw_string(), "gsid" => PTS_GSID));
+		$server_response = phoromatic::upload_to_remote_server(array("r" => "update_system_details", "h" => phodevi::system_hardware(true), "s" => phodevi::system_software(true)));
+		self::$phoromatic_server_build = self::read_xml_value($server_response, M_PHOROMATIC_SERVER_BUILD);
 
-		return pts_xml_read_single_value($server_response, M_PHOROMATIC_GEN_RESPONSE) == M_PHOROMATIC_RESPONSE_TRUE;
+		return self::read_xml_value($server_response, M_PHOROMATIC_GEN_RESPONSE) == M_PHOROMATIC_RESPONSE_TRUE;
 	}
-	protected static function update_system_status($current_task)
+	protected static function update_system_status($current_task, $estimated_time_remaining = 0)
 	{
-		$server_response = phoromatic::upload_to_remote_server(array("r" => "update_system_status", "a" => $current_task));
+		$server_response = phoromatic::upload_to_remote_server(array("r" => "update_system_status", "a" => $current_task, "time" => $estimated_time_remaining));
 
-		return pts_xml_read_single_value($server_response, M_PHOROMATIC_GEN_RESPONSE) == M_PHOROMATIC_RESPONSE_TRUE;
+		return self::read_xml_value($server_response, M_PHOROMATIC_GEN_RESPONSE) == M_PHOROMATIC_RESPONSE_TRUE;
 	}
 	protected static function report_warning_to_phoromatic($warning)
 	{
 		$server_response = phoromatic::upload_to_remote_server(array("r" => "report_pts_warning", "a" => $warning));
 
-		return pts_xml_read_single_value($server_response, M_PHOROMATIC_GEN_RESPONSE) == M_PHOROMATIC_RESPONSE_TRUE;
+		return self::read_xml_value($server_response, M_PHOROMATIC_GEN_RESPONSE) == M_PHOROMATIC_RESPONSE_TRUE;
 	}
 	private static function capture_test_logs($save_identifier)
 	{
@@ -512,16 +579,16 @@ class phoromatic extends pts_module_interface
 
 		if(is_dir(SAVE_RESULTS_DIR . $save_identifier . "/system-logs/") && pts_read_assignment("PHOROMATIC_UPLOAD_SYSTEM_LOGS"))
 		{
-			$system_logs_zip = pts_new_temporary_file();
-			pts_zip_archive_create($system_logs_zip, SAVE_RESULTS_DIR . $save_identifier . "/system-logs/");
+			$system_logs_zip = pts_client::create_temporary_file();
+			pts_compression::zip_archive_create($system_logs_zip, SAVE_RESULTS_DIR . $save_identifier . "/system-logs/");
 			$data["system-logs"] = base64_encode(file_get_contents($system_logs_zip));
 			unlink($system_logs_zip);
 		}
 
 		if(is_dir(SAVE_RESULTS_DIR . $save_identifier . "/test-logs/") && pts_read_assignment("PHOROMATIC_UPLOAD_TEST_LOGS"))
 		{
-			$test_logs_zip = pts_new_temporary_file();
-			pts_zip_archive_create($test_logs_zip, SAVE_RESULTS_DIR . $save_identifier . "/test-logs/");
+			$test_logs_zip = pts_client::create_temporary_file();
+			pts_compression::zip_archive_create($test_logs_zip, SAVE_RESULTS_DIR . $save_identifier . "/test-logs/");
 			$data["test-logs"] = base64_encode(file_get_contents($test_logs_zip));
 			unlink($test_logs_zip);
 		}
@@ -538,11 +605,12 @@ class phoromatic extends pts_module_interface
 			"c" => $composite_xml,
 			"i" => pts_read_assignment("PHOROMATIC_SCHEDULE_ID"),
 			"ti" => pts_read_assignment("AUTO_TEST_RESULTS_IDENTIFIER"),
+			"ts" => pts_read_assignment("PHOROMATIC_TRIGGER"),
 			"sl" => $logs["system-logs"],
 			"tl" => $logs["test-logs"]
 			));
 
-		return pts_xml_read_single_value($server_response, M_PHOROMATIC_GEN_RESPONSE) == M_PHOROMATIC_RESPONSE_TRUE;
+		return self::read_xml_value($server_response, M_PHOROMATIC_GEN_RESPONSE) == M_PHOROMATIC_RESPONSE_TRUE;
 	}
 	protected static function upload_unscheduled_test_results($save_identifier)
 	{
@@ -587,16 +655,16 @@ class phoromatic extends pts_module_interface
 		self::$phoromatic_account = pts_module::read_option("remote_account");
 		self::$phoromatic_verifier = pts_module::read_option("remote_verifier");
 		self::$phoromatic_system = pts_module::read_option("remote_system");
-		$phoromatic = "phoromatic";
 
-		pts_attach_module($phoromatic);
+		$phoromatic = "phoromatic";
+		pts_module_manager::attach_module($phoromatic);
 		return true;
 	}
 	protected static function phoromatic_schedule_entry_string($title, $description, $start_time, $active_on)
 	{
 		echo "\n" . $title . ":\n";
 		echo "\t" . $description . "\n";
-		echo "\tRuns at " . $start_time . " on " . pts_parse_week_string($active_on) . ".\n";
+		echo "\tRuns at " . $start_time . " on " . pts_strings::parse_week_string($active_on) . ".\n";
 	}
 
 
@@ -627,7 +695,7 @@ class phoromatic extends pts_module_interface
 
 		if($host != null)
 		{
-			//$host
+			//$host = $host;
 			$to_post["aid"] = $account;
 			$to_post["vid"] = $verifier;
 			$to_post["sid"] = $system;
@@ -646,8 +714,10 @@ class phoromatic extends pts_module_interface
 		}
 
 		$to_post["pts"] = PTS_VERSION;
+		$to_post["pts_core"] = PTS_CORE_VERSION;
+		$to_post["gsid"] = PTS_GSID;
 
-		return pts_http_upload_via_post($host, $to_post);
+		return pts_network::http_upload_via_post($host, $to_post);
 	}
 }
 
