@@ -24,18 +24,24 @@
 class system_monitor extends pts_module_interface
 {
 	const module_name = "System Monitor";
-	const module_version = "2.0.0";
+	const module_version = "3.0.0";
 	const module_description = "This module contains sensor monitoring support.";
 	const module_author = "Michael Larabel";
 
+	static $result_identifier = null;
 	static $to_monitor = array();
 
+	static $individual_test_run_request = null;
+	static $individual_test_run_offsets = null;
+	static $individual_monitoring = null;
+
 	public static function module_info()
 	{
 		$info = "";
 
 		$info .= "\nMonitoring these sensors are as easy as running your normal Phoronix Test Suite commands but at the beginning of the command add: MONITOR=<selected sensors> (example: MONITOR=cpu.temp,cpu.voltage phoronix-test-suite benchmark universe). Below are all of the sensors supported by this version of the Phoronix Test Suite.\n\n";
-		$info .= "Supported Options:\n";
+		$info .= "Supported Options:\n\n";
+
 		foreach(self::monitor_arguments() as $arg)
 		{
 			$info .= "  - " . $arg . "\n";
@@ -56,50 +62,101 @@ class system_monitor extends pts_module_interface
 		}
 	}
 
-	public static function __pre_run_process()
+	public static function __pre_run_process(&$test_run_manager)
 	{
+		self::$result_identifier = $test_run_manager->get_results_identifier();
+		self::$individual_monitoring = pts_module::read_variable("MONITOR_INDIVIDUAL") == '1';
+		self::$individual_monitoring = true;
 		self::$to_monitor = array();
-		$to_show = explode(",", pts_module_variable("MONITOR"));
+		$to_show = pts_strings::comma_explode(pts_module::read_variable("MONITOR"));
 		$monitor_all = in_array("all", $to_show);
 
-		foreach(pts_available_sensors() as $pts_sensor)
+		foreach(phodevi::supported_sensors() as $sensor)
 		{
-			if($monitor_all || in_array($pts_sensor->get_identifier(), $to_show) || in_array("all." . $pts_sensor->get_sensor_type(), $to_show))
+			if($monitor_all || in_array(phodevi::sensor_identifier($sensor), $to_show) || in_array("all." . $sensor[0], $to_show))
 			{
-				if($pts_sensor->read_sensor() != -1)
-				{
-					// Sensor supported
-					array_push(self::$to_monitor, $pts_sensor);
-					pts_module::save_file("logs/" . $pts_sensor->get_identifier());
-				}
+				array_push(self::$to_monitor, $sensor);
+				pts_module::save_file("logs/" . phodevi::sensor_identifier($sensor));
 			}
 		}
 
-		pts_module::pts_timed_function(8, "pts_monitor_update");
+		pts_module::pts_timed_function("pts_monitor_update", 3);
 	}
-	public static function __event_results_process(&$tandem_xml)
+	public static function __pre_test_run(&$test_run_request)
 	{
-		foreach(self::$to_monitor as $id_point => &$pts_sensor)
+		if(self::$individual_monitoring == false)
 		{
-			$sensor_results = self::parse_monitor_log("logs/" . $pts_sensor->get_identifier());
+			return;
+		}
+
+		self::$individual_test_run_request = $test_run_request;
+
+		foreach(self::$to_monitor as $id_point => $sensor)
+		{
+			$log_f = pts_module::read_file("logs/" . phodevi::sensor_identifier($sensor));
+			$offset = count(explode("\n", $log_f));
+			self::$individual_test_run_offsets[$id_point] = $offset;
+		}
+	}
+	public static function __post_test_run_process(&$tandem_xml)
+	{
+		if(self::$individual_monitoring == false)
+		{
+			return;
+		}
+
+		foreach(self::$to_monitor as $id_point => $sensor)
+		{
+			$sensor_results = self::parse_monitor_log("logs/" . phodevi::sensor_identifier($sensor), self::$individual_test_run_offsets[$id_point]);
 
 			if(count($sensor_results) > 2)
 			{
-				$graph_title = $pts_sensor->get_formatted_hardware_type() . " " . $pts_sensor->get_sensor_string() . " Monitor";
-				//$sub_title = implode(" ", pts_read_assignment("TO_RUN_IDENTIFIERS"));
-				$sub_title = "System Monitor Module";
+				$graph_title = phodevi::sensor_name($sensor) . " Monitor";
 
-				$tandem_id = pts_request_new_id();
-				$tandem_xml->addXmlObject(P_RESULTS_TEST_TITLE, $tandem_id, $graph_title);
-				$tandem_xml->addXmlObject(P_RESULTS_TEST_VERSION, $tandem_id, null);
-				$tandem_xml->addXmlObject(P_RESULTS_TEST_ATTRIBUTES, $tandem_id, $sub_title);
-				$tandem_xml->addXmlObject(P_RESULTS_TEST_SCALE, $tandem_id, $pts_sensor->get_sensor_unit());
+				$tandem_id = $tandem_xml->request_unique_id();
+				$tandem_xml->addXmlObject(P_RESULTS_TEST_TITLE, $tandem_id, self::$individual_test_run_request->test_profile->get_title());
+				$tandem_xml->addXmlObject(P_RESULTS_TEST_VERSION, $tandem_id, self::$individual_test_run_request->test_profile->get_version());
+				$tandem_xml->addXmlObject(P_RESULTS_TEST_PROFILE_VERSION, $tandem_id, null);
+				$tandem_xml->addXmlObject(P_RESULTS_TEST_ATTRIBUTES, $tandem_id, phodevi::sensor_name($sensor) . " Monitor");
+				$tandem_xml->addXmlObject(P_RESULTS_TEST_SCALE, $tandem_id, phodevi::read_sensor_unit($sensor));
 				$tandem_xml->addXmlObject(P_RESULTS_TEST_PROPORTION, $tandem_id, null);
 				$tandem_xml->addXmlObject(P_RESULTS_TEST_RESULTFORMAT, $tandem_id, "LINE_GRAPH");
 				$tandem_xml->addXmlObject(P_RESULTS_TEST_TESTNAME, $tandem_id, null);
-				$tandem_xml->addXmlObject(P_RESULTS_TEST_ARGUMENTS, $tandem_id, $pts_sensor->get_formatted_hardware_type() . " " . $pts_sensor->get_sensor_string());
+				$tandem_xml->addXmlObject(P_RESULTS_TEST_ARGUMENTS, $tandem_id, phodevi::sensor_name($sensor) . self::$individual_test_run_request->get_arguments());
 
-				$tandem_xml->addXmlObject(P_RESULTS_RESULTS_GROUP_IDENTIFIER, $tandem_id, pts_read_assignment("TEST_RESULTS_IDENTIFIER"), 5, "sys-monitor-" . $id_point);
+				$tandem_xml->addXmlObject(P_RESULTS_RESULTS_GROUP_IDENTIFIER, $tandem_id, self::$result_identifier, 5, "sys-monitor-" . $id_point);
+				$tandem_xml->addXmlObject(P_RESULTS_RESULTS_GROUP_VALUE, $tandem_id, implode(",", $sensor_results), 5, "sys-monitor-" . $id_point);
+				$tandem_xml->addXmlObject(P_RESULTS_RESULTS_GROUP_RAW, $tandem_id, implode(",", $sensor_results), 5, "sys-monitor-" . $id_point);
+			}
+		}
+
+		self::$individual_test_run_request = null;
+		self::$individual_test_run_offsets[$id_point] = array();
+	}
+	public static function __event_results_process(&$tandem_xml)
+	{
+		foreach(self::$to_monitor as $id_point => $sensor)
+		{
+			$sensor_results = self::parse_monitor_log("logs/" . phodevi::sensor_identifier($sensor));
+			pts_module::remove_file("logs/" . phodevi::sensor_identifier($sensor));
+
+			if(count($sensor_results) > 2)
+			{
+				$graph_title = phodevi::sensor_name($sensor) . " Monitor";
+				$sub_title = "System Monitor Module";
+
+				$tandem_id = $tandem_xml->request_unique_id();
+				$tandem_xml->addXmlObject(P_RESULTS_TEST_TITLE, $tandem_id, $graph_title);
+				$tandem_xml->addXmlObject(P_RESULTS_TEST_VERSION, $tandem_id, null);
+				$tandem_xml->addXmlObject(P_RESULTS_TEST_PROFILE_VERSION, $tandem_id, null);
+				$tandem_xml->addXmlObject(P_RESULTS_TEST_ATTRIBUTES, $tandem_id, $sub_title);
+				$tandem_xml->addXmlObject(P_RESULTS_TEST_SCALE, $tandem_id, phodevi::read_sensor_unit($sensor));
+				$tandem_xml->addXmlObject(P_RESULTS_TEST_PROPORTION, $tandem_id, null);
+				$tandem_xml->addXmlObject(P_RESULTS_TEST_RESULTFORMAT, $tandem_id, "LINE_GRAPH");
+				$tandem_xml->addXmlObject(P_RESULTS_TEST_TESTNAME, $tandem_id, null);
+				$tandem_xml->addXmlObject(P_RESULTS_TEST_ARGUMENTS, $tandem_id, phodevi::sensor_name($sensor));
+
+				$tandem_xml->addXmlObject(P_RESULTS_RESULTS_GROUP_IDENTIFIER, $tandem_id, self::$result_identifier, 5, "sys-monitor-" . $id_point);
 				$tandem_xml->addXmlObject(P_RESULTS_RESULTS_GROUP_VALUE, $tandem_id, implode(",", $sensor_results), 5, "sys-monitor-" . $id_point);
 				$tandem_xml->addXmlObject(P_RESULTS_RESULTS_GROUP_RAW, $tandem_id, implode(",", $sensor_results), 5, "sys-monitor-" . $id_point);
 			}
@@ -107,24 +164,28 @@ class system_monitor extends pts_module_interface
 	}
 	public static function pts_monitor_update()
 	{
-		foreach(self::$to_monitor as &$pts_sensor)
+		foreach(self::$to_monitor as $sensor)
 		{
-			$sensor_value = $pts_sensor->read_sensor();
+			$sensor_value = phodevi::read_sensor($sensor);
 
-			if($sensor_value != -1 && pts_module::is_file("logs/" . $pts_sensor->get_identifier()))
+			if($sensor_value != -1 && pts_module::is_file("logs/" . phodevi::sensor_identifier($sensor)))
 			{
-				pts_module::save_file("logs/" . $pts_sensor->get_identifier(), $sensor_value, true);
+				pts_module::save_file("logs/" . phodevi::sensor_identifier($sensor), $sensor_value, true);
 			}
 		}
 	}
-	private static function parse_monitor_log($log_file)
+	private static function parse_monitor_log($log_file, $start_offset = 0)
 	{
 		$log_f = pts_module::read_file($log_file);
-		pts_module::remove_file($log_file);
 		$line_breaks = explode("\n", $log_f);
 		$contains_a_non_zero = false;
 		$results = array();
 
+		for($i = 0; $i < $start_offset && isset($line_breaks[$i]); $i++)
+		{
+			unset($line_breaks[$i]);
+		}
+
 		foreach($line_breaks as $line)
 		{
 			$line = trim($line);
@@ -152,14 +213,14 @@ class system_monitor extends pts_module_interface
 	{
 		$args = array("all");
 
-		foreach(pts_available_sensors() as $pts_sensor)
+		foreach(phodevi::available_sensors() as $sensor)
 		{
-			if(!in_array("all." . $pts_sensor->get_sensor_type(), $args))
+			if(!in_array("all." . $sensor[0], $args))
 			{
-				array_push($args, "all." . $pts_sensor->get_sensor_type());
+				array_push($args, "all." . $sensor[0]);
 			}
 
-			array_push($args, $pts_sensor->get_hardware_type() . "." . $pts_sensor->get_sensor_type());
+			array_push($args, phodevi::sensor_identifier($sensor));
 		}
 
 		return $args;
