@@ -36,7 +36,7 @@ abstract class bilde_gd_renderer extends bilde_renderer
 	public function html_embed_code($file_name, $attributes = null, $is_xsl = false)
 	{
 		$file_name = str_replace("BILDE_EXTENSION", strtolower($this->get_renderer()), $file_name);
-		$attributes = pts_to_array($attributes);
+		$attributes = pts_arrays::to_array($attributes);
 		$attributes["src"] = $file_name;
 
 		if($is_xsl)
@@ -114,11 +114,27 @@ abstract class bilde_gd_renderer extends bilde_renderer
 
 		imagettftext($this->image, $font_size, $rotation, $text_x, $text_y, $font_color, $font_type, $text_string);
 	}
+	public function draw_pie_piece($center_x, $center_y, $radius, $offset_percent, $percent, $body_color, $border_color = null, $border_width = 1, $title = null)
+	{
+		return false; // TODO: implement
+	}
+	public function draw_dashed_line($start_x, $start_y, $end_x, $end_y, $color, $line_width, $dash_length, $blank_length)
+	{
+		// TODO: dirty, temporary hack
+		if($line_width != 1)
+		{
+			parent::draw_dashed_line($start_x, $start_y, $end_x, $end_y, $color, $line_width, $dash_length, $blank_length);
+		}
+		else
+		{
+			imagedashedline($this->image, $start_x, $start_y, $end_x, $end_y, $color);
+		}
+	}
 	public function write_text_center($text_string, $font_type, $font_size, $font_color, $bound_x1, $bound_y1, $bound_x2, $bound_y2, $rotate_text = false, $onclick = null)
 	{
 		if($bound_x1 != $bound_x2)
 		{
-			while($this->text_string_width($this->trim_double($text_string, 2), $font_type, $font_size) > abs($bound_x2 - $bound_x1 - 2))
+			while($this->text_string_width($text_string, $font_type, $font_size) > abs($bound_x2 - $bound_x1 - 2))
 			{
 				$font_size -= 0.5;
 			}
@@ -220,6 +236,10 @@ abstract class bilde_gd_renderer extends bilde_renderer
 	{
 		return imagecolorallocate($this->image, hexdec(substr($hex, 1, 2)), hexdec(substr($hex, 3, 2)), hexdec(substr($hex, 5, 2)));
 	}
+	public function convert_type_to_hex($type)
+	{
+		return '#' . str_pad(base_convert($type, 10, 16), 6, 0, STR_PAD_LEFT);
+	}
 	public function text_string_dimensions($string, $font_type, $font_size, $predefined_string = false)
 	{
 		return $this->soft_text_string_dimensions($string, $font_type, $font_size, $predefined_string);
