@@ -23,8 +23,8 @@
 
 class bilde_swf_renderer extends bilde_renderer
 {
-	var $swf_font = null;
-	var $renderer = "SWF";
+	private $swf_font = null;
+	public $renderer = "SWF";
 
 	public function __construct($width, $height, $embed_identifiers = "")
 	{
@@ -42,7 +42,7 @@ class bilde_swf_renderer extends bilde_renderer
 	public function html_embed_code($file_name, $attributes = null, $is_xsl = false)
 	{
 		$file_name = str_replace("BILDE_EXTENSION", strtolower($this->get_renderer()), $file_name);
-		$attributes = pts_to_array($attributes);
+		$attributes = pts_arrays::to_array($attributes);
 		$attributes["value"] = $file_name;
 		$attributes["src"] = $file_name;
 
@@ -104,6 +104,10 @@ class bilde_swf_renderer extends bilde_renderer
 	{
 		$this->write_swf_text($text_string, $font_type, $font_size, $font_color, $bound_x1, $bound_y1, $bound_x2, $bound_y2, $rotate_text, "LEFT");
 	}
+	public function draw_pie_piece($center_x, $center_y, $radius, $offset_percent, $percent, $body_color, $border_color = null, $border_width = 1, $title = null)
+	{
+		return false; // TODO: implement
+	}
 	public function write_text_right($text_string, $font_type, $font_size, $font_color, $bound_x1, $bound_y1, $bound_x2, $bound_y2, $rotate_text = false, $onclick = null)
 	{
 		$this->write_swf_text($text_string, $font_type, $font_size, $font_color, $bound_x1, $bound_y1, $bound_x2, $bound_y2, $rotate_text, "RIGHT");
@@ -226,6 +230,10 @@ class bilde_swf_renderer extends bilde_renderer
 	{
 		return array(hexdec(substr($hex, 1, 2)), hexdec(substr($hex, 3, 2)), hexdec(substr($hex, 5, 2)));
 	}
+	public function convert_type_to_hex($type)
+	{
+		return '#' . dexhec($type[0]) . dexhec($type[1]) . dexhec($type[2]);
+	}
 	public function text_string_dimensions($string, $font_type, $font_size, $predefined_string = false)
 	{
 		return array(0, 0);
