@@ -23,29 +23,6 @@
 
 class phodevi_gpu extends phodevi_device_interface
 {
-	public static function read_sensor($identifier)
-	{
-		switch($identifier)
-		{
-			case "temperature":
-				$sensor = "gpu_temperature";
-				break;
-			case "fan-speed":
-				$sensor = "gpu_fan_speed";
-				break;
-			case "current-frequency":
-				$sensor = array("gpu_current_frequency", false);
-				break;
-			case "core-usage":
-				$sensor = "gpu_core_usage";
-				break;
-			default:
-				$sensor = false;
-				break;
-		}
-
-		return $sensor;
-	}
 	public static function read_property($identifier)
 	{
 		switch($identifier)
@@ -295,9 +272,19 @@ class phodevi_gpu extends phodevi_device_interface
 	{
 		$resolution = false;
 
+		if((($default_mode = getenv("DEFAULT_VIDEO_MODE")) != false))
+		{
+			$default_mode = explode('x', $default_mode);
+
+			if(count($default_mode) == 2 && is_numeric($default_mode[0]) && is_numeric($default_mode[1]))
+			{
+				return $default_mode;
+			}
+		}
+
 		if(IS_MACOSX)
 		{
-			$info = pts_trim_explode(' ', phodevi_osx_parser::read_osx_system_profiler("SPDisplaysDataType", "Resolution"));
+			$info = pts_strings::trim_explode(' ', phodevi_osx_parser::read_osx_system_profiler("SPDisplaysDataType", "Resolution"));
 			$resolution = array();
 			$resolution[0] = $info[0];
 			$resolution[1] = $info[2];
@@ -307,14 +294,14 @@ class phodevi_gpu extends phodevi_device_interface
 			if(IS_LINUX)
 			{
 				// Before calling xrandr first try to get the resolution through KMS path
-				foreach(pts_glob("/sys/class/drm/card*/*/modes") as $connector_path)
+				foreach(pts_file_io::glob("/sys/class/drm/card*/*/modes") as $connector_path)
 				{
-					$connector_path = pts_add_trailing_slash(dirname($connector_path));
+					$connector_path = dirname($connector_path) . '/';
 
-					if(is_file($connector_path . "enabled") && pts_file_get_contents($connector_path . "enabled") == "enabled")
+					if(is_file($connector_path . "enabled") && pts_file_io::file_get_contents($connector_path . "enabled") == "enabled")
 					{
-						$mode = pts_first_element_in_array(explode("\n", pts_file_get_contents($connector_path . "modes")));
-						$info = pts_trim_explode('x', $mode);
+						$mode = pts_arrays::first_element(explode("\n", pts_file_io::file_get_contents($connector_path . "modes")));
+						$info = pts_strings::trim_explode('x', $mode);
 
 						if(count($info) == 2)
 						{
@@ -325,23 +312,14 @@ class phodevi_gpu extends phodevi_device_interface
 				}
 			}
 
-			if($resolution == false && IS_NVIDIA_GRAPHICS)
-			{
-				// Way to find resolution through NVIDIA's NV-CONTROL extension
-				if(($frontend_res = phodevi_parser::read_nvidia_extension("FrontendResolution")) != false)
-				{
-					$resolution = explode(',', $frontend_res);
-				}
-			}
-
-			if($resolution == false && pts_executable_in_path("xrandr"))
+			if($resolution == false && pts_client::executable_in_path("xrandr"))
 			{
 				// Read resolution from xrandr
 				$info = shell_exec("xrandr 2>&1 | grep \"*\"");
 
 				if(strpos($info, "*") !== false)
 				{
-					$res = pts_trim_explode("x", $info);
+					$res = pts_strings::trim_explode("x", $info);
 					$res[0] = substr($res[0], strrpos($res[0], " "));
 					$res[1] = substr($res[1], 0, strpos($res[1], " "));
 					$res = array_map("trim", $res);
@@ -353,6 +331,16 @@ class phodevi_gpu extends phodevi_device_interface
 				}
 			}
 
+			if($resolution == false && IS_NVIDIA_GRAPHICS)
+			{
+				// Way to find resolution through NVIDIA's NV-CONTROL extension
+				// But rely upon xrandr first since when using NVIDIA TwinView the reported FrontEndResolution may be the smaller of the two
+				if(($frontend_res = phodevi_parser::read_nvidia_extension("FrontendResolution")) != false)
+				{
+					$resolution = pts_strings::comma_explode($frontend_res);
+				}
+			}
+
 			if($resolution == false)
 			{
 				// Fallback to reading resolution from xdpyinfo
@@ -391,8 +379,9 @@ class phodevi_gpu extends phodevi_device_interface
 		$current_resolution = phodevi::read_property("gpu", "screen-resolution");
 		$current_pixel_count = $current_resolution[0] * $current_resolution[1];
 		$available_modes = array();
-		$supported_ratios = array(1.60, 1.25, 1.33, 1.70, 1.77);
+		$supported_ratios = array(1.60, 1.25, 1.33, 1.70, 1.71, 1.78);
 		$ignore_modes = array(
+			array(640, 400),
 			array(720, 480), array(832, 624),
 			array(960, 540), array(960, 600),
 			array(896, 672), array(928, 696),
@@ -405,7 +394,7 @@ class phodevi_gpu extends phodevi_device_interface
 
 		if($override_check = (($override_modes = getenv("OVERRIDE_VIDEO_MODES")) != false))
 		{
-			$override_modes = explode(',', $override_modes);
+			$override_modes = pts_strings::comma_explode($override_modes);
 
 			for($i = 0; $i < count($override_modes); $i++)
 			{
@@ -414,7 +403,7 @@ class phodevi_gpu extends phodevi_device_interface
 		}
 
 		// Attempt reading available modes from xrandr
-		if(pts_executable_in_path("xrandr") && !IS_MACOSX) // MacOSX has xrandr but currently on at least my setup will emit a Bus Error when called
+		if(pts_client::executable_in_path("xrandr") && !IS_MACOSX) // MacOSX has xrandr but currently on at least my setup will emit a Bus Error when called
 		{
 			$xrandr_lines = array_reverse(explode("\n", shell_exec("xrandr 2>&1")));
 
@@ -425,7 +414,7 @@ class phodevi_gpu extends phodevi_device_interface
 					$xrandr_mode = substr($xrandr_mode, 0, $cut_point);
 				}
 
-				$res = pts_trim_explode('x', $xrandr_mode);
+				$res = pts_strings::trim_explode('x', $xrandr_mode);
 
 				if(count($res) == 2)
 				{
@@ -461,16 +450,16 @@ class phodevi_gpu extends phodevi_device_interface
 
 		foreach($available_modes as $mode_index => $mode)
 		{
-			$this_ratio = pts_trim_double($mode[0] / $mode[1], 2);
+			$this_ratio = pts_math::set_precision($mode[0] / $mode[1], 2);
 
 			if($override_check && !in_array($mode, $override_modes))
 			{
 				// Using override modes and this mode is not present
 				unset($available_modes[$mode_index]);
 			}
-			else if($current_pixel_count > 614400 && ($mode[0] * $mode[1]) < 480000)
+			else if($current_pixel_count > 614400 && ($mode[0] * $mode[1]) < 480000 && stripos(phodevi::read_name("gpu"), "llvmpipe") === false)
 			{
-				// For displays larger than 1024 x 600, drop modes below 800 x 600
+				// For displays larger than 1024 x 600, drop modes below 800 x 600 unless llvmpipe is being used
 				unset($available_modes[$mode_index]);
 			}
 			else if($current_pixel_count > 480000 && !in_array($this_ratio, $supported_ratios))
@@ -616,7 +605,7 @@ class phodevi_gpu extends phodevi_device_interface
 	}
 	public static function gpu_frequency_string()
 	{
-		$freq = (IS_ATI_GRAPHICS || IS_MESA_GRAPHICS ? phodevi::read_property("gpu", "stock-frequency") : phodevi_gpu::gpu_current_frequency());
+		$freq = phodevi::read_property("gpu", "stock-frequency");
 		$freq_string = null;
 
 		if($freq[0] != 0)
@@ -641,7 +630,8 @@ class phodevi_gpu extends phodevi_device_interface
 
 		if(IS_NVIDIA_GRAPHICS) // NVIDIA GPU
 		{
-			list($core_freq, $mem_freq) = explode(",", phodevi_parser::read_nvidia_extension("GPUDefault3DClockFreqs"));
+			// GPUDefault3DClockFreqs is the default and does not show under/over-clocking
+			list($core_freq, $mem_freq) = pts_strings::comma_explode(phodevi_parser::read_nvidia_extension("GPU3DClockFreqs"));
 		}
 		else if(IS_ATI_GRAPHICS && IS_LINUX) // ATI GPU
 		{
@@ -654,19 +644,40 @@ class phodevi_gpu extends phodevi_device_interface
 		}
 		else if(IS_MESA_GRAPHICS)
 		{
-			switch(phodevi::read_property("system", "dri-display-driver"))
+			switch(phodevi::read_property("system", "display-driver"))
 			{
 				case "radeon":
-					// Sure would be nice if there was a cleaner way of handling this...
-					$log_parse = shell_exec("cat /var/log/Xorg.0.log 2>&1 | grep \" Clock: \"");
+					if(is_file("/sys/kernel/debug/dri/0/radeon_pm_info"))
+					{
+						// radeon_pm_info should be present with Linux 2.6.34+
+						foreach(pts_strings::trim_explode("\n", pts_file_io::file_get_contents("/sys/kernel/debug/dri/0/radeon_pm_info")) as $pm_line)
+						{
+							list($descriptor, $value) = pts_strings::colon_explode($pm_line);
 
-					$core_freq = substr($log_parse, strpos($log_parse, "Default Engine Clock: ") + 22);
-					$core_freq = substr($core_freq, 0, strpos($core_freq, "\n"));
-					$core_freq = is_numeric($core_freq) ? $core_freq / 1000 : 0;
+							switch($descriptor)
+							{
+								case "default engine clock":
+									$core_freq = pts_arrays::first_element(explode(' ', $value)) / 1000;
+									break;
+								case "default memory clock":
+									$mem_freq = pts_arrays::first_element(explode(' ', $value)) / 1000;
+									break;
+							}
+						}
+					}
+					else
+					{
+						// Old ugly way of handling the clock information
+						$log_parse = shell_exec("cat /var/log/Xorg.0.log 2>&1 | grep \" Clock: \"");
 
-					$mem_freq = substr($log_parse, strpos($log_parse, "Default Memory Clock: ") + 22);
-					$mem_freq = substr($mem_freq, 0, strpos($mem_freq, "\n"));
-					$mem_freq = is_numeric($mem_freq) ? $mem_freq / 1000 : 0;					
+						$core_freq = substr($log_parse, strpos($log_parse, "Default Engine Clock: ") + 22);
+						$core_freq = substr($core_freq, 0, strpos($core_freq, "\n"));
+						$core_freq = is_numeric($core_freq) ? $core_freq / 1000 : 0;
+
+						$mem_freq = substr($log_parse, strpos($log_parse, "Default Memory Clock: ") + 22);
+						$mem_freq = substr($mem_freq, 0, strpos($mem_freq, "\n"));
+						$mem_freq = is_numeric($mem_freq) ? $mem_freq / 1000 : 0;
+					}				
 					break;
 			}
 		}
@@ -685,7 +696,7 @@ class phodevi_gpu extends phodevi_device_interface
 	public static function gpu_model()
 	{
 		// Report graphics processor string
-		$info = pts_executable_in_path("glxinfo") != false ? shell_exec("glxinfo 2>&1 | grep renderer") : null;
+		$info = pts_client::executable_in_path("glxinfo") != false ? shell_exec("glxinfo 2>&1 | grep renderer") : null;
 		$video_ram = phodevi::read_property("gpu", "memory-capacity");
 
 		if(($pos = strpos($info, "renderer string:")) > 0)
@@ -701,7 +712,7 @@ class phodevi_gpu extends phodevi_device_interface
 		if(IS_ATI_GRAPHICS && IS_LINUX)
 		{
 			$crossfire_status = phodevi_linux_parser::read_amd_pcsdb("SYSTEM/Crossfire/chain/*,Enable");
-			$crossfire_status = pts_to_array($crossfire_status);
+			$crossfire_status = pts_arrays::to_array($crossfire_status);
 			$crossfire_card_count = 0;
 
 			for($i = 0; $i < count($crossfire_status); $i++)
@@ -762,8 +773,6 @@ class phodevi_gpu extends phodevi_device_interface
 			{
 				$info = substr($info, 0, $cut);
 			}
-
-			$info = $info;
 		}
 		else if(IS_BSD)
 		{
@@ -857,99 +866,10 @@ class phodevi_gpu extends phodevi_device_interface
 	
 		$clean_phrases = array("OpenGL Engine");
 		$info = str_replace($clean_phrases, "", $info);
-		$info = pts_clean_information_string($info);
+		$info = phodevi::clean_info_string($info);
 
 		return $info;
 	}
-	public static function gpu_temperature()
-	{
-		// Report graphics processor temperature
-		$temp_c = -1;
-
-		if(IS_NVIDIA_GRAPHICS)
-		{
-			$temp_c = phodevi_parser::read_nvidia_extension("GPUCoreTemp");
-		}
-		else if(IS_ATI_GRAPHICS && IS_LINUX)
-		{
-			$temp_c = phodevi_linux_parser::read_ati_overdrive("Temperature");
-		}
-
-		return is_numeric($temp_c) ? $temp_c : -1;
-	}
-	public static function gpu_fan_speed()
-	{
-		// Report graphics processor fan speed as a percent
-		$fan_speed = -1;
-
-		if(IS_NVIDIA_GRAPHICS)
-		{
-			// NVIDIA fan speed reading support in NVIDIA 190.xx and newer
-			// TODO: support for multiple fans, also for reading GPUFanTarget to get appropriate fan
-			// nvidia-settings --describe GPUFanTarget 
-			$fan_speed = phodevi_parser::read_nvidia_extension("[fan:0]/GPUCurrentFanSpeed");
-		}
-		else if(IS_ATI_GRAPHICS && IS_LINUX)
-		{
-			$fan_speed = phodevi_linux_parser::read_ati_overdrive("FanSpeed");
-		}
-
-		return is_numeric($fan_speed) ? $fan_speed : -1;
-	}
-	public static function gpu_current_frequency($show_memory = true)
-	{
-		// Graphics processor real/current frequency
-		$core_freq = 0;
-		$mem_freq = 0;
-
-		if(IS_NVIDIA_GRAPHICS) // NVIDIA GPU
-		{
-			$nv_freq = phodevi_parser::read_nvidia_extension("GPUCurrentClockFreqs");
-
-			$nv_freq = explode(",", $nv_freq);
-			$core_freq = $nv_freq[0];
-			$mem_freq = $nv_freq[1];
-		}
-		else if(IS_ATI_GRAPHICS && IS_LINUX) // ATI GPU
-		{
-			$od_clocks = phodevi_linux_parser::read_ati_overdrive("CurrentClocks");
-
-			if(is_array($od_clocks) && count($od_clocks) >= 2) // ATI OverDrive
-			{
-				$core_freq = array_shift($od_clocks);
-				$mem_freq = array_pop($od_clocks);
-			}
-		}
-
-		if(!is_numeric($core_freq))
-		{
-			$core_freq = 0;
-		}
-		if(!is_numeric($mem_freq))
-		{
-			$mem_freq = 0;
-		}
-
-		if($core_freq == 0 && $mem_freq == 0)
-		{
-			$show_memory = false;
-			$core_freq = -1;
-		}
-
-		return ($show_memory ? array($core_freq, $mem_freq) : $core_freq);
-	}
-	public static function gpu_core_usage()
-	{
-		// Determine GPU usage
-		$gpu_usage = -1;
-
-		if(IS_ATI_GRAPHICS && IS_LINUX)
-		{
-			$gpu_usage = phodevi_linux_parser::read_ati_overdrive("GPUload");
-		}
-
-		return $gpu_usage;
-	}
 }
 
 ?>
