@@ -23,48 +23,6 @@
 
 class phodevi_system extends phodevi_device_interface
 {
-	public static function read_sensor($identifier)
-	{
-		switch($identifier)
-		{
-			case "temperature":
-				$sensor = "sys_temperature";
-				break;
-			case "cpu-voltage":
-				$sensor = "sys_cpu_voltage";
-				break;
-			case "v3-voltage":
-				$sensor = "sys_v3_voltage";
-				break;
-			case "v5-voltage":
-				$sensor = "sys_v5_voltage";
-				break;
-			case "v12-voltage":
-				$sensor = "sys_v12_voltage";
-				break;
-			case "power-consumption":
-			case "battery-discharge-rate":
-				$sensor = "sys_power_consumption_rate";
-				break;
-			case "power-current":
-				$sensor = "sys_power_current";
-				break;
-			case "uptime":
-				$sensor = "sys_uptime";
-				break;
-			case "iowait":
-				$sensor = "sys_iowait";
-				break;
-			case "fan-speed":
-				$sensor = "sys_fan_speed";
-				break;
-			default:
-				$sensor = false;
-				break;
-		}
-
-		return $sensor;
-	}
 	public static function read_property($identifier)
 	{
 		switch($identifier)
@@ -94,7 +52,10 @@ class phodevi_system extends phodevi_device_interface
 				$property = new phodevi_device_property("sw_display_server", PHODEVI_SMART_CACHE);
 				break;
 			case "display-driver":
-				$property = new phodevi_device_property("sw_display_driver", PHODEVI_STAND_CACHE);
+				$property = new phodevi_device_property(array("sw_display_driver", false), PHODEVI_STAND_CACHE);
+				break;
+			case "display-driver-string":
+				$property = new phodevi_device_property(array("sw_display_driver", true), PHODEVI_STAND_CACHE);
 				break;
 			case "dri-display-driver":
 				$property = new phodevi_device_property("sw_dri_display_driver", PHODEVI_SMART_CACHE);
@@ -120,6 +81,9 @@ class phodevi_system extends phodevi_device_interface
 			case "kernel-architecture":
 				$property = new phodevi_device_property("sw_kernel_architecture", PHODEVI_SMART_CACHE);
 				break;
+			case "kernel-string":
+				$property = new phodevi_device_property("sw_kernel_string", PHODEVI_SMART_CACHE);
+				break;
 			case "compiler":
 				$property = new phodevi_device_property("sw_compiler", PHODEVI_STAND_CACHE);
 				break;
@@ -127,328 +91,6 @@ class phodevi_system extends phodevi_device_interface
 
 		return $property;
 	}
-	public static function sys_cpu_voltage()
-	{
-		if(IS_LINUX)
-		{
-			$sensor = phodevi_linux_parser::read_sensors("VCore");
-		}
-		else
-		{
-			$sensor = null;
-		}
-
-		return is_numeric($sensor) ? $sensor : -1;
-	}
-	public static function sys_v3_voltage()
-	{
-		if(IS_LINUX)
-		{
-			$sensor = phodevi_linux_parser::read_sensors(array("V3.3", "+3.3V"));
-		}
-		else
-		{
-			$sensor = null;
-		}
-
-		return is_numeric($sensor) ? $sensor : -1;
-	}
-	public static function sys_v5_voltage()
-	{
-		if(IS_LINUX)
-		{
-			$sensor = phodevi_linux_parser::read_sensors(array("V5", "+5V"));
-		}
-		else
-		{
-			$sensor = null;
-		}
-
-		return is_numeric($sensor) ? $sensor : -1;
-	}
-	public static function sys_v12_voltage()
-	{
-		if(IS_LINUX)
-		{
-			$sensor = phodevi_linux_parser::read_sensors(array("V12", "+12V"));
-		}
-		else
-		{
-			$sensor = null;
-		}
-
-		return is_numeric($sensor) ? $sensor : -1;
-	}
-	public static function sys_temperature()
-	{
-		// Reads the system's temperature
-		$temp_c = -1;
-
-		if(IS_LINUX)
-		{
-			// Assuming the first thermal sensor is for the system, see TODO in phodevi_cpu
-			$raw_temp = phodevi_linux_parser::read_sysfs_node("/sys/class/thermal/thermal_zone*/temp", "POSITIVE_NUMERIC");
-
-			if($raw_temp == -1)
-			{
-				$raw_temp = phodevi_linux_parser::read_sysfs_node("/sys/class/hwmon/hwmon*/device/temp1_input", "POSITIVE_NUMERIC", array("name" => "!coretemp"));
-			}
-
-			if($raw_temp == -1)
-			{
-				$raw_temp = phodevi_linux_parser::read_sysfs_node("/sys/class/hwmon/hwmon*/temp1_input", "POSITIVE_NUMERIC");
-			}
-
-			if($raw_temp != -1)
-			{
-				if($raw_temp > 1000)
-				{
-					$raw_temp = $raw_temp / 1000;
-				}
-
-				$temp_c = pts_trim_double($raw_temp, 2);	
-			}
-
-			if($temp_c == -1)
-			{
-				$acpi = phodevi_linux_parser::read_acpi(array(
-					"/thermal_zone/THM1/temperature",
-					"/thermal_zone/TZ00/temperature",
-					"/thermal_zone/TZ01/temperature"), "temperature");
-
-				if(($end = strpos($acpi, ' ')) > 0)
-				{
-					$temp_c = substr($acpi, 0, $end);
-				}
-			}
-
-			if($temp_c == -1)
-			{
-				$sensors = phodevi_linux_parser::read_sensors(array("Sys Temp", "Board Temp"));
-
-				if($sensors != false && is_numeric($sensors))
-				{
-					$temp_c = $sensors;
-				}
-			}
-		}
-		else if(IS_BSD)
-		{
-			$acpi = phodevi_bsd_parser::read_sysctl("hw.acpi.thermal.tz1.temperature");
-
-			if(($end = strpos($acpi, 'C')) > 0)
-			{
-				$acpi = substr($acpi, 0, $end);
-
-				if(is_numeric($acpi))
-				{
-					$temp_c = $acpi;
-				}
-			}
-		}
-
-		return $temp_c;
-	}
-	public static function sys_power_consumption_rate()
-	{
-		// Returns power consumption rate in mW
-		$rate = -1;
-
-		if(IS_LINUX)
-		{
-			$power_now = phodevi_linux_parser::read_sysfs_node("/sys/class/power_supply/*/power_now", "POSITIVE_NUMERIC", array("status" => "Discharging"));
-
-			if($power_now != -1)
-			{
-				// sysfs power_now seems to be displayed in microWatts
-				$rate = pts_trim_double($power_now / 1000, 2);
-			}
-
-			if($rate == -1)
-			{
-				$battery = array("/battery/BAT0/state", "/battery/BAT1/state");
-				$state = phodevi_linux_parser::read_acpi($battery, "charging state");
-				$power = phodevi_linux_parser::read_acpi($battery, "present rate");
-				$voltage = phodevi_linux_parser::read_acpi($battery, "present voltage");
-
-				if($state == "discharging")
-				{
-					$power_unit = substr($power, strrpos($power, " ") + 1);
-					$power = substr($power, 0, strpos($power, " "));
-
-					if($power_unit == "mA")
-					{
-						$voltage_unit = substr($voltage, strrpos($voltage, " ") + 1);
-						$voltage = substr($voltage, 0, strpos($voltage, " "));
-
-						if($voltage_unit == "mV")
-						{
-							$rate = round(($power * $voltage) / 1000);
-						}				
-					}
-					else if($power_unit == "mW")
-					{
-						$rate = $power;
-					}
-				}
-			}
-		}
-		else if(IS_SOLARIS)
-		{
-			$battery = phodevi_solaris_parser::read_hal_property("/org/freedesktop/Hal/devices/pseudo/acpi_drv_0_battery0_0", "battery.reporting.rate");
-
-			if(is_numeric($battery))
-			{
-				$rate = $battery;
-			}
-		}
-		else if(IS_BSD)
-		{
-			$battery = phodevi_bsd_parser::read_acpiconf("Present rate");
-
-			if($battery && substr($battery, -2) == "mW")
-			{
-				$rate = substr($battery, 0, strpos($battery, " "));
-			}
-		}
-
-		return $rate;
-	}
-	public static function sys_power_current()
-	{
-		// Returns power consumption rate in uA
-		$current = -1;
-
-		if(IS_LINUX)
-		{
-			$raw_current = phodevi_linux_parser::read_sysfs_node("/sys/devices/w1_bus_master1/*/getcurrent", "NO_CHECK");
-
-			if($raw_current != -1)
-			{
-				if(substr($raw_current, 0, 1) == "-")
-				{
-					$current = substr($raw_current, 1);
-				}
-			}
-		}
-
-		return $current;
-	}
-	public static function sys_iowait()
-	{
-		$iowait = -1;
-
-		if(IS_LINUX && is_file("/proc/stat"))
-		{
-			$start_stat = pts_file_get_contents("/proc/stat");
-			sleep(1);
-			$end_stat = pts_file_get_contents("/proc/stat");
-
-			$start_stat = explode(" ", substr($start_stat, 0, strpos($start_stat, "\n")));
-			$end_stat = explode(" ", substr($end_stat, 0, strpos($end_stat, "\n")));
-
-			for($i = 2, $diff_cpu_total = 0; $i < 9; $i++)
-			{
-				$diff_cpu_total += $end_stat[$i] - $start_stat[$i];
-			}
-
-			$diff_iowait = $end_stat[6] - $start_stat[6];
-
-			$iowait = pts_trim_double(1000 * $diff_iowait / $diff_cpu_total / 10, 2);	
-		}
-
-		return $iowait;
-	}
-	public static function sys_uptime()
-	{
-		// Returns the system's uptime in seconds
-		$uptime = 1;
-
-		if(is_file("/proc/uptime"))
-		{
-			$uptime = pts_first_string_in_string(pts_file_get_contents("/proc/uptime"));
-		}
-		else if(($uptime_cmd = pts_executable_in_path("uptime")) != false)
-		{
-			$uptime_counter = 0;
-			$uptime_output = shell_exec($uptime_cmd . " 2>&1");
-			$uptime_output = substr($uptime_output, strpos($uptime_output, " up") + 3);
-			$uptime_output = substr($uptime_output, 0, strpos($uptime_output, " user"));
-			$uptime_output = substr($uptime_output, 0, strrpos($uptime_output, ",")) . " ";
-
-			if(($day_end_pos = strpos($uptime_output, " day")) !== false)
-			{
-				$day_output = substr($uptime_output, 0, $day_end_pos);
-				$day_output = substr($day_output, strrpos($day_output, " ") + 1);
-
-				if(is_numeric($day_output))
-				{
-					$uptime_counter += $day_output * 86400;
-				}
-			}
-
-			if(($mins_end_pos = strpos($uptime_output, " mins")) !== false)
-			{
-				$mins_output = substr($uptime_output, 0, $day_end_pos);
-				$mins_output = substr($mins_output, strrpos($mins_output, " ") + 1);
-
-				if(is_numeric($mins_output))
-				{
-					$uptime_counter += $mins_output * 60;
-				}
-			}
-
-			if(($time_split_pos = strpos($uptime_output, ":")) !== false)
-			{
-				$hours_output = substr($uptime_output, 0, $time_split_pos);
-				$hours_output = substr($hours_output, strrpos($hours_output, " ") + 1);
-				$mins_output = substr($uptime_output, $time_split_pos + 1);
-				$mins_output = substr($mins_output, 0, strpos($mins_output, " "));
-
-				if(is_numeric($hours_output))
-				{
-					$uptime_counter += $hours_output * 3600;
-				}
-				if(is_numeric($mins_output))
-				{
-					$uptime_counter += $mins_output * 60;
-				}
-			}
-
-			if(is_numeric($uptime_counter) && $uptime_counter > 0)
-			{
-				$uptime = $uptime_counter;
-			}
-		}
-
-		return intval($uptime);
-	}
-	public static function sys_fan_speed()
-	{
-		$fan_speed = -1;
-
-		if(IS_LINUX)
-		{
-			$raw_fan = phodevi_linux_parser::read_sysfs_node("/sys/class/hwmon/hwmon*/device/fan2_input", "POSITIVE_NUMERIC");
-
-			if($raw_fan == -1)
-			{
-				$raw_fan = phodevi_linux_parser::read_sysfs_node("/sys/class/hwmon/hwmon*/device/fan3_input", "POSITIVE_NUMERIC");
-			}
-
-			if($raw_fan == -1)
-			{
-				$raw_fan = phodevi_linux_parser::read_sysfs_node("/sys/class/hwmon/hwmon*/device/fan4_input", "POSITIVE_NUMERIC");
-			}
-
-			if($raw_fan != -1)
-			{
-				$fan_speed = $raw_fan;
-			}
-		}
-
-		return $fan_speed;
-	}
 	public static function sw_username()
 	{
 		// Gets the system user's name
@@ -468,7 +110,7 @@ class phodevi_system extends phodevi_device_interface
 	{
 		$hostname = "Unknown";
 
-		if(($bin = pts_executable_in_path("hostname")))
+		if(($bin = pts_client::executable_in_path("hostname")))
 		{
 			$hostname = trim(shell_exec($bin . " 2>&1"));
 		}
@@ -482,13 +124,13 @@ class phodevi_system extends phodevi_device_interface
 	public static function sw_vendor_identifier()
 	{
 		// Returns the vendor identifier used with the External Dependencies and other distro-specific features
-		$vendor = IS_LINUX ? phodevi_linux_parser::read_lsb("Distributor ID") : false;
+		$vendor = IS_LINUX ? phodevi_linux_parser::read_lsb_distributor_id() : false;
 
 		if(!$vendor)
 		{
 			$vendor = phodevi::read_property("system", "operating-system");
 
-			if(($spos = strpos($vendor, " ")) > 1)
+			if(($spos = strpos($vendor, ' ')) > 1)
 			{
 				$vendor = substr($vendor, 0, $spos);
 			}
@@ -507,7 +149,7 @@ class phodevi_system extends phodevi_device_interface
 		}
 		else if(IS_BSD)
 		{
-			if(pts_executable_in_path("mount"))
+			if(pts_client::executable_in_path("mount"))
 			{
 				$mount = shell_exec("mount 2>&1");
 				
@@ -540,11 +182,25 @@ class phodevi_system extends phodevi_device_interface
 			switch($fs)
 			{
 				case "UNKNOWN (0x9123683e)":
+					// 0x9123683e is the superblock for Btrfs
 					$fs = "Btrfs";
 					break;
+				case "UNKNOWN (0x52345362)":
+					// 0x52345362 is the superblock for Reiser4
+					$fs = "Reiser4";
+					break;
 				case "UNKNOWN (0x3434)":
+					// 0x3434 is the superblock for NILFS2
 					$fs = "NILFS2";
 					break;
+				case "UNKNOWN (0x24051905)":
+					// 0x24051905 is the superblock for UBIFS
+					$fs = "UBIFS";
+					break;
+				case "UNKNOWN (0x65735546)":
+					// 0x65735546 is the superblock for the FUSE module
+					$fs = "FUSE";
+					break;
 				case "ext2/ext3":
 					if(is_readable("/proc/mounts"))
 					{
@@ -614,7 +270,7 @@ class phodevi_system extends phodevi_device_interface
 		$virtualized = null;
 		$gpu = phodevi::read_name("gpu");
 
-		if(strpos(phodevi::read_property("cpu", "model"), "QEMU") !== false || (is_readable("/sys/class/dmi/id/bios_vendor") && pts_file_get_contents("/sys/class/dmi/id/bios_vendor") == "QEMU"))
+		if(strpos(phodevi::read_property("cpu", "model"), "QEMU") !== false || (is_readable("/sys/class/dmi/id/bios_vendor") && pts_file_io::file_get_contents("/sys/class/dmi/id/bios_vendor") == "QEMU"))
 		{
 			$virtualized = "QEMU";
 		}
@@ -637,27 +293,22 @@ class phodevi_system extends phodevi_device_interface
 	public static function sw_compiler()
 	{
 		// Returns version of the compiler (if present)
-		$compiler_info = null;
+		$compilers = array();
 
-		if(pts_executable_in_path("gcc"))
+		if(pts_client::executable_in_path("gcc"))
 		{
 			// GCC
-			$compiler_info = "GCC " . trim(shell_exec("gcc -dumpversion 2>&1"));
+			$compilers["gcc"] = "GCC " . trim(shell_exec("gcc -dumpversion 2>&1"));
 		}
-		else if(pts_executable_in_path("suncc"))
+
+		if(pts_client::executable_in_path("clang"))
 		{
-			// Sun Studio / SunCC
-			$info = trim(shell_exec("suncc -V 2>&1"));
-
-			if(($s = strpos($info, "Sun C")) != false)
-			{
-				$info = substr($info, $s);
-				$info = substr($info, 0, strpos($info, "\n"));
-
-				$compiler_info = $info;
-			}
+			// Clang
+			$compiler_info = "Clang " . trim(shell_exec("clang -dumpversion 2>&1"));
+			$compilers["clang"] = trim($compiler_info);
 		}
-		else if(pts_executable_in_path("llvmc"))
+
+		if(pts_client::executable_in_path("llvmc"))
 		{
 			// LLVM - Low Level Virtual Machine (llvmc)
 			$info = trim(shell_exec("llvmc -version 2>&1"));
@@ -667,31 +318,77 @@ class phodevi_system extends phodevi_device_interface
 				$info = substr($info, 0, strpos($info, "\n", $s));
 				$info = substr($info, strrpos($info, "\n"));
 
-				$compiler_info = trim($info);
+				$compilers["llvmc"] = trim($info);
 			}
 		}
 
-		return $compiler_info;
+		if(pts_client::executable_in_path("suncc"))
+		{
+			// Sun Studio / SunCC
+			$info = trim(shell_exec("suncc -V 2>&1"));
+
+			if(($s = strpos($info, "Sun C")) != false)
+			{
+				$info = substr($info, $s);
+				$info = substr($info, 0, strpos($info, "\n"));
+
+				$compilers["suncc"] = $info;
+			}
+		}
+
+		// Try to make the compiler that's used by default to appear first
+		if(pts_client::read_env("CC") && isset($compilers[basename(pts_client::read_env("CC"))]))
+		{
+			$cc_env = basename(pts_client::read_env("CC"));
+			$default_compiler = $compilers[$cc_env];
+			unset($compilers[$cc_env]);
+			array_unshift($compilers, $default_compiler);
+		}
+		else if(pts_client::executable_in_path("cc") && is_link(pts_client::executable_in_path("cc")))
+		{
+			$cc_link = basename(readlink(pts_client::executable_in_path("cc")));
+
+			if(isset($compilers[$cc_link]))
+			{
+				$default_compiler = $compilers[$cc_link];
+				unset($compilers[pts_client::read_env("CC")]);
+				array_unshift($compilers, $default_compiler);
+			}
+		}
+
+		return implode(" + ", array_unique($compilers));
+	}
+	public static function sw_kernel_string()
+	{
+		return phodevi::read_property("system", "kernel") . " (" . phodevi::read_property("system", "kernel-architecture") . ")";
 	}
 	public static function sw_kernel()
 	{
-		return php_uname("r");
+		return php_uname('r');
 	}
 	public static function sw_kernel_architecture()
 	{
 		// Find out the kernel archiecture
-		$kernel_arch = php_uname('m');
-
-		switch($kernel_arch)
+		if(IS_WINDOWS)
 		{
-			case "X86-64":
-			case "amd64":
-				$kernel_arch = "x86_64";
-				break;
-			case "i86pc":
-			case "i586":
-				$kernel_arch = "i686";
-				break;
+			//$kernel_arch = strpos($_SERVER["PROCESSOR_ARCHITECTURE"], 64) !== false || strpos($_SERVER["PROCESSOR_ARCHITEW6432"], 64 != false) ? "x86_64" : "i686";
+			$kernel_arch = $_SERVER["PROCESSOR_ARCHITEW6432"] == "AMD64" ? "x86_64" : "i686";
+		}
+		else
+		{
+			$kernel_arch = php_uname('m');
+
+			switch($kernel_arch)
+			{
+				case "X86-64":
+				case "amd64":
+					$kernel_arch = "x86_64";
+					break;
+				case "i86pc":
+				case "i586":
+					$kernel_arch = "i686";
+					break;
+			}
 		}
 
 		return $kernel_arch;
@@ -729,7 +426,7 @@ class phodevi_system extends phodevi_device_interface
 	public static function sw_operating_system()
 	{
 		// Determine the operating system release
-		$vendor = IS_LINUX ? phodevi_linux_parser::read_lsb("Distributor ID") : false;
+		$vendor = IS_LINUX ? phodevi_linux_parser::read_lsb_distributor_id() : false;
 		$version = phodevi::read_property("system", "os-version");
 
 		if(!$vendor || $version == "Unknown")
@@ -785,7 +482,14 @@ class phodevi_system extends phodevi_device_interface
 
 			if($os == null)
 			{
-				$os = php_uname("s");
+				if(IS_WINDOWS)
+				{
+					$os = trim(exec("ver"));
+				}
+				else
+				{
+					$os = php_uname("s");
+				}
 			}
 		}
 		else
@@ -818,17 +522,17 @@ class phodevi_system extends phodevi_device_interface
 		$desktop_environment = null;
 		$desktop_version = null;
 
-		if(pts_process_running_bool("gnome-panel"))
+		if(pts_client::is_process_running("gnome-panel"))
 		{
 			// GNOME
 			$desktop_environment = "GNOME";
 
-			if(pts_executable_in_path("gnome-about"))
+			if(pts_client::executable_in_path("gnome-about"))
 			{
-				$desktop_version = pts_last_string_in_string(trim(shell_exec("gnome-about --version 2> /dev/null")));
+				$desktop_version = pts_strings::last_in_string(trim(shell_exec("gnome-about --version 2> /dev/null")));
 			}
 		}
-		else if(($kde4 = pts_process_running_bool("kded4")) || pts_process_running_bool("kded"))
+		else if(($kde4 = pts_client::is_process_running("kded4")) || pts_client::is_process_running("kded"))
 		{
 			// KDE 4.x
 			$desktop_environment = "KDE";
@@ -837,7 +541,7 @@ class phodevi_system extends phodevi_device_interface
 
 			for($i = 0; $i < count($kde_lines) && empty($desktop_version); $i++)
 			{
-				$line_segments = explode(":", $kde_lines[$i]);
+				$line_segments = pts_strings::colon_explode($kde_lines[$i]);
 
 				if(in_array($line_segments[0], array("KDE", "KDE Development Platform")) && isset($line_segments[1]))
 				{
@@ -852,7 +556,7 @@ class phodevi_system extends phodevi_device_interface
 				}
 			}
 		}
-		else if(pts_process_running_bool("chromeos-wm"))
+		else if(pts_client::is_process_running("chromeos-wm"))
 		{
 			$chrome_output = trim(shell_exec("chromeos-wm -version"));
 
@@ -864,19 +568,19 @@ class phodevi_system extends phodevi_device_interface
 
 			$desktop_environment = $chrome_output;
 		}
-		else if(pts_process_running_bool("lxde-settings"))
+		else if(pts_client::is_process_running("lxsession"))
 		{
 			$lx_output = trim(shell_exec("lxpanel --version"));
 			$version = substr($lx_output, strpos(" ", $lx_output) + 1);
 
 			$desktop_environment = "LXDE";
 
-			if(strlen(pts_remove_chars($version, true, true, false, false, false, false)) == strlen($version))
+			if(strlen(pts_strings::keep_in_string($version, TYPE_CHAR_NUMERIC | TYPE_CHAR_DECIMAL)) == strlen($version))
 			{
 				$desktop_version = $version;
 			}
 		}
-		else if(pts_process_running_bool("xfce4-session") || pts_process_running_bool("xfce-mcs-manager"))
+		else if(pts_client::is_process_running("xfce4-session") || pts_client::is_process_running("xfce-mcs-manager"))
 		{
 			// Xfce 4.x
 			$desktop_environment = "Xfce";
@@ -911,7 +615,7 @@ class phodevi_system extends phodevi_device_interface
 		}
 		else
 		{
-			if(!(($x_bin = pts_executable_in_path("Xorg")) || ($x_bin = pts_executable_in_path("X"))))
+			if(!(($x_bin = pts_client::executable_in_path("Xorg")) || ($x_bin = pts_client::executable_in_path("X"))))
 			{
 				return false;
 			}
@@ -942,45 +646,53 @@ class phodevi_system extends phodevi_device_interface
 
 		return $info;
 	}
-	public static function sw_display_driver()
+	public static function sw_display_driver($with_version = true)
 	{
 		if(IS_WINDOWS)
 		{
 			return null;
 		}
 
-		$ddx_info = "";
-		$xorg_module_driver = phodevi::read_property("system", "dri-display-driver");
+		$display_driver = phodevi::read_property("system", "dri-display-driver");
 
-		if(empty($xorg_module_driver))
+		if(empty($display_driver))
 		{
 			if(IS_ATI_GRAPHICS)
 			{
-				$xorg_module_driver = "fglrx";
+				$display_driver = "fglrx";
 			}
 			else if(IS_NVIDIA_GRAPHICS)
 			{
-				$xorg_module_driver = "nvidia";
+				$display_driver = "nvidia";
 			}
-			else if((IS_MESA_GRAPHICS || IS_BSD) && stripos(phodevi::read_name("gpu"), "NVIDIA") !== false)
+			else if((IS_MESA_GRAPHICS || IS_BSD) && stripos(phodevi::read_property("gpu", "model"), "NVIDIA") !== false)
 			{
-				$xorg_module_driver = "nv";
+				if(is_file("/sys/class/drm/version"))
+				{
+					// If there's DRM loaded and NVIDIA, it should be Nouveau
+					$display_driver = "nouveau";
+				}
+				else
+				{
+					// The dead xf86-video-nv doesn't use any DRM
+					$display_driver = "nv";
+				}
 			}
 			else
 			{
 				// Fallback to hopefully detect the module, takes the first word off the GPU string and sees if it is the module
 				// This works in at least the case of the Cirrus driver
-				$xorg_module_driver = strtolower(pts_first_string_in_string(phodevi::read_name("gpu")));
+				$display_driver = strtolower(pts_strings::first_in_string(phodevi::read_property("gpu", "model")));
 			}
 		}
 
-		if(!empty($xorg_module_driver))
+		if(!empty($display_driver))
 		{
-			$driver_version = phodevi_parser::read_xorg_module_version($xorg_module_driver . "_drv");
+			$driver_version = phodevi_parser::read_xorg_module_version($display_driver . "_drv");
 
 			if($driver_version == false || $driver_version == "1.0.0")
 			{
-				switch($xorg_module_driver)
+				switch($display_driver)
 				{
 					case "radeon":
 						// RadeonHD driver also reports DRI driver as "radeon", so try reading that instead
@@ -988,7 +700,7 @@ class phodevi_system extends phodevi_device_interface
 
 						if($driver_version != false)
 						{
-							$xorg_module_driver = "radeonhd";
+							$display_driver = "radeonhd";
 						}
 						break;
 					case "nvidia":
@@ -1011,25 +723,25 @@ class phodevi_system extends phodevi_device_interface
 				}
 			}
 
-			if($driver_version == false && IS_UNKNOWN_GRAPHICS)
+			if($driver_version == false)
 			{
 				// See if the VESA driver is in use
 				$vesa_version = phodevi_parser::read_xorg_module_version("vesa_drv");
 
 				if($vesa_version)
 				{
-					$xorg_module_driver = "vesa";
+					$display_driver = "vesa";
 					$driver_version = $vesa_version;
 				}
 			}
 
-			if(!empty($driver_version))
+			if(!empty($driver_version) && $with_version)
 			{
-				$ddx_info = $xorg_module_driver . " " . $driver_version;
+				$display_driver .= ' ' . $driver_version;
 			}
 		}
 
-		return $ddx_info;
+		return $display_driver;
 	}
 	public static function sw_opengl_driver()
 	{
@@ -1040,23 +752,19 @@ class phodevi_system extends phodevi_device_interface
 		{
 			$info = null; // TODO: Windows support
 		}
-		else if(pts_executable_in_path("glxinfo"))
+		else if(pts_client::executable_in_path("glxinfo"))
 		{
 			$info = phodevi_parser::software_glxinfo_version();
 
-			if(($pos = strpos($info, ' ')) != false)
+			if(($pos = strpos($info, ' ')) != false && strpos($info, "Mesa") === false)
 			{
 				$info = substr($info, 0, $pos);
 			}
 		}
-		else if((IS_NVIDIA_LINUX || (IS_BSD && phodevi_bsd_parser::read_sysctl("dev.nvidia.0.%driver"))) && pts_executable_in_path("nvidia-settings"))
+		else if(pts_client::executable_in_path("nvidia-settings"))
 		{
 			$info = phodevi_parser::read_nvidia_extension("OpenGLVersion");
 		}
-		else
-		{
-			$info = null;
-		}
 
 		return $info;
 	}
@@ -1065,7 +773,7 @@ class phodevi_system extends phodevi_device_interface
 		// OpenGL version
 		$info = null;
 
-		if(pts_executable_in_path("glxinfo"))
+		if(pts_client::executable_in_path("glxinfo"))
 		{
 			$info = shell_exec("glxinfo 2>&1 | grep vendor");
 
@@ -1079,6 +787,10 @@ class phodevi_system extends phodevi_device_interface
 		{
 			$info = "NVIDIA";
 		}
+		else if(is_readable("/sys/module/fglrx/initstate") && pts_file_io::file_get_contents("/sys/module/fglrx/initstate") == "live")
+		{
+			$info = "ATI";
+		}
 		else if(is_readable("/dev/dri/card0"))
 		{
 			$info = "Mesa";
@@ -1099,11 +811,29 @@ class phodevi_system extends phodevi_device_interface
 			$driver_info = file_get_contents("/proc/dri/0/name");
 			$dri_driver = substr($driver_info, 0, strpos($driver_info, " "));
 
-			if($dri_driver == "i915")
+			if(in_array($dri_driver, array("i915", "i965")))
 			{
 				$dri_driver = "intel";
 			}
 		}
+		else if(is_file("/sys/class/drm/card0/device/vendor"))
+		{
+			$vendor_id = file_get_contents("/sys/class/drm/card0/device/vendor");
+
+			switch($vendor_id)
+			{
+				case 0x1002:
+					$dri_driver = "radeon";
+					break;
+				case 0x8086:
+					$dri_driver = "intel";
+					break;
+				case 0x10de:
+					// NVIDIA
+					$dri_driver = "nouveau";
+					break;
+			}
+		}
 
 		return $dri_driver;
 	}
@@ -1137,7 +867,7 @@ class phodevi_system extends phodevi_device_interface
 	{
 		$python_version = null;
 
-		if(pts_executable_in_path("python") != false)
+		if(pts_client::executable_in_path("python") != false)
 		{
 			$python_version = trim(shell_exec("python -V 2>&1"));
 		}
