@@ -32,7 +32,7 @@ class phodevi_linux_parser
 		{
 			$find_count = 0;
 
-			foreach(pts_glob($search) as $sysfs_file)
+			foreach(pts_file_io::glob($search) as $sysfs_file)
 			{
 				if(is_array($node_dir_check))
 				{
@@ -48,7 +48,7 @@ class phodevi_linux_parser
 						}
 						else if($value_check !== true)
 						{
-							$value_check_value = pts_file_get_contents($sysfs_dir . $node_check);
+							$value_check_value = pts_file_io::file_get_contents($sysfs_dir . $node_check);
 
 							if(isset($value_check[0]) && $value_check[0] == '!')
 							{
@@ -72,7 +72,7 @@ class phodevi_linux_parser
 					}
 				}
 
-				$sysfs_value = pts_file_get_contents($sysfs_file);
+				$sysfs_value = pts_file_io::file_get_contents($sysfs_file);
 
 				switch($type)
 				{
@@ -117,16 +117,16 @@ class phodevi_linux_parser
 			}
 		}
 
-		return $sysfs_file_cache[$arg_hash] == false ? -1 : pts_file_get_contents($sysfs_file_cache[$arg_hash]);
+		return $sysfs_file_cache[$arg_hash] == false ? -1 : pts_file_io::file_get_contents($sysfs_file_cache[$arg_hash]);
 	}
 	public static function read_dmidecode($type, $sub_type, $object, $find_once = false, $ignore = null)
 	{
 		// Read Linux dmidecode
 		$value = array();
 
-		if(is_readable("/dev/mem") && pts_executable_in_path("dmidecode"))
+		if(is_readable("/dev/mem") && pts_client::executable_in_path("dmidecode"))
 		{
-			$ignore = pts_to_array($ignore);
+			$ignore = pts_arrays::to_array($ignore);
 
 			$dmidecode = shell_exec("dmidecode --type " . $type . " 2>&1");
 			$sub_type = "\n" . $sub_type . "\n";
@@ -145,7 +145,7 @@ class phodevi_linux_parser
 					$found_in_section = false;
 					for($i = 0; $i < count($dmidecode_elements) && $found_in_section == false; $i++)
 					{
-						$dmidecode_r = pts_trim_explode(":", $dmidecode_elements[$i]);
+						$dmidecode_r = pts_strings::colon_explode($dmidecode_elements[$i]);
 
 						if($dmidecode_r[0] == $object && isset($dmidecode_r[1]) && !in_array($dmidecode_r[1], $ignore))
 						{
@@ -190,9 +190,9 @@ class phodevi_linux_parser
 					break;
 			}
 
-			$start_stat = pts_trim_spaces(file_get_contents($path));
+			$start_stat = pts_strings::trim_spaces(file_get_contents($path));
 			usleep(500000);
-			$end_stat = pts_trim_spaces(file_get_contents($path));
+			$end_stat = pts_strings::trim_spaces(file_get_contents($path));
 
 			$start_stat = explode(" ", $start_stat);
 			$end_stat = explode(" ", $end_stat);
@@ -207,7 +207,7 @@ class phodevi_linux_parser
 			$speed = $delta_seconds != 0 ? $delta_mb / $delta_seconds : 0;
 		}
 
-		return pts_trim_double($speed, 2);
+		return pts_math::set_precision($speed, 2);
 	}
 	public static function read_sys_dmi($identifier)
 	{
@@ -217,11 +217,11 @@ class phodevi_linux_parser
 		{
 			$ignore_words = phodevi_parser::hardware_values_to_remove();
 
-			foreach(pts_to_array($identifier) as $id)
+			foreach(pts_arrays::to_array($identifier) as $id)
 			{
 				if(is_readable("/sys/class/dmi/id/" . $id))
 				{
-					$dmi_file = pts_file_get_contents("/sys/class/dmi/id/" . $id);
+					$dmi_file = pts_file_io::file_get_contents("/sys/class/dmi/id/" . $id);
 
 					if(!empty($dmi_file) && !in_array(strtolower($dmi_file), $ignore_words))
 					{
@@ -240,7 +240,7 @@ class phodevi_linux_parser
 		// OverDrive supported in fglrx 8.52+ drivers
 		$value = false;
 
-		if(pts_executable_in_path("aticonfig"))
+		if(pts_client::executable_in_path("aticonfig"))
 		{
 			if($attribute == "Temperature")
 			{
@@ -276,15 +276,15 @@ class phodevi_linux_parser
 				{
 					foreach(explode("\n", $info) as $line)
 					{
-						$line_r = explode(":", $line);
+						$line_r = pts_strings::colon_explode($line);
 
 						if(count($line_r) == 2)
 						{
-							$od_option = str_replace(" ", "", trim($line_r[0]));
+							$od_option = str_replace(" ", "", $line_r[0]);
 
 							if($od_option == $attribute)
 							{
-								$od_value = pts_trim_spaces($line_r[1]);
+								$od_value = pts_strings::trim_spaces($line_r[1]);
 								$od_value = str_replace(array("%"), "", $od_value);
 								$od_value_r = explode(" ", $od_value);
 
@@ -307,7 +307,7 @@ class phodevi_linux_parser
 
 		if($try_aticonfig)
 		{
-			if(pts_executable_in_path("aticonfig"))
+			if(pts_client::executable_in_path("aticonfig"))
 			{
 				$info = shell_exec("aticonfig --get-pcs-key=" . $attribute . " 2>&1");
 
@@ -347,7 +347,7 @@ class phodevi_linux_parser
 		$last_found_section_count = -1;
 		$this_section_count = 0;
 		$attribute_values = array();
-		$attribute = explode(",", $attribute);
+		$attribute = pts_strings::comma_explode($attribute);
 
 		if(count($attribute) == 2)
 		{
@@ -372,7 +372,7 @@ class phodevi_linux_parser
 
 					for($i = 0; $i < count($attribute_prefix) && $i < count($header) && $prefix_matches; $i++)
 					{
-						if($attribute_prefix[$i] != $header[$i] && !pts_proximity_match($attribute_prefix[$i], $header[$i]))
+						if($attribute_prefix[$i] != $header[$i] && pts_strings::proximity_match($attribute_prefix[$i], $header[$i]) == false)
 						{
 							$prefix_matches = false;
 						}
@@ -437,7 +437,7 @@ class phodevi_linux_parser
 		// Read ATI/AMD graphics hardware using aticonfig
 		$adapters = array();
 
-		if(pts_executable_in_path("aticonfig"))
+		if(pts_client::executable_in_path("aticonfig"))
 		{
 			$info = trim(shell_exec("aticonfig --list-adapters 2>&1"));
 
@@ -457,7 +457,7 @@ class phodevi_linux_parser
 		// Read CPU information
 		$cpuinfo_matches = array();
 
-		foreach(pts_to_array($attribute) as $attribute_check)
+		foreach(pts_arrays::to_array($attribute) as $attribute_check)
 		{
 			if(is_file("/proc/cpuinfo"))
 			{
@@ -465,7 +465,13 @@ class phodevi_linux_parser
 
 				foreach($cpuinfo_lines as $line)
 				{
-					$line = pts_trim_explode(": ", $line);
+					$line = pts_strings::trim_explode(": ", $line);
+
+					if(!isset($line[0]))
+					{
+						continue;
+					}
+
 					$this_attribute = $line[0];
 					$this_value = (count($line) > 1 ? $line[1] : "");
 
@@ -484,12 +490,25 @@ class phodevi_linux_parser
 
 		return $cpuinfo_matches;
 	}
+	public static function read_lsb_distributor_id()
+	{
+		$vendor = phodevi_linux_parser::read_lsb("Distributor ID");
+
+		// Quirks for derivative distributions that don't know how to handle themselves properly
+		if($vendor == "MandrivaLinux" && phodevi_linux_parser::read_lsb("Description") == "PCLinuxOS")
+		{
+			// PC Linux OS only stores its info in /etc/pclinuxos-release
+			$vendor = false;
+		}
+
+		return $vendor;
+	}
 	public static function read_lsb($desc)
 	{
 		// Read LSB Release information, Linux Standards Base
 		$info = false;
 
-		if(pts_executable_in_path("lsb_release"))
+		if(pts_client::executable_in_path("lsb_release"))
 		{
 			static $output = null;
 
@@ -512,9 +531,9 @@ class phodevi_linux_parser
 		// Read HAL - Hardware Abstraction Layer
 		$info = false;
 
-		if(pts_executable_in_path("lshal"))
+		if(pts_client::executable_in_path("lshal"))
 		{
-			$name = pts_to_array($name);
+			$name = pts_arrays::to_array($name);
 			$remove_words = phodevi_parser::hardware_values_to_remove();
 
 			for($i = 0; $i < count($name) && empty($info); $i++)
@@ -552,7 +571,7 @@ class phodevi_linux_parser
 	{
 		// Read ACPI - Advanced Configuration and Power Interface
 		$value = false;
-		$point = pts_to_array($point);
+		$point = pts_arrays::to_array($point);
 
 		for($i = 0; $i < count($point) && empty($value); $i++)
 		{
@@ -562,7 +581,7 @@ class phodevi_linux_parser
 
 				for($i = 0; $i < count($acpi_lines) && $value == false; $i++)
 				{
-					$line = pts_trim_explode(": ", $acpi_lines[$i]);
+					$line = pts_strings::trim_explode(": ", $acpi_lines[$i]);
 					$this_attribute = $line[0];
 					$this_value = (count($line) > 1 ? $line[1] : null);
 
@@ -581,7 +600,7 @@ class phodevi_linux_parser
 		// Read PCI bus information
 		static $pci_info = null;
 		$info = false;
-		$desc = pts_to_array($desc);
+		$desc = pts_arrays::to_array($desc);
 
 		if($pci_info == null)
 		{
@@ -589,7 +608,7 @@ class phodevi_linux_parser
 			{
 				$lspci_cmd = "/sbin/lspci";
 			}
-			else if(($lspci = pts_executable_in_path("lspci")))
+			else if(($lspci = pts_client::executable_in_path("lspci")))
 			{
 				$lspci_cmd = $lspci;
 			}
@@ -638,7 +657,7 @@ class phodevi_linux_parser
 
 				if(($strlen = strlen($sub_pci_info)) >= 6 && $strlen < 96)
 				{
-					$info = pts_clean_information_string($sub_pci_info);
+					$info = phodevi::clean_info_string($sub_pci_info);
 				}
 			}
 		}
@@ -650,18 +669,24 @@ class phodevi_linux_parser
 		// Read LM_Sensors
 		$value = false;
 
-		if(pts_executable_in_path("sensors"))
+		if(pts_client::executable_in_path("sensors"))
 		{
 			$sensors = shell_exec("sensors 2>&1");
 			$sensors_lines = explode("\n", $sensors);
-			$attributes = pts_to_array($attributes);
+			$attributes = pts_arrays::to_array($attributes);
 
 			for($j = 0; $j < count($attributes) && empty($value); $j++)
 			{
 				$attribute = $attributes[$j];
 				for($i = 0; $i < count($sensors_lines) && $value == false; $i++)
 				{
-					$line = pts_trim_explode(": ", $sensors_lines[$i]);
+					$line = pts_strings::trim_explode(": ", $sensors_lines[$i]);
+
+					if(!isset($line[0]))
+					{
+						continue;
+					}
+
 					$this_attribute = $line[0];
 
 					if($this_attribute == $attribute)
