@@ -21,14 +21,14 @@
 	along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
 
-class pts_BarGraph extends pts_CustomGraph
+class pts_BarGraph extends pts_Graph
 {
 	protected $identifier_width = -1;
 	protected $minimum_identifier_font = 6;
 
-	public function __construct(&$result_object)
+	public function __construct(&$result_object, &$result_file = null)
 	{
-		parent::__construct($result_object);
+		parent::__construct($result_object, $result_file);
 		$this->graph_type = "BAR_GRAPH";
 	}
 	protected function render_graph_pre_init()
@@ -48,33 +48,27 @@ class pts_BarGraph extends pts_CustomGraph
 	}
 	protected function render_graph_identifiers()
 	{
-		$px_from_top_start = $this->graph_top_end - 5;
 		$px_from_top_end = $this->graph_top_end + 5;
 
+		$this->graph_image->draw_dashed_line($this->graph_left_start + $this->identifier_width, $this->graph_top_end, $this->graph_left_end - ($this->graph_attr_width % $this->identifier_width), $this->graph_top_end, $this->graph_color_notches, 10, 1, $this->identifier_width - 1);
+
 		foreach(array_keys($this->graph_identifiers) as $i)
 		{
 			$px_bound_left = $this->graph_left_start + ($this->identifier_width * $i);
 			$px_bound_right = $px_bound_left + $this->identifier_width;
 
-			if($i == 0)
-			{
-				$this->graph_image->draw_line($px_bound_left, $px_from_top_start, $px_bound_left, $px_from_top_end, $this->graph_color_notches);
-			}
-
 			if($i == (count($this->graph_identifiers) - 1) && $px_bound_right != $this->graph_left_end)
 			{
 				$px_bound_right = $this->graph_left_end;
 			}
 
-			$this->graph_image->draw_line($px_bound_right, $px_from_top_start, $px_bound_right, $px_from_top_end, $this->graph_color_notches);
-
 			if($this->graph_font_size_identifiers <= $this->minimum_identifier_font)
 			{
 				$this->graph_image->write_text_left($this->graph_identifiers[$i], $this->graph_font, 9, $this->graph_color_headers, $px_bound_left + ceil($this->identifier_width / 2), $px_from_top_end, $px_bound_left + ceil($this->identifier_width / 2), $px_from_top_end, true);
 			}
 			else
 			{
-				$this->graph_image->write_text_center($this->graph_identifiers[$i], $this->graph_font, $this->graph_font_size_identifiers, $this->graph_color_headers, $px_bound_left, $px_from_top_end - 3, $px_bound_right, $px_from_top_end - 3, false, true);
+				$this->graph_image->write_text_center($this->graph_identifiers[$i], $this->graph_font, $this->graph_font_size_identifiers, $this->graph_color_headers, $px_bound_left, $px_from_top_end - 3, $px_bound_right, $px_from_top_end - 3, false);
 			}
 		}
 	}
@@ -83,14 +77,15 @@ class pts_BarGraph extends pts_CustomGraph
 		$bar_count = count($this->graph_data);
 		$separator_width = ($a = (8 - (floor($bar_count / 2) * 2))) > 0 ? $a : 0;
 		$bar_width = floor(($this->identifier_width - $separator_width - ($bar_count * $separator_width)) / $bar_count);
+		$highlight_bar = PTS_MODE == "CLIENT" ? pts_strings::comma_explode(pts_client::read_env("GRAPH_HIGHLIGHT")) : false;
 
 		for($i_o = 0; $i_o < $bar_count; $i_o++)
 		{
-			$paint_color = $this->next_paint_color();
+			$paint_color = $this->get_paint_color((isset($this->graph_data_title[$i_o]) ? $this->graph_data_title[$i_o] : null));
 
 			foreach(array_keys($this->graph_data[$i_o]) as $i)
 			{
-				$value = $this->trim_double($this->graph_data[$i_o][$i], 2);
+				$value = pts_math::set_precision($this->graph_data[$i_o][$i], 2);
 				$graph_size = round(($value / $this->graph_maximum_value) * ($this->graph_top_end - $this->graph_top_start));
 				$value_plot_top = $this->graph_top_end + 1 - $graph_size;
 
@@ -102,15 +97,15 @@ class pts_BarGraph extends pts_CustomGraph
 					$value_plot_top = 1;
 				}
 
-				$title_tooltip = $this->graph_identifiers[$i_o] . ": " . $this->graph_data[$i_o][$i];
-				$run_std_deviation = pts_standard_deviation(explode(':', $this->graph_data_raw[$i_o][$i]));
+				$title_tooltip = $this->graph_identifiers[$i] . ": " . $value;
+				$run_std_deviation = isset($this->graph_data_raw[$i_o][$i]) ? pts_math::standard_deviation(pts_strings::colon_explode($this->graph_data_raw[$i_o][$i])) : 0;
 
 				if($run_std_deviation > 0)
 				{
-					$title_tooltip .= " || " . $this->trim_double($run_std_deviation, 1) . " STD.";
+					$title_tooltip .= " || " . pts_math::set_precision($run_std_deviation, 1) . " STD.";
 				}
 
-				$this->graph_image->draw_rectangle_with_border($px_bound_left + 1, $value_plot_top, $px_bound_right - 1, $this->graph_top_end, $paint_color, $this->graph_color_body_light, $title_tooltip);
+				$this->graph_image->draw_rectangle_with_border($px_bound_left + 1, $value_plot_top, $px_bound_right - 1, $this->graph_top_end, in_array($this->graph_identifiers[$i], $highlight_bar) ? $this->graph_color_alert : $paint_color, $this->graph_color_body_light, $title_tooltip);
 
 				if(($px_bound_right - $px_bound_left) < 15)
 				{
@@ -120,11 +115,11 @@ class pts_BarGraph extends pts_CustomGraph
 
 				if($graph_size > 18)
 				{
-					$this->graph_image->write_text_center($this->graph_data[$i_o][$i], $this->graph_font, $this->graph_font_size_bars, $this->graph_color_body_text, $px_bound_left + 1, $value_plot_top + 2, $px_bound_right - 1, $value_plot_top + 2);
+					$this->graph_image->write_text_center($value, $this->graph_font, $this->graph_font_size_bars, $this->graph_color_body_text, $px_bound_left + 2, $value_plot_top + 2, $px_bound_right - 2, $value_plot_top + 2);
 				}
 				else if($graph_size > 10)
 				{
-					$this->graph_image->write_text_center($this->graph_data[$i_o][$i], $this->graph_font, ceil($this->graph_font_size_bars * 0.6), $this->graph_color_body_text, $px_bound_left, $value_plot_top  + 1, $px_bound_right, $value_plot_top + 1);
+					$this->graph_image->write_text_center($value, $this->graph_font, ceil($this->graph_font_size_bars * 0.6), $this->graph_color_body_text, $px_bound_left, $value_plot_top  + 1, $px_bound_right, $value_plot_top + 1);
 				}
 			}
 		}
