@@ -23,9 +23,9 @@
 
 class pts_CandleStickGraph extends pts_BarGraph
 {
-	public function __construct(&$result_object)
+	public function __construct(&$result_object, &$result_file = null)
 	{
-		parent::__construct($result_object);
+		parent::__construct($result_object, $result_file);
 		$this->graph_type = "CANDLE_STICK_GRAPH";
 	}
 	protected function render_graph_candle_sticks()
@@ -35,11 +35,11 @@ class pts_CandleStickGraph extends pts_BarGraph
 
 		for($i_o = 0; $i_o < $bar_count; $i_o++)
 		{
-			$paint_color = $this->next_paint_color();
+			$paint_color = $this->get_paint_color((isset($this->graph_data_title[$i_o]) ? $this->graph_data_title[$i_o] : null));
 
 			for($i = 0; $i < count($this->graph_data_raw[$i_o]); $i++)
 			{
-				$run_values_r = explode(":", $this->graph_data_raw[$i_o][$i]);
+				$run_values_r = pts_strings::colon_explode($this->graph_data_raw[$i_o][$i]);
 
 				$start_value = $run_values_r[0];
 				$end_value = $run_values_r[(count($run_values_r) - 1)];
