@@ -24,10 +24,10 @@
 abstract class pts_Graph
 {
 	// Defaults
-	protected $graph_attr_marks = 6; // Number of marks to make on vertical axis
-	protected $graph_attr_width = 580; // Graph width
-	protected $graph_attr_height = 300; // Graph height
-	protected $graph_attr_big_border = false; // Border around graph or not
+	protected $graph_attr_marks; // Number of marks to make on vertical axis
+	protected $graph_attr_width; // Graph width
+	protected $graph_attr_height; // Graph height
+	protected $graph_attr_big_border; // Border around graph or not
 
 	protected $graph_left_start = 10; // Distance in px to start graph from left side
 	protected $graph_left_end_opp = 10; // Distance in px to end graph from right side
@@ -35,33 +35,31 @@ abstract class pts_Graph
 	protected $graph_top_end_opp = 22; // Distance in px to end graph from bottom side
 
 	// Colors
-	protected $graph_color_notches = "#000000"; // Color for notches
-	protected $graph_color_text = "#000000"; // Color for text
-	protected $graph_color_border = "#000000"; // Color for border (if used)
-	protected $graph_color_main_headers = "#2b6b29"; // Color of main text headers
-	protected $graph_color_headers = "#2b6b29"; // Color of other headers
-	protected $graph_color_background = "#FFFFFF"; // Color of background
-	protected $graph_color_body = "#8b8f7c"; // Color of graph body
-	protected $graph_color_body_text = "#FFFFFF"; // Color of graph body text
-	protected $graph_color_body_light = "#B0B59E"; // Color of the border around graph bars (if doing a bar graph)
-	protected $graph_color_alert = "#C80000"; // Color of any alerts
-
-	protected $graph_color_paint = array("#3B433A", "#BB2413", "#FF9933", "#006C00", "#5028CA", "#0094B3", 
-	"#A8BC00", "#00F6FF", "#8A00AC", "#790066", "#797766", "#5598b1"); // Colors to use for the bars / lines, one color for each key
+	protected $graph_color_notches; // Color for notches
+	protected $graph_color_text; // Color for text
+	protected $graph_color_border; // Color for border (if used)
+	protected $graph_color_main_headers; // Color of main text headers
+	protected $graph_color_headers; // Color of other headers
+	protected $graph_color_background; // Color of background
+	protected $graph_color_body; // Color of graph body
+	protected $graph_color_body_text; // Color of graph body text
+	protected $graph_color_body_light; // Color of the border around graph bars (if doing a bar graph)
+	protected $graph_color_alert; // Color of any alerts
+	protected $graph_color_paint; // Colors to use for the bars / lines, one color for each key
 
 	// Text
-	protected $graph_font = "Sans.ttf"; // TTF file name
+	protected $graph_font; // TTF file name
 	protected $graph_font_size_tick_mark = 10; // Tick mark size
 	protected $graph_font_size_key = 9; // Size of height for keys
-	protected $graph_font_size_heading = 18; // Font size of headings
-	protected $graph_font_size_bars = 12; // Font size for text on the bars/objects
-	protected $graph_font_size_identifiers = 11; // Font size of identifiers
-	protected $graph_font_size_sub_heading = 12; // Font size of headers
-	protected $graph_font_size_axis_heading = 11; // Font size of axis headers
-	protected $graph_watermark_text = "PHORONIX-TEST-SUITE.COM"; // Text for watermark in upper right hand corner. If null, no watermark will display
-	protected $graph_watermark_url = "http://www.phoronix-test-suite.com/";
-	protected $graph_version = "";
-	protected $graph_proportion = "";
+	protected $graph_font_size_heading; // Font size of headings
+	protected $graph_font_size_bars; // Font size for text on the bars/objects
+	protected $graph_font_size_identifiers; // Font size of identifiers
+	protected $graph_font_size_sub_heading ; // Font size of headers
+	protected $graph_font_size_axis_heading; // Font size of axis headers
+	protected $graph_watermark_text; // Text for watermark in upper right hand corner. If null, no watermark will display
+	protected $graph_watermark_url;
+	protected $graph_version = null;
+	protected $graph_proportion = null;
 
 	// Not user-friendly changes below this line
 	protected $graph_body_image = false;
@@ -92,14 +90,57 @@ abstract class pts_Graph
 	// Internal Switches, Etc
 
 	protected $regression_marker_threshold = 0;
+	protected $is_multi_way_comparison = false;
 	private $test_identifier = null;
 
-	public function __construct(&$result_object)
+	public function __construct(&$result_object = null, &$result_file = null)
 	{
-		$this->graph_title = $result_object->get_name_formatted();
-		$this->graph_y_title = $result_object->get_scale_formatted();
-		$this->test_identifier = $result_object->get_test_name();
-		$this->addSubTitle($result_object->get_attributes());
+		// Setup config values
+		//if(PTS_MODE == "CLIENT" || (defined("PTS_LIB_GRAPH_CONFIG_XML") && is_file(PTS_LIB_GRAPH_CONFIG_XML)))
+		$graph_config = new pts_graph_config_tandem_XmlReader();
+
+		$this->graph_attr_width = $this->read_graph_config($graph_config, P_GRAPH_SIZE_WIDTH); // Graph width
+		$this->graph_attr_height = $this->read_graph_config($graph_config, P_GRAPH_SIZE_HEIGHT); // Graph height
+		$this->graph_attr_big_border = $this->read_graph_config($graph_config, P_GRAPH_BORDER) == "TRUE"; // Graph border
+
+		// Colors
+		$this->graph_color_notches = $this->read_graph_config($graph_config, P_GRAPH_COLOR_NOTCHES); // Color for notches
+		$this->graph_color_text = $this->read_graph_config($graph_config, P_GRAPH_COLOR_TEXT); // Color for text
+		$this->graph_color_border = $this->read_graph_config($graph_config, P_GRAPH_COLOR_BORDER); // Color for border (if used)
+		$this->graph_color_main_headers = $this->read_graph_config($graph_config, P_GRAPH_COLOR_MAINHEADERS); // Color of main text headers
+		$this->graph_color_headers = $this->read_graph_config($graph_config, P_GRAPH_COLOR_HEADERS); // Color of other headers
+		$this->graph_color_background = $this->read_graph_config($graph_config, P_GRAPH_COLOR_BACKGROUND); // Color of background
+		$this->graph_color_body = $this->read_graph_config($graph_config, P_GRAPH_COLOR_BODY); // Color of graph body
+		$this->graph_color_body_text = $this->read_graph_config($graph_config, P_GRAPH_COLOR_BODYTEXT); // Color of graph body text
+		$this->graph_color_body_light = $this->read_graph_config($graph_config, P_GRAPH_COLOR_ALTERNATE); // Color of the border around graph bars (if doing a bar graph)
+		$this->graph_color_alert = $this->read_graph_config($graph_config, P_GRAPH_COLOR_ALERT); // Color for alerts
+		$this->graph_color_paint = pts_strings::comma_explode($this->read_graph_config($graph_config, P_GRAPH_COLOR_PAINT)); // Colors to use for the bars / lines, one color for each key
+
+		// Text
+		$this->graph_watermark_text = $this->read_graph_config($graph_config, P_GRAPH_WATERMARK); // watermark
+		$this->graph_watermark_url = $this->read_graph_config($graph_config, P_GRAPH_WATERMARK_URL); // watermark URL
+		//$this->graph_font = $this->read_graph_config($graph_config, P_GRAPH_FONT_TYPE);  // TTF file name
+		$this->graph_font_size_heading = $this->read_graph_config($graph_config, P_GRAPH_FONT_SIZE_HEADERS); // Font size of headings
+		$this->graph_font_size_bars = $this->read_graph_config($graph_config, P_GRAPH_FONT_SIZE_TEXT); // Font size for text on the bars/objects
+		$this->graph_font_size_identifiers = $this->read_graph_config($graph_config, P_GRAPH_FONT_SIZE_IDENTIFIERS); // Font size of identifiers
+		$this->graph_font_size_sub_heading = $this->read_graph_config($graph_config, P_GRAPH_FONT_SIZE_SUBHEADERS); // Font size of headers
+		$this->graph_font_size_axis_heading = $this->read_graph_config($graph_config, P_GRAPH_FONT_SIZE_AXIS); // Font size of axis headers
+
+		$this->graph_attr_marks = $this->read_graph_config($graph_config, P_GRAPH_MARKCOUNT); // Number of marks to make on vertical axis
+		$this->graph_renderer = $this->read_graph_config($graph_config, P_GRAPH_RENDERER); // Renderer
+
+		// Reset of setup besides config
+		if($result_object != null)
+		{
+			$test_version = $result_object->test_profile->get_version();
+			$this->graph_title = $result_object->test_profile->get_title() . (isset($test_version[2]) ? " v" . $test_version : null);
+
+			$this->graph_y_title = $result_object->test_profile->get_result_scale_formatted();
+			$this->test_identifier = $result_object->test_profile->get_identifier();
+			$this->graph_proportion = $result_object->test_profile->get_result_proportion();
+			$this->addSubTitle($result_object->get_arguments_description());
+			$this->addInternalIdentifier("Test", $result_object->test_profile->get_identifier());
+		}
 
 		$this->update_graph_dimensions(-1, -1, true);
 
@@ -122,8 +163,33 @@ abstract class pts_Graph
 			}
 		}
 
+		if($result_file != null && $result_file instanceOf pts_result_file)
+		{
+			$this->is_multi_way_comparison = $result_file->is_multi_way_comparison() && $this->graph_type == "BAR_GRAPH";
+			$this->addInternalIdentifier("Identifier", $result_file->get_suite_name());
+
+			$pts_version = pts_arrays::last_element($result_file->get_system_pts_version());
+			if(empty($pts_version))
+			{
+				$pts_version = PTS_VERSION;
+			}
+
+			$this->graph_version = "Phoronix Test Suite " . $pts_version;
+		}
+
 		$this->graph_font = $font_type;
 	}
+	public function read_graph_config(&$graph_config, $xml_path)
+	{
+		static $config_store = null;
+
+		if(!isset($config_store[$xml_path]))
+		{
+			$config_store[$xml_path] = $graph_config->getXmlValue($xml_path);
+		}
+
+		return $config_store[$xml_path];
+	}
 	public function requestRenderer($renderer)
 	{
 		$this->graph_renderer = $renderer;
@@ -145,14 +211,6 @@ abstract class pts_Graph
 	{
 		$this->graph_hide_identifiers = true;
 	}
-	public function loadGraphVersion($data)
-	{
-		$this->graph_version = $data;
-	}
-	public function loadGraphProportion($data)
-	{
-		$this->graph_proportion = $data;
-	}
 	public function loadGraphData($data_array)
 	{
 		loadGraphValues($data_array);
@@ -163,7 +221,7 @@ abstract class pts_Graph
 		{
 			if(is_float($data_item))
 			{
-				$data_item = $this->trim_double($data_item, 2);
+				$data_item = round($data_item, 2);
 			}
 		}
 
@@ -189,7 +247,7 @@ abstract class pts_Graph
 	}
 	public function addSubTitle($sub_title)
 	{
-		$sub_titles = array_map("trim", explode("|", $sub_title));
+		$sub_titles = array_map("trim", explode('|', $sub_title));
 
 		foreach($sub_titles as $sub_title)
 		{
@@ -249,6 +307,72 @@ abstract class pts_Graph
 
 		return $this->graph_color_paint[$this->graph_color_paint_index];
 	}
+	protected function shade_color($hex_color)
+	{
+		$stepping = 54;
+		$hex[] = hexdec(substr($hex_color, 1, 2));
+		$hex[] = hexdec(substr($hex_color, 3, 2));
+		$hex[] = hexdec(substr($hex_color, 5, 2));
+
+		foreach($hex as &$component)
+		{
+			if($component == 0)
+			{
+				continue;
+			}
+
+			if($component < $stepping)
+			{
+				$component = 255;
+			}
+
+			$component -= $stepping;
+		}
+		return '#' . str_pad(dechex($hex[0]), 2, 0) . str_pad(dechex($hex[1]), 2, 0) . str_pad(dechex($hex[2]), 2, 0);
+	}
+	protected function get_paint_color($identifier = 0)
+	{
+		static $used_paint_colors;
+
+		if(!isset($used_paint_colors[$identifier]))
+		{
+			if(PTS_MODE == "CLIENT" && pts_client::read_env("GRAPH_GROUP_SIMILAR"))
+			{
+				static $groups;
+
+				$group = trim(pts_arrays::last_element(pts_strings::colon_explode($identifier)));
+
+				if(!isset($groups[$group]))
+				{
+					$groups[$group] = $this->next_paint_color();
+				}
+				else
+				{
+					$color = $this->graph_image->convert_type_to_hex($groups[$group]);
+					$color = $this->shade_color($color);
+					$groups[$group] = $this->graph_image->convert_hex_to_type($color);
+				}
+
+				$used_paint_colors[$identifier] = $groups[$group];
+			}
+			else
+			{
+				// Use a counter to prevent possible infinite loop when running out of unique paint colors
+				$i = 0;
+
+				do
+				{
+					$i++;
+					$next_color = $this->next_paint_color();
+				}
+				while(is_array($used_paint_colors) && in_array($next_color, $used_paint_colors) == true && $i < 10);
+
+				$used_paint_colors[$identifier] = $next_color;
+			}
+		}
+
+		return $used_paint_colors[$identifier];
+	}
 	protected function reset_paint_index()
 	{
 		$this->graph_color_paint_index = -1;
@@ -257,31 +381,30 @@ abstract class pts_Graph
 	{
 		$real_maximum = 0;
 
-		foreach($this->graph_data as $graph_set)
+		foreach($this->graph_data as &$data_r)
 		{
-			foreach($graph_set as $set_item)
+			$data_max = max($data_r);
+
+			if(!is_numeric($data_max))
 			{
-				if((is_numeric($set_item) && $set_item > $real_maximum) || (!is_numeric($set_item) && strlen($set_item) > strlen($real_maximum)))
-				{
-					$real_maximum = $set_item;
-				}
+				$data_max = str_repeat(9, strlen($data_max));
+			}
+
+			if($data_max > $real_maximum)
+			{
+				$real_maximum = $data_max;
 			}
 		}
 
 		if(is_numeric($real_maximum))
 		{
-			// disable forcing 100 top when display Percent
-			if(false && $real_maximum <= 100 && $this->graph_y_title == "Percent")
-			{
-				$maximum = (ceil(100 / $this->graph_attr_marks) + 1) * $this->graph_attr_marks;
-			}
-			else if($real_maximum < $this->graph_attr_marks)
+			if($real_maximum < $this->graph_attr_marks)
 			{
 				$maximum = $real_maximum * 1.35;
 			}
 			else
 			{
-				$maximum = (floor(round($real_maximum * 1.35) / $this->graph_attr_marks) + 1) * $this->graph_attr_marks;
+				$maximum = (floor(round($real_maximum * 1.24) / $this->graph_attr_marks) + 1) * $this->graph_attr_marks;
 
 				if($real_maximum > 100)
 				{
@@ -314,7 +437,7 @@ abstract class pts_Graph
 	}
 	protected function find_longest_string($string_r)
 	{
-		$longest_string = "";
+		$longest_string = null;
 		$longest_string_length = 0;
 
 		if(!is_array($string_r))
@@ -372,35 +495,44 @@ abstract class pts_Graph
 			$this->graph_top_end += $this->graph_top_end_opp / 2;
 		}
 
+		if(($key_count = count($this->graph_data_title)) > 8)
+		{
+			$this->update_graph_dimensions(-1, $this->graph_attr_height + (floor(($key_count - 8) / 4) * 14), true);
+		}
+
 		// Do the actual work
 		$this->render_graph_pre_init();
 		$this->render_graph_init();
-		$this->render_graph_base();
+		$this->render_graph_key();
+		$this->render_graph_base($this->graph_left_start, $this->graph_top_start, $this->graph_left_end, $this->graph_top_end);
 		$this->render_graph_heading();
 
-		if(!$this->graph_hide_identifiers)
+		if($this->graph_hide_identifiers == false)
 		{
 			$this->render_graph_identifiers();
 		}
 
 		if($this->graph_value_type == "NUMERICAL")
 		{
-			$this->render_graph_value_ticks();
+			$this->render_graph_value_ticks($this->graph_left_start, $this->graph_top_start, $this->graph_left_end, $this->graph_top_end);
 		}
 
-		$this->render_graph_key();
 		$this->render_graph_result();
-		$this->render_graph_watermark();
 		return $this->return_graph_image();
 	}
 	protected function render_graph_pre_init()
 	{
 		return;
 	}
-	protected function render_graph_init()
+	protected function render_graph_init($bilde_attributes = null)
 	{
+		if(defined("PHOROMATIC_TRACKER"))
+		{
+			$bilde_attributes["cache_font_size"] = true;
+		}
+
 		$this->update_graph_dimensions();
-		$this->graph_image = bilde_renderer::setup_renderer($this->graph_renderer, $this->graph_attr_width, $this->graph_attr_height, $this->graph_internal_identifiers);
+		$this->graph_image = bilde_renderer::setup_renderer($this->graph_renderer, $this->graph_attr_width, $this->graph_attr_height, $this->graph_internal_identifiers, $bilde_attributes);
 		$this->requestRenderer($this->graph_image->get_renderer());
 
 		// Initalize Colors
@@ -429,6 +561,11 @@ abstract class pts_Graph
 		{
 			$this->graph_image->draw_rectangle(0, 0, $this->graph_attr_width, $this->graph_attr_height, $this->graph_color_background);
 		}
+
+		if(($sub_title_count = count($this->graph_sub_titles)) > 1)
+		{
+			$this->graph_top_start += (($sub_title_count - 1) * ($this->graph_font_size_sub_heading + 4));
+		}
 	}
 	protected function render_graph_heading($with_version = true)
 	{
@@ -437,31 +574,21 @@ abstract class pts_Graph
 
 		foreach($this->graph_sub_titles as $i => $sub_title)
 		{
-			$this->graph_image->write_text_center($sub_title, $this->graph_font, $this->graph_font_size_sub_heading, $this->graph_color_main_headers, $this->graph_left_start, (31 + ($i * 18)), $this->graph_left_end, (31 + ($i * 18)), false, true);
+			$this->graph_image->write_text_center($sub_title, $this->graph_font, $this->graph_font_size_sub_heading, $this->graph_color_main_headers, $this->graph_left_start, (31 + ($i * 18)), $this->graph_left_end, (31 + ($i * 18)), false);
 		}
 
 		if($with_version)
 		{
-			$this->graph_image->write_text_right($this->graph_version, $this->graph_font, 7, $this->graph_color_body_light, $this->graph_left_end, $this->graph_top_start - 9, $this->graph_left_end, $this->graph_top_start - 9);
+			$this->graph_image->write_text_right($this->graph_version, $this->graph_font, 7, $this->graph_color_body_light, $this->graph_left_end, $this->graph_top_start - 9, $this->graph_left_end, $this->graph_top_start - 9, false, "http://www.phoronix-test-suite.com/");
 		}
 	}
-	protected function render_graph_base()
+	protected function render_graph_base($left_start, $top_start, $left_end, $top_end)
 	{
-		if(count($this->graph_data_title) > 1 || $this->graph_show_key)
-		{
-			$this->graph_top_start += 8 + (ceil(count($this->graph_data_title) / 4) * 12);
-		}
-
-		if(($sub_title_count = count($this->graph_sub_titles)) > 1)
-		{
-			$this->graph_top_start += (($sub_title_count - 1) * 14);
-		}
-
-		$this->graph_image->draw_rectangle_with_border($this->graph_left_start, $this->graph_top_start, $this->graph_left_end, $this->graph_top_end, $this->graph_color_body, $this->graph_color_notches);
+		$this->graph_image->draw_rectangle_with_border($left_start, $top_start, $left_end, $top_end, $this->graph_color_body, $this->graph_color_notches);
 
 		if($this->graph_body_image != false)
 		{
-			$this->graph_image->image_copy_merge($this->graph_body_image, $this->graph_left_start + (($this->graph_left_end - $this->graph_left_start) / 2) - imagesx($this->graph_body_image) / 2, $this->graph_top_start + (($this->graph_top_end - $this->graph_top_start) / 2) - imagesy($this->graph_body_image) / 2);
+			$this->graph_image->image_copy_merge($this->graph_body_image, $left_start + (($left_end - $left_start) / 2) - imagesx($this->graph_body_image) / 2, $top_start + (($top_end - $top_start) / 2) - imagesy($this->graph_body_image) / 2);
 		}
 
 		if(!empty($this->graph_y_title) && !$this->graph_y_title_hide)
@@ -478,12 +605,12 @@ abstract class pts_Graph
 					case "LIB":
 						$proportion = "Fewer Are Better";
 						$offset += 12;
-						$this->graph_image->draw_arrow($this->graph_left_start + 5, $this->graph_top_start - 4, $this->graph_left_start + 5, $this->graph_top_start - 11, $this->graph_color_main_headers, $this->graph_color_body_light, 1);
+						$this->graph_image->draw_arrow($left_start + 5, $top_start - 4, $left_start + 5, $top_start - 11, $this->graph_color_main_headers, $this->graph_color_body_light, 1);
 						break;
 					case "HIB":
 						//$proportion = "Higher Is Better";
 						$offset += 12;
-						$this->graph_image->draw_arrow($this->graph_left_start + 5, $this->graph_top_start - 11, $this->graph_left_start + 5, $this->graph_top_start - 4, $this->graph_color_main_headers, $this->graph_color_body_light, 1);
+						$this->graph_image->draw_arrow($left_start + 5, $top_start - 11, $left_start + 5, $top_start - 4, $this->graph_color_main_headers, $this->graph_color_body_light, 1);
 						break;
 				}
 
@@ -498,22 +625,31 @@ abstract class pts_Graph
 				}
 			}
 
-			$this->graph_image->write_text_left($str, $this->graph_font, 7, $this->graph_color_main_headers, $this->graph_left_start + $offset, $this->graph_top_start - 7, $this->graph_left_start + $offset, $this->graph_top_start - 7);
+			$this->graph_image->write_text_left($str, $this->graph_font, 7, $this->graph_color_main_headers, $left_start + $offset, $top_start - 7, $left_start + $offset, $top_start - 7);
+		}
+
+		
+
+		if(!empty($this->graph_watermark_text))
+		{
+			$this->graph_image->write_text_right($this->graph_watermark_text, $this->graph_font, 10, $this->graph_color_text, $left_end - 2, $top_start + 8, $left_end - 2, $top_start + 8, false, $this->graph_watermark_url);
 		}
 	}
-	protected function render_graph_value_ticks()
+	protected function render_graph_value_ticks($left_start, $top_start, $left_end, $top_end)
 	{
-		$tick_width = ($this->graph_top_end - $this->graph_top_start) / $this->graph_attr_marks;
-		$px_from_left_start = $this->graph_left_start - 5;
-		$px_from_left_end = $this->graph_left_start + 5;
+		$tick_width = ($top_end - $top_start) / $this->graph_attr_marks;
+		$px_from_left_start = $left_start - 5;
+		$px_from_left_end = $left_start + 5;
 
 		$display_value = 0;
 
+		$this->graph_image->draw_dashed_line($left_start, $top_start + $tick_width, $left_start, ($top_end - 1), $this->graph_color_notches, 10, 1, $tick_width);
+
 		for($i = 0; $i < $this->graph_attr_marks; $i++)
 		{
-			$px_from_top = $this->graph_top_end - ($tick_width * $i);
+			$px_from_top = $top_end - ($tick_width * $i);
 
-			$this->graph_image->draw_line($px_from_left_start, $px_from_top, $px_from_left_end, $px_from_top, $this->graph_color_notches);
+			//$this->graph_image->draw_line($px_from_left_start, $px_from_top, $px_from_left_end, $px_from_top, $this->graph_color_notches);
 
 			if($display_value != 0)
 			{
@@ -523,10 +659,10 @@ abstract class pts_Graph
 			if($i != 0 && $this->graph_background_lines)
 			{
 				$line_width = 6;
-				$this->graph_image->draw_dashed_line($px_from_left_end + 6, $px_from_top, $this->graph_left_end, $px_from_top, $this->graph_color_body_light, 1, 8, 9);
+				$this->graph_image->draw_dashed_line($px_from_left_end + 6, $px_from_top, $this->graph_left_end - 6, $px_from_top, $this->graph_color_body_light, 1, 20, 15);
 			}
 
-			$display_value += $this->trim_double($this->graph_maximum_value / $this->graph_attr_marks, 2);
+			$display_value += round($this->graph_maximum_value / $this->graph_attr_marks, 2);
 		}
 	}
 	protected function render_graph_identifiers()
@@ -544,37 +680,48 @@ abstract class pts_Graph
 			return;
 		}
 
-		$key_counter = 0;
-		$component_y = $this->graph_top_start - 19;
+		$key_count = count($this->graph_data_title);
+		$key_pos = 0;
+		$key_item_width = 18 + $this->text_string_width($this->find_longest_string($this->graph_data_title), $this->graph_font, $this->graph_font_size_key);
+		$keys_per_line = floor(($this->graph_left_end - $this->graph_left_start - 14) / $key_item_width);
+		$key_line_height = 14;
+		$this->graph_top_start += 12;
+		$component_y = $this->graph_top_start - $key_line_height - 5;
 		$this->reset_paint_index();
 
-		for($i = 0; $i < count($this->graph_data_title); $i++)
+		for($i = 0; $i < $key_count; $i++)
 		{
 			if(!empty($this->graph_data_title[$i]))
 			{
-				$this_color = $this->next_paint_color();
-				$key_counter += 1;
+				$this_color = $this->get_paint_color($this->graph_data_title[$i]);
+				$key_pos++;
 
-				$component_x = $this->graph_left_start + 14 + (($this->graph_left_end - $this->graph_left_start) / 4) * (($key_counter - 1) % 4);
+				if($i != 0 && $key_pos % $keys_per_line == 1)
+				{
+					$key_pos = 1;
+					$component_y += $key_line_height;
+					$this->graph_top_start += $key_line_height;
+				}
+				else if($this->is_multi_way_comparison)
+				{
+					$this_key_way = substr($this->graph_data_title[$i], 0, strpos($this->graph_data_title[$i], ": "));
 
-				$this->graph_image->write_text_left($this->graph_data_title[$i], $this->graph_font, $this->graph_font_size_key, $this_color, $component_x, $component_y, $component_x, $component_y);
+					if($i != 0 && $this_key_way != $prev_key_way)
+					{
+						$key_pos = 1;
+						$component_y += $key_line_height;
+						$this->graph_top_start += $key_line_height;
+					}
+
+					$prev_key_way = $this_key_way;
+				}
+
+				$component_x = $this->graph_left_start + 13 + ($key_item_width * ($key_pos - 1 % $keys_per_line));
 
 				$this->graph_image->draw_rectangle_with_border($component_x - 13, $component_y - 5, $component_x - 3, $component_y + 5, $this_color, $this->graph_color_notches);
-
-				if($key_counter % 4 == 0)
-				{
-					$component_y -= 14;
-				}
+				$this->graph_image->write_text_left($this->graph_data_title[$i], $this->graph_font, $this->graph_font_size_key, $this_color, $component_x, $component_y, $component_x, $component_y);
 			}
 		}
-		$this->reset_paint_index();
-	}
-	protected function render_graph_watermark()
-	{
-		if(!empty($this->graph_watermark_text))
-		{
-			$this->graph_image->write_text_right($this->graph_watermark_text, $this->graph_font, 10, $this->graph_color_text, $this->graph_left_end - 2, $this->graph_top_start + 8, $this->graph_left_end - 2, $this->graph_top_start + 8, false, $this->graph_watermark_url);
-		}
 	}
 	protected function return_graph_image($quality = 85)
 	{
@@ -583,40 +730,6 @@ abstract class pts_Graph
 
 		return $return_object;
 	}
-	protected function trim_double($double, $accuracy = 2)
-	{
-		// Should be same as pts_trim_double()
-		// Set precision for a variable's points after the decimal spot
-		$return = explode(".", $double);
-
-		if(count($return) == 1)
-		{
-			$return[1] = "00";
-		}
-	
-		if(count($return) == 2 && $accuracy > 0)
-		{
-			$strlen = strlen($return[1]);
-
-			if($strlen > $accuracy)
-			{
-				$return[1] = substr($return[1], 0, $accuracy);
-			}
-			else if($strlen < $accuracy)
-			{
-				$return[1] .= str_repeat('0', ($accuracy - $strlen));
-			}
-
-			$return = $return[0] . "." . $return[1];
-		}
-		else
-		{
-			$return = $return[0];
-		}
-
-		return $return;
-	}
-
 
 	//
 	// Renderer-specific Functions
