@@ -21,11 +21,11 @@
 	along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
 
-class pts_PassFailGraph extends pts_CustomGraph
+class pts_PassFailGraph extends pts_Graph
 {
-	public function __construct(&$result_object)
+	public function __construct(&$result_object, &$result_file = null)
 	{
-		parent::__construct($result_object);
+		parent::__construct($result_object, $result_file);
 		$this->graph_type = "PASS_FAIL";
 		$this->graph_value_type = "ABSTRACT";
 		$this->graph_hide_identifiers = true;
