@@ -21,12 +21,12 @@
 	along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
 
-class pts_TestCountPassGraph extends pts_CustomGraph
+class pts_TestCountPassGraph extends pts_Graph
 {
-	public function __construct(&$result_object)
+	public function __construct(&$result_object, &$result_file = null)
 	{
 		$this->graph_y_title_hide = true;
-		parent::__construct($result_object);
+		parent::__construct($result_object, $result_file);
 		$this->graph_type = "TEST_COUNT_PASS";
 		$this->graph_value_type = "ABSTRACT";
 		$this->graph_hide_identifiers = true;
@@ -58,7 +58,7 @@ class pts_TestCountPassGraph extends pts_CustomGraph
 
 		$identifiers_total_width = $graph_width - $main_width - 2;
 
-		$headings = explode(",", $this->graph_y_title);
+		$headings = pts_strings::comma_explode($this->graph_y_title);
 		$identifiers_width = floor($identifiers_total_width / count($headings));
 		$headings_font_size = $this->graph_font_size_bars;
 		while(($this->text_string_width($this->find_longest_string($headings), $this->graph_font, $headings_font_size) > ($identifiers_width - 2)) || $this->text_string_height($this->graph_maximum_value, $this->graph_font, $headings_font_size) > ($line_height - 4))
@@ -68,7 +68,7 @@ class pts_TestCountPassGraph extends pts_CustomGraph
 
 		for($j = 0; $j < count($this->graph_data[0]); $j++)
 		{
-			$results = array_reverse(explode(",", $this->graph_data[0][$j]));
+			$results = array_reverse(pts_strings::comma_explode($this->graph_data[0][$j]));
 			$line_ttf_height = $this->text_string_height("AZ@![]()@|_", $this->graph_font, $this->graph_font_size_bars);
 			for($i = 0; $i < count($headings) && $i < count($results); $i++)
 			{
