@@ -87,7 +87,7 @@ class pts_module_interface
 
 	public static function __pre_install_process($obj = null)
 	{
-		// Passed is an array of the test identifiers for all tests about to be installed
+		// Passed is the pts_test_install_manager
 		return;
 	}
 	public static function __pre_test_download($obj = null)
@@ -119,7 +119,7 @@ class pts_module_interface
 	}
 	public static function __post_install_process($obj = null)
 	{
-		// Passed is an array of the test identifiers for all tests that were supposed to be just installed
+		// Passed is the pts_test_install_manager
 		return;
 	}
 
@@ -129,7 +129,7 @@ class pts_module_interface
 
 	public static function __pre_run_process($obj = null)
 	{
-		// Passed is the current pts_test_run_manager, where accessible is an array of pts_test_run_request objects for all tests scheduled to run
+		// Passed is the current pts_test_run_manager, where accessible is an array of pts_test_result objects for all tests scheduled to run
 		return;
 	}
 	public static function __pre_test_run($obj = null)
@@ -147,9 +147,14 @@ class pts_module_interface
 		// Passed is a read-only copy of the current pts_test_result for the given test
 		return;
 	}
+	public static function __post_test_run_process($obj = null)
+	{
+		// Passed is a copy of the tandem_xml object
+		return;
+	}
 	public static function __post_run_process($obj = null)
 	{
-		// Passed is the current pts_test_run_manager, where accessible is an array of pts_test_run_request objects for all tests scheduled to run
+		// Passed is the current pts_test_run_manager, where accessible is an array of pts_test_result objects for all tests scheduled to run
 		return;
 	}
 
@@ -169,12 +174,12 @@ class pts_module_interface
 	}
 	public static function __event_results_saved($obj = null)
 	{
-		// Passed is a string of the results identifier that was saved
+		// Passed is a copy of the pts_test_run_manager
 		return;
 	}
 	public static function __event_user_error($obj = null)
 	{
-		// Passed is a read-only copy of the pts_user_error object
+		// TODO use __event_user_error
 		return;
 	}
 
