@@ -28,14 +28,20 @@ class pts_module_option
 	private $option_supported_values;
 	private $option_default_value;
 	private $option_function_check;
+	private $option_setup_check;
 
-	public function __construct($identifier, $question_string, $supported_values = null, $default_value = null, $function_to_check = null)
+	public function __construct($identifier, $question_string, $supported_values = null, $default_value = null, $function_to_check = null, $setup_check = true)
 	{
 		$this->option_identifier = $identifier;
 		$this->option_question = $question_string;
 		$this->option_supported_values = $supported_values;
 		$this->option_default_value = $default_value;
 		$this->option_function_check = $function_to_check;
+		$this->option_setup_check = $setup_check;
+	}
+	public function setup_check_needed()
+	{
+		return $this->option_setup_check;
 	}
 	public function get_identifier()
 	{
@@ -88,13 +94,13 @@ class pts_module_option
 					}
 					break;
 				case "NUMERIC_DASH":
-					if(!empty($input) && strlen(pts_remove_chars($input, true, false, false, true)) == strlen($input))
+					if(!empty($input) && strlen(pts_strings::keep_in_string($identifier, TYPE_CHAR_NUMERIC | TYPE_CHAR_DASH)) == strlen($input))
 					{
 						$supported = true;
 					}
 					break;
 				case "ALPHA_NUMERIC":
-					if(!empty($input) && strlen(pts_remove_chars($input, true, false, true)) == strlen($input))
+					if(!empty($input) && strlen(pts_strings::keep_in_string($identifier, TYPE_CHAR_NUMERIC | TYPE_CHAR_LETTER)) == strlen($input))
 					{
 						$supported = true;
 					}
@@ -111,6 +117,12 @@ class pts_module_option
 						$supported = true;
 					}
 					break;
+				case "LOCAL_FILE":
+					if(is_file($input))
+					{
+						$supported = true;
+					}
+					break;
 				case "LOCAL_EXECUTABLE":
 					if(is_executable($input))
 					{
@@ -122,6 +134,21 @@ class pts_module_option
 					{
 						$supported = true;
 					}
+				case "INSTALLED_TEST_OR_SUITE":
+					if(in_array($input, pts_tests::installed_tests()) || in_array($input, pts_suites::installed_suites()))
+					{
+						$supported = true;
+					}
+				case "INSTALLED_SUITE":
+					if(in_array($input, pts_suites::installed_suites()))
+					{
+						$supported = true;
+					}
+				case "VALID_SAVE_NAME":
+					if(!empty($input) && !pts_is_run_object($input))
+					{
+						$supported = true;
+					}
 				case "NOT_EMPTY":
 					if(!empty($input))
 					{
