@@ -22,8 +22,8 @@
 
 class pts_pdf_template extends FPDF
 {
-	var $pts_title = "";
-	var $pts_sub_title = "";
+	private $pts_title = "";
+	private $pts_sub_title = "";
 
 	function __construct($Title = "", $SubTitle = "")
 	{
@@ -45,9 +45,9 @@ class pts_pdf_template extends FPDF
 			return;
 		}
 
-		if(RESULTS_VIEWER_DIR . "pts-logo.jpg")
+		if(is_file(STATIC_DIR . "images/pts-158x82.jpg"))
 		{
-			$this->Image(RESULTS_VIEWER_DIR . "pts-logo.jpg", 10, 8, 30);
+			$this->Image(STATIC_DIR . "images/pts-158x82.jpg", 10, 8, 30);
 		}
 
 		$this->SetFont("Arial", "B", 14);
@@ -67,7 +67,7 @@ class pts_pdf_template extends FPDF
 
 		$this->SetY(-10);
 		$this->SetFont("Arial", "B", 7);
-		$this->Cell(0, 0, "Phoronix Test Suite v" . PTS_VERSION, 0, 0, "L");
+		$this->Cell(0, 0, pts_title(), 0, 0, "L");
 		$this->Cell(0, 0, "www.phoronix-test-suite.com", 0, 0, "R");
 	}
 	function WriteBigHeaderCenter($Header)
