@@ -22,11 +22,17 @@
 
 class pts_result_file_merge_manager
 {
-	private $test_results;
+	private $test_results = null;
+	private $skip_subsystems = null;
 
-	public function __construct()
+	public function __construct($pass_attributes = null)
 	{
 		$this->test_results = array();
+
+		if(isset($pass_attributes["subsystem_targets_to_skip"]) && is_array($pass_attributes["subsystem_targets_to_skip"]))
+		{
+			$this->skip_subsystems = $pass_attributes["subsystem_targets_to_skip"];
+		}
 	}
 	public function add_test_result_set($merge_test_objects_array, &$result_merge_select)
 	{
@@ -40,15 +46,26 @@ class pts_result_file_merge_manager
 		$select_identifiers = $result_merge_select instanceOf pts_result_merge_select ? $result_merge_select->get_selected_identifiers() : null;
 
 		$merged = false;
-		$mto_test_name = $merge_test_object->get_test_name();
+		$mto_test_name = $merge_test_object->test_profile->get_identifier();
+
+		if($this->skip_subsystems != null)
+		{
+			// Check whether to omit rendering this test if only certain subsystem test types should be merged
+			$test_subsystem = pts_tests::test_hardware_type($mto_test_name);
+
+			if($test_subsystem != null && !in_array($test_subsystem, $this->skip_subsystems))
+			{
+				return false;
+			}
+		}
 
 		if(isset($this->test_results[$mto_test_name]))
 		{
 			foreach($this->test_results[$mto_test_name] as &$mto_compare)
 			{
-				if(trim($mto_compare->get_arguments()) == trim($merge_test_object->get_arguments()) && $mto_compare->get_attributes() == $merge_test_object->get_attributes() && $mto_compare->get_version() == $merge_test_object->get_version() && $mto_compare->get_scale() == $merge_test_object->get_scale())
+				if(trim($mto_compare->get_arguments()) == trim($merge_test_object->get_arguments()) && $mto_compare->get_arguments_description() == $merge_test_object->get_arguments_description() && $mto_compare->test_profile->get_version() == $merge_test_object->test_profile->get_version() && $mto_compare->test_profile->get_result_scale() == $merge_test_object->test_profile->get_result_scale() && pts_strings::version_strings_comparable($mto_compare->test_profile->get_test_profile_version(), $merge_test_object->test_profile->get_test_profile_version()))
 				{
-					foreach($merge_test_object->get_result_buffer()->get_buffer_items() as $buffer_item)
+					foreach($merge_test_object->test_result_buffer->get_buffer_items() as $buffer_item)
 					{
 						$this_identifier = $buffer_item->get_result_identifier();
 
@@ -61,7 +78,7 @@ class pts_result_file_merge_manager
 
 							if(!$this->result_already_contained($mto_compare, $buffer_item))
 							{
-								$mto_compare->add_result_to_buffer($this_identifier, $buffer_item->get_result_value(), $buffer_item->get_result_raw());
+								$mto_compare->test_result_buffer->add_test_result($this_identifier, $buffer_item->get_result_value(), $buffer_item->get_result_raw());
 							}
 						}
 					}
@@ -87,8 +104,8 @@ class pts_result_file_merge_manager
 					$skip_adding = true;
 				}
 
-				$result_buffer = $merge_test_object->get_result_buffer();
-				$merge_test_object->flush_result_buffer();
+				$result_buffer = $merge_test_object->test_result_buffer;
+				$merge_test_object->test_result_buffer = new pts_test_result_buffer();
 
 				foreach($result_buffer->get_buffer_items() as $buffer_item)
 				{
@@ -101,13 +118,13 @@ class pts_result_file_merge_manager
 							$this_identifier = $renamed;
 						}
 
-						$merge_test_object->add_result_to_buffer($this_identifier, $buffer_item->get_result_value(), $buffer_item->get_result_raw());
+						$merge_test_object->test_result_buffer->add_test_result($this_identifier, $buffer_item->get_result_value(), $buffer_item->get_result_raw());
 					}
 				}
 			}
 
 			// Add Result
-			if(!$skip_adding)
+			if($skip_adding == false)
 			{
 				array_push($this->test_results[$mto_test_name], $merge_test_object);
 			}
@@ -117,7 +134,7 @@ class pts_result_file_merge_manager
 	{
 		$contained = false;
 
-		foreach($mto_compare as $check_buffer_item)
+		foreach($mto_compare->test_result_buffer->get_buffer_items() as $check_buffer_item)
 		{
 			if($buffer_item->get_result_identifier() == $check_buffer_item->get_result_identifier() && $buffer_item->get_result_value() == $check_buffer_item->get_result_value())
 			{
@@ -132,7 +149,7 @@ class pts_result_file_merge_manager
 	{
 		$linear_array = array();
 
-		foreach($this->test_results as &$test_name_object_array)
+		foreach($this->test_results as $test_name => &$test_name_object_array)
 		{
 			foreach($test_name_object_array as $merge_object)
 			{
