@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2008 - 2009, Phoronix Media
-	Copyright (C) 2008 - 2009, Michael Larabel
+	Copyright (C) 2008 - 2010, Phoronix Media
+	Copyright (C) 2008 - 2010, Michael Larabel
 	pts_graph_config_tandem_XmlReader.php: The XML reading object for the Phoronix Test Suite for the graph config
 
 	Additional Notes: A very simple XML parser with a few extras... Does not currently support attributes on tags, etc.
@@ -30,6 +30,8 @@ class pts_graph_config_tandem_XmlReader extends tandem_XmlReader
 
 	public function __construct($new_values = null)
 	{
+		pts_loader::load_definitions("graph-config.xml");
+
 		$file = null;
 
 		if(PTS_MODE == "CLIENT")
@@ -56,12 +58,35 @@ class pts_graph_config_tandem_XmlReader extends tandem_XmlReader
 	{
 		if($this->override_values != false && isset($this->override_values[$xml_path]))
 		{
-			return $this->override_values[$xml_path];
+			$value = $this->override_values[$xml_path];
 		}
 		else
 		{
-			return parent::getValue($xml_path, $xml_tag, $xml_match, $is_fallback_call);
+			$value = parent::getValue($xml_path, $xml_tag, $xml_match, $is_fallback_call);
 		}
+
+		return $value;
+	}
+	function handleXmlZeroTagFallback($xml_tag)
+	{
+		static $fallback_reader = null;
+		$fallback_value = false;
+
+		if($fallback_reader != null || is_file(STATIC_DIR . "graph-config-defaults.xml"))
+		{
+			if($fallback_reader == null)
+			{
+				$fallback_reader = new tandem_XmlReader(STATIC_DIR . "graph-config-defaults.xml");
+			}
+
+			$fallback_value = $fallback_reader->getXMLValue($xml_tag);
+		}
+		else if(PTS_MODE == "CLIENT")
+		{
+			echo "\nUndefined Graph Config Option: $xml_tag\n";
+		}
+
+		return $fallback_value;
 	}
 }
 ?>
