@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2008 - 2009, Phoronix Media
-	Copyright (C) 2008 - 2009, Michael Larabel
+	Copyright (C) 2008 - 2010, Phoronix Media
+	Copyright (C) 2008 - 2010, Michael Larabel
 	pts_results_tandem_XmlReader.php: The XML reading object for the Phoronix Test Suite for test results
 
 	Additional Notes: A very simple XML parser with a few extras... Does not currently support attributes on tags, etc.
@@ -28,12 +28,19 @@ class pts_results_tandem_XmlReader extends tandem_XmlReader
 {
 	public function __construct($read_xml)
 	{
-		if(!pts_is_file($read_xml) && defined("SAVE_RESULTS_DIR") && is_file(SAVE_RESULTS_DIR . $read_xml . "/composite.xml"))
+		pts_loader::load_definitions("result-file.xml");
+
+		if(!$this->pts_is_file($read_xml) && defined("SAVE_RESULTS_DIR") && is_file(SAVE_RESULTS_DIR . $read_xml . "/composite.xml"))
 		{
 			$read_xml = SAVE_RESULTS_DIR . $read_xml . "/composite.xml";
 		}
 
 		parent::__construct($read_xml);
 	}
+	private function pts_is_file(&$file_check)
+	{
+		// $file_check could contain the XML markup already, so first check for < as the start of an open tag from say <?xml version
+		return !isset($file_check[1024]) && substr($file_check, 0, 1) != "<" && is_file($file_check);
+	}
 }
 ?>
