@@ -4,7 +4,7 @@
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
 	Copyright (C) 2008 - 2010, Phoronix Media
-	Copyright (C) 2004 - 2010, Michael Larabel
+	Copyright (C) 2008 - 2010, Michael Larabel
 	pts_test_tandem_XmlReader.php: The XML reading object for the Phoronix Test Suite with optimizations for handling test profiles
 
 	Additional Notes: A very simple XML parser with a few extras... Does not currently support attributes on tags, etc.
@@ -30,9 +30,11 @@ class pts_test_tandem_XmlReader extends tandem_XmlReader
 
 	public function __construct($read_xml)
 	{
-		if(function_exists("pts_location_test") && (!is_file($read_xml) || substr($read_xml, -3) != "xml"))
+		pts_loader::load_definitions("test-profile.xml");
+
+		if(!is_file($read_xml) || substr($read_xml, -3) != "xml")
 		{
-			$read_xml = pts_location_test($read_xml);
+			$read_xml = pts_tests::test_profile_location($read_xml);
 		}
 
 		$this->override_values = array();
@@ -45,6 +47,10 @@ class pts_test_tandem_XmlReader extends tandem_XmlReader
 			$this->overrideXMLValue($xml_tag, $value);
 		}
 	}
+	public function getOverrideValues()
+	{
+		return $this->override_values;
+	}
 	public function overrideXMLValue($xml_tag, $value)
 	{
 		$this->override_values[$xml_tag] = $value;
@@ -73,7 +79,7 @@ class pts_test_tandem_XmlReader extends tandem_XmlReader
 
 		$test_extends = $this->getValue(P_TEST_CTPEXTENDS, null, null, true);
 
-		if(!empty($test_extends) && pts_is_test($test_extends))
+		if(!empty($test_extends)) // For now drop && pts_is_test($test_extends)
 		{
 			$test_below_parser = new pts_test_tandem_XmlReader($test_extends);
 			$test_below_tag = $test_below_parser->getXMLValue($xml_tag);
