@@ -24,8 +24,8 @@ class default_benchmark implements pts_option_interface
 {
 	public static function run($r)
 	{
-		pts_run_option_next("install_test", $r, array("IS_DEFAULTS_MODE" => true, "SILENCE_MESSAGES" => true));
-		pts_run_option_next("run_test", $r, array("IS_DEFAULTS_MODE" => true));
+		pts_client::run_next("install_test", $r, array("IS_DEFAULTS_MODE" => true));
+		pts_client::run_next("run_test", $r, array("IS_DEFAULTS_MODE" => true));
 	}
 }
 
