@@ -24,23 +24,23 @@ class diagnostics implements pts_option_interface
 {
 	public static function run($r)
 	{
-		echo pts_string_header(pts_title() . "\n" . "Diagnostics Output");
 		$pts_defined_constants = get_defined_constants(true);
+		$show_all_constants = isset($r[0]) && $r[0] == "full";
 		foreach($pts_defined_constants["user"] as $constant => $constant_value)
 		{
-			if($r[0] == "full" || (!in_array(substr($constant, 0, 2), array("P_", "S_")) && substr($constant, 0, 3) != "IS_" && substr($constant, 0, 5) != "TYPE_"))
+			if($show_all_constants || (!in_array(substr($constant, 0, 2), array("P_", "S_")) && substr($constant, 0, 3) != "IS_" && substr($constant, 0, 5) != "TYPE_"))
 			{
 				echo $constant . " = " . $constant_value . "\n";
 			}
 		}
 
-		echo "\nEnd-User Run-Time Variables:\n";
-		foreach(pts_user_runtime_variables() as $var => $var_value)
+		echo "\nVariables That Can Be Used As Result Identifiers / File Names:\n";
+		foreach(pts_client::user_run_save_variables() as $var => $var_value)
 		{
 			echo $var . " = " . $var_value . "\n";
 		}
 		echo "\nEnvironmental Variables (accessible via test scripts):\n";
-		foreach(pts_env_variables() as $var => $var_value)
+		foreach(pts_client::environmental_variables() as $var => $var_value)
 		{
 			echo $var . " = " . $var_value . "\n";
 		}
