@@ -24,7 +24,7 @@ class gui_gtk implements pts_option_interface
 {
 	public static function required_function_sets()
 	{
-		return array("gui", "run", "gtk", "install", "install_dependencies", "comparisons", "unit_caching");
+		return array("gui", "run", "gtk");
 	}
 	public static function run($r)
 	{
@@ -32,9 +32,9 @@ class gui_gtk implements pts_option_interface
 		{
 			echo "\nThe PHP GTK module must be loaded for the GUI.\nThis module can be found @ http://gtk.php.net/\n\n";
 
-			if(getenv("TERM") == null && getenv("DISPLAY") != null)
+			if(pts_client::read_env("TERM") == null && pts_client::read_env("DISPLAY") != null)
 			{
-				pts_display_web_browser(STATIC_DIR . "error-gui.html", null, true, true);
+				pts_client::display_web_page(STATIC_DIR . "error-gui.html", null, true, true);
 			}
 
 			return false;
@@ -82,21 +82,21 @@ class gui_gtk implements pts_option_interface
 		}
 
 		$startup_tasks = array(
-		array("pts_cache_hardware_calls", "Building Hardware Information"),
-		array("pts_cache_software_calls", "Building Software Information"),
-		array("pts_cache_suite_calls", "Caching Suite Information"),
-		array("pts_cache_test_calls", "Caching Test Information"),
-		array("pts_download_all_generic_reference_system_comparison_results", "Downloading Reference Comparison Results"),
-		array("pts_generic_reference_system_build_cache", "Building Reference Comparison Cache")
+		array("Building Hardware Information", array("pts_client", "cache_hardware_calls")),
+		array("Building Software Information", array("pts_client", "cache_software_calls")),
+		array("Caching Suite Information", array("pts_client", "cache_suite_calls")),
+		array("Caching Test Information", array("pts_client", "cache_test_calls")),
+		array("Downloading Reference Comparison Results", array("pts_client", "cache_generic_reference_systems_results")),
+		array("Building Reference Comparison Cache", array("pts_client", "cache_generic_reference_systems"))
 		);
 
 		$progress_window = new pts_gtk_simple_progress_window();
 
 		$tasks_completed = 0;
 		$task_count = count($startup_tasks);
-		foreach($startup_tasks as $function => $task)
+		foreach($startup_tasks as &$task)
 		{
-			list($task_call, $task_string) = $task;
+			list($task_string, $task_call) = $task;
 			$progress_window->update_progress_bar(($tasks_completed / $task_count) * 100, $task_string);
 			call_user_func($task_call);
 			$tasks_completed++;
@@ -105,7 +105,7 @@ class gui_gtk implements pts_option_interface
 
 		$progress_window->completed();
 
-		pts_attach_module("gui_gtk_events");
+		pts_module_manager::attach_module("gui_gtk_events");
 	}
 	public static function system_tray_activate()
 	{
@@ -174,13 +174,13 @@ class gui_gtk implements pts_option_interface
 		array_push($file_menu, new pts_gtk_menu_item("Quit", array("gui_gtk", "kill_gtk_window"), "STRING", Gtk::STOCK_QUIT));
 
 		$license_type = array();
-		foreach(pts_license_test_types() as $license)
+		foreach(pts_types::software_license_types() as $license)
 		{
 			array_push($license_type, new pts_gtk_menu_item($license, array("gui_gtk", "check_test_license_select"), "CHECK_BUTTON", null, true));
 		}
 
 		$subsystem_type = array();
-		foreach(pts_subsystem_test_types() as $subsystem)
+		foreach(pts_types::subsystem_targets() as $subsystem)
 		{
 			array_push($subsystem_type, new pts_gtk_menu_item($subsystem, array("gui_gtk", "check_test_type_select"), "CHECK_BUTTON", null, true));
 		}
@@ -189,12 +189,12 @@ class gui_gtk implements pts_option_interface
 			new pts_gtk_menu_item("System _Information", array("gui_gtk", "show_system_info_interface")),
 			new pts_gtk_menu_item("Software _Dependencies", array("gui_gtk", "show_dependency_info_interface")),
 			null,
-			new pts_gtk_menu_item(array("Tests", "Suites"), array("gui_gtk", "radio_test_suite_select"), "RADIO_BUTTON", null, pts_read_user_config(P_OPTION_UI_SELECT_SUITESORTESTS)),
+			new pts_gtk_menu_item(array("Tests", "Suites"), array("gui_gtk", "radio_test_suite_select"), "RADIO_BUTTON", null, pts_config::read_user_config(P_OPTION_UI_SELECT_SUITESORTESTS)),
 			null,
 			"License" => $license_type,
 			"Subsystem" => $subsystem_type,
-			"Dependencies" => array(new pts_gtk_menu_item(array("Show All", "All Dependencies Installed", "Dependencies Missing"), array("gui_gtk", "radio_test_dependencies_select"), "RADIO_BUTTON", null, pts_read_user_config(P_OPTION_UI_SELECT_DEPENDENCIES))),
-			"File Downloads" => array(new pts_gtk_menu_item(array("Show All", "All Files Available Locally", "Files Need To Be Downloaded"), array("gui_gtk", "radio_test_downloads_select"), "RADIO_BUTTON", null, pts_read_user_config(P_OPTION_UI_SELECT_DOWNLOADS)))
+			"Dependencies" => array(new pts_gtk_menu_item(array("Show All", "All Dependencies Installed", "Dependencies Missing"), array("gui_gtk", "radio_test_dependencies_select"), "RADIO_BUTTON", null, pts_config::read_user_config(P_OPTION_UI_SELECT_DEPENDENCIES))),
+			"File Downloads" => array(new pts_gtk_menu_item(array("Show All", "All Files Available Locally", "Files Need To Be Downloaded"), array("gui_gtk", "radio_test_downloads_select"), "RADIO_BUTTON", null, pts_config::read_user_config(P_OPTION_UI_SELECT_DOWNLOADS)))
 			);
 
 		$main_menu_items = array(
@@ -249,7 +249,7 @@ class gui_gtk implements pts_option_interface
 		$reference_comparison_objects = array();
 		if(($prev_identifier = pts_read_assignment("PREV_SAVE_RESULTS_IDENTIFIER")))
 		{
-			$reference_tests = pts_result_file_reference_tests($prev_identifier);
+			$reference_tests = pts_result_comparisons::reference_tests_for_result($prev_identifier);
 			if(count($reference_tests) > 0)
 			{
 				$objs = gui_gtk::pts_gtk_reference_system_comparison_objects($prev_identifier, $reference_tests, $reference_comparison_objects);
@@ -307,13 +307,14 @@ class gui_gtk implements pts_option_interface
 		// Setup System Tray
 		if(class_exists("GtkStatusIcon"))
 		{
-			gui_gtk::system_tray_monitor();
+			// Using the system tray icon seems to cause PHP5-GTK on Ubuntu Lucid to hang
+			//gui_gtk::system_tray_monitor();
 		}
 
 		pts_set_assignment("GTK_GUI_INIT", false);
 		gui_gtk::update_main_notebook();
 
-		// pts_attach_module("notify_send_events");
+		// pts_module_manager::attach_module("notify_send_events");
 
 		$window->show_all();
 		Gtk::main();
@@ -331,7 +332,8 @@ class gui_gtk implements pts_option_interface
 		}
 		if(($p = pts_read_assignment("PREV_TEST_INSTALLED")))
 		{
-			$button_box->add(new pts_gtk_label("<b>Installed " . pts_test_identifier_to_name($p) . "</b> "));
+			$test_profile = new pts_test_profile($p);
+			$button_box->add(new pts_gtk_label("<b>Installed " . $test_profile->get_title() . "</b> "));
 
 			$ti_button = new GtkButton("Run Test");
 			$ti_button->connect_simple("clicked", array("gui_gtk", "show_run_confirmation_interface"), $p);
@@ -366,34 +368,49 @@ class gui_gtk implements pts_option_interface
 	}
 	public static function drag_drop_item($widget, $context, $x, $y, $data, $info, $time, $img)
 	{
-		$file = str_replace("file://", "", trim($data->data));
+		$file = str_replace("file://", null, trim($data->data));
+		$options = array();
 
-		if(substr($file, -4) == ".svg")
+		if(strpos($file, "global.phoronix-test-suite.com") !== false)
 		{
-			$svg_options = pts_parse_svg_options($file);
-
-			if(count($svg_options) > 0)
+			if(($find_data = strpos($file, "?k=profile&u=")) !== false)
 			{
-				$window = pts_read_assignment("GTK_OBJ_WINDOW");
+				$strip_url = substr($file, $find_data + 13);
 
-				foreach($window->get_children() as $child)
+				if(($cut = strpos($strip_url, '#')) !== false)
 				{
-					$window->remove($child);
+					$strip_url = substr($strip_url, 0, $cut);
 				}
 
-				$vertical = array(null);
-
-				for($i = 0; $i < count($svg_options); $i++)
+				if(pts_global::is_global_id($strip_url))
 				{
-					array_push($vertical, new pts_gtk_button($svg_options[$i][1], array("gui_gtk", "drag_drop_item_clicked"), $svg_options[$i][0]));
+					$options[0][0] = $strip_url;
+					$options[0][1] = "Run This Phoronix Global Comparison";
 				}
-				array_push($vertical, new pts_gtk_button("Return", array("gui_gtk", "drag_drop_item_clicked"), "return", -1, -1, Gtk::STOCK_QUIT));
-				array_push($vertical, null);
-
-				pts_gtk_array_to_boxes($window, $vertical, 16);
-				gui_gtk::redraw_main_window();
 			}
 		}
+
+		if(count($options) > 0)
+		{
+			$window = pts_read_assignment("GTK_OBJ_WINDOW");
+
+			foreach($window->get_children() as $child)
+			{
+				$window->remove($child);
+			}
+
+			$vertical = array(null);
+
+			for($i = 0; $i < count($options); $i++)
+			{
+				array_push($vertical, new pts_gtk_button($options[$i][1], array("gui_gtk", "drag_drop_item_clicked"), $options[$i][0]));
+			}
+			array_push($vertical, new pts_gtk_button("Return", array("gui_gtk", "drag_drop_item_clicked"), "return", -1, -1, Gtk::STOCK_QUIT));
+			array_push($vertical, null);
+
+			pts_gtk_array_to_boxes($window, $vertical, 16);
+			gui_gtk::redraw_main_window();
+		}
 	}
 	public static function drag_drop_item_clicked($clicked)
 	{
@@ -404,10 +421,10 @@ class gui_gtk implements pts_option_interface
 		{
 			case "return":
 				// TODO: refresh main window instead of having to redo it all
-				pts_run_option_next("gui_gtk");
+				pts_client::run_next("gui_gtk");
 				break;
 			default:
-				pts_run_option_next("install_test", $clicked, array("SILENCE_MESSAGES" => true));
+				pts_client::run_next("install_test", $clicked, array("AUTOMATED_MODE" => true));
 				gui_gtk::show_run_confirmation_interface($clicked);
 				break;
 		}
@@ -417,7 +434,7 @@ class gui_gtk implements pts_option_interface
 		$previous_select = (is_array($p = pts_read_assignment("GTK_SELECTED_ITEM_PREV")) ? $p : array());
 		$identifiers = pts_gtk_selected_items($object);
 		pts_set_assignment("GTK_MULTIPLE_SELECT_ITEMS", ($multiple_selected = count($identifiers) > 1));
-		pts_set_assignment("GTK_LAST_SELECTED_ITEM", ($identifier = pts_last_element_in_array(array_diff($identifiers, $previous_select))));
+		pts_set_assignment("GTK_LAST_SELECTED_ITEM", ($identifier = pts_arrays::last_element(array_diff($identifiers, $previous_select))));
 		pts_set_assignment("GTK_SELECTED_ITEMS", $identifiers);
 		pts_set_assignment_once("GTK_HAS_TOUCHED_SELECT_MENU", true);
 
@@ -459,7 +476,7 @@ class gui_gtk implements pts_option_interface
 			$info_r["Test"] = $result_file->get_suite_name();
 			$info_r["null2"] = null;
 
-			$reference_tests = pts_result_file_reference_tests($identifier);
+			$reference_tests = pts_result_comparisons::reference_tests_for_result($identifier);
 			if(count($reference_tests) > 0)
 			{
 				$objs = gui_gtk::pts_gtk_reference_system_comparison_objects($identifier, $reference_tests, $append_elements);
@@ -479,7 +496,6 @@ class gui_gtk implements pts_option_interface
 		}
 		else if(pts_read_assignment("GTK_TEST_OR_SUITE") == "TEST")
 		{
-			$identifier = pts_test_name_to_identifier($identifier);
 			$test_profile = new pts_test_profile($identifier);
 
 			$info_r["Maintainer"] = $test_profile->get_maintainer();
@@ -501,7 +517,6 @@ class gui_gtk implements pts_option_interface
 		}
 		else if(pts_read_assignment("GTK_TEST_OR_SUITE") == "SUITE")
 		{
-			$identifier = pts_suite_name_to_identifier($identifier);
 			$test_suite = new pts_test_suite($identifier);
 
 			$info_r["Maintainer"] = $test_suite->get_maintainer();
@@ -537,7 +552,7 @@ class gui_gtk implements pts_option_interface
 	public static function update_details_frame_for_install($to_install)
 	{
 		$gtk_obj_main_frame = pts_read_assignment("GTK_OBJ_MAIN_FRAME");
-		$gtk_obj_main_frame->set_label(array_pop(pts_to_array($to_install)));
+		$gtk_obj_main_frame->set_label(array_pop(pts_arrays::to_array($to_install)));
 
 		if(pts_is_assignment("GTK_OBJ_MAIN_FRAME_BOX"))
 		{
@@ -549,10 +564,10 @@ class gui_gtk implements pts_option_interface
 		$append_elements = array();
 
 		// PTS Test
-		$info_r["Estimated Download Size"] = pts_estimated_download_size($to_install) . " MB";
-		$info_r["null1"] = null;
-		$info_r["Estimated Install Size"] = pts_estimated_environment_size($to_install) . " MB";
-		$info_r["null2"] = null;
+		//$info_r["Estimated Download Size"] = pts_estimated_download_size($to_install) . " MB";
+		//$info_r["null1"] = null;
+		//$info_r["Estimated Install Size"] = pts_estimated_environment_size($to_install) . " MB";
+		//$info_r["null2"] = null;
 
 		$titles = array();
 		$values = array();
@@ -579,7 +594,7 @@ class gui_gtk implements pts_option_interface
 		{
 			if(count($merge_select_object->get_selected_identifiers()) != 0)
 			{
-				$ref_check_button = new GtkCheckButton(pts_last_element_in_array($merge_select_object->get_selected_identifiers()));
+				$ref_check_button = new GtkCheckButton(pts_arrays::last_element($merge_select_object->get_selected_identifiers()));
 				$ref_check_button->set_active(false);
 				$ref_check_button->connect("toggled", array("gui_gtk", "toggle_reference_systems"), $merge_select_object, $compare_results);
 
@@ -615,8 +630,8 @@ class gui_gtk implements pts_option_interface
 		}
 
 		$pass_args = array("AUTOMATED_MODE" => true, "REFERENCE_COMPARISONS" => $reference_comparisons, "PREV_SAVE_NAME_TITLE" => $comparison_title);
-		pts_run_option_next("reference_comparison", $identifier, $pass_args);
-		pts_run_option_next("gui_gtk");
+		pts_client::run_next("reference_comparison", $identifier, $pass_args);
+		pts_client::run_next("gui_gtk");
 
 		$window = pts_read_assignment("GTK_OBJ_WINDOW");
 
@@ -669,7 +684,7 @@ class gui_gtk implements pts_option_interface
 		if(pts_read_assignment("GTK_TEST_OR_SUITE") == "SUITE")
 		{
 			// Installed Suites
-			$i_s = pts_gui_installed_suites();
+			$i_s = pts_suites::installed_suites();
 
 			if(count($i_s) > 0)
 			{
@@ -701,7 +716,7 @@ class gui_gtk implements pts_option_interface
 			pts_gtk_add_notebook_tab($main_notebook, $available_tests, "Available Tests");
 		}
 
-		$r_i = pts_saved_test_results_identifiers();
+		$r_i = pts_client::saved_test_results();
 		$test_results = pts_gtk_table(array(count($r_i) . " Test Results"), $r_i, array("gui_gtk", "update_details_frame_from_select"), "No test results have been saved.");
 		pts_gtk_add_notebook_tab($main_notebook, $test_results, "Test Results");
 
@@ -774,14 +789,14 @@ class gui_gtk implements pts_option_interface
 				gui_gtk::show_main_interface();
 				break;
 			case "install":
-				pts_run_option_next("install_test", $identifiers, array("SILENCE_MESSAGES" => true));
-				pts_run_option_next("gui_gtk");
+				pts_client::run_next("install_test", $identifiers, array("AUTOMATED_MODE" => true));
+				pts_client::run_next("gui_gtk");
 				break;
 			case "BENCHMARK":
 			case "RUN":
 				if($button_call == "BENCHMARK")
 				{
-					pts_run_option_next("install_test", $identifiers, array("SILENCE_MESSAGES" => true));
+					pts_client::run_next("install_test", $identifiers, array("AUTOMATED_MODE" => true));
 				}
 
 				$args_to_pass = array("IS_BATCH_MODE" => pts_read_assignment("GTK_BATCH_MODE"), 
@@ -832,8 +847,8 @@ class gui_gtk implements pts_option_interface
 					$args_to_pass["AUTO_TEST_OPTION_SELECTIONS"] = $preset_test_options;
 				}
 
-				pts_run_option_next("run_test", $identifiers, $args_to_pass);
-				pts_run_option_next("gui_gtk");
+				pts_client::run_next("run_test", $identifiers, $args_to_pass);
+				pts_client::run_next("gui_gtk");
 				break;
 		}
 
@@ -894,7 +909,7 @@ class gui_gtk implements pts_option_interface
 	}
 	public static function show_run_confirmation_interface($identifiers, $task = "RUN")
 	{
-		$identifiers = pts_to_array($identifiers);
+		$identifiers = pts_arrays::to_array($identifiers);
 		if(empty($identifiers))
 		{
 			echo "DEBUG: Null identifier in gtk_gui::show_run_confirmation_interface()\n";
@@ -922,7 +937,8 @@ class gui_gtk implements pts_option_interface
 
 			foreach($identifiers as $identifier)
 			{
-				$test_options = pts_test_options($identifier);
+				$test_profile = new pts_test_profile($identifier);
+				$test_options = $test_profile->get_test_option_objects();
 
 				if(count($test_options) == 0)
 				{
@@ -952,12 +968,12 @@ class gui_gtk implements pts_option_interface
 						else
 						{
 							$combobox = GtkComboBox::new_text();
-							foreach($o->get_all_option_names() as $option_name)
+							foreach($o->get_all_option_names_with_messages() as $option_name)
 							{
 								$combobox->append_text($option_name);
 							}
 
-							if(count($o->get_all_option_names()) > 1)
+							if(count($o->get_all_option_names_with_messages()) > 1)
 							{
 								$combobox->append_text("Test All Options");
 							}
@@ -999,7 +1015,7 @@ class gui_gtk implements pts_option_interface
 		pts_set_assignment("GTK_OBJ_SAVE_NAME", $save_name);
 		array_push($menu_items, array(new GtkLabel("Save Name"), $save_name));
 
-		if(count($identifiers) == 1 && (pts_is_test_result($identifiers[0]) || pts_is_global_id($identifiers[0])))
+		if(count($identifiers) == 1 && (pts_is_test_result($identifiers[0]) || pts_global::is_global_id($identifiers[0])))
 		{
 			$save_name->set_text($identifiers[0]);
 			$save_name->set_sensitive(false);
@@ -1154,13 +1170,13 @@ class gui_gtk implements pts_option_interface
 				$proxy_port = trim($proxy_port->get_text());
 
 
-				if(pts_http_get_contents("http://www.phoronix-test-suite.com/PTS", $proxy_address, $proxy_port) == "PTS")
+				if(pts_network::http_get_contents("http://www.phoronix-test-suite.com/PTS", $proxy_address, $proxy_port) == "PTS")
 				{					
-					pts_user_config_init(array(P_OPTION_NET_PROXY_ADDRESS => $proxy_address, P_OPTION_NET_PROXY_PORT => $proxy_port));
-					pts_exit("Restarting pts-core...\n", 8);					
+					pts_config::user_config_generate(array(P_OPTION_NET_PROXY_ADDRESS => $proxy_address, P_OPTION_NET_PROXY_PORT => $proxy_port));
+					pts_client::exit_client("Restarting pts-core...", 8);					
 				}
 
-				$setup_success = pts_global_setup_account($username, $password);
+				$setup_success = pts_global::create_account($username, $password);
 				break;
 		}
 	}
@@ -1168,7 +1184,7 @@ class gui_gtk implements pts_option_interface
 	{
 		$id_entry = pts_read_assignment("GTK_OBJ_GLOBAL_ID");
 		$global_id = $id_entry->get_text();
-		$is_valid = $force || pts_global_valid_id_string($global_id);
+		$is_valid = $force || pts_global::is_valid_global_id_format($global_id);
 
 		pts_gtk_object_set_sensitive("GTK_OBJ_GLOBAL_RESULTS", $is_valid);
 		pts_gtk_object_set_sensitive("GTK_OBJ_GLOBAL_CLONE", $is_valid);
@@ -1180,7 +1196,7 @@ class gui_gtk implements pts_option_interface
 		$global_id = ($id_entry ? trim($id_entry->get_text()) : false);
 
 		/*
-		if(!pts_is_global_id($global_id))
+		if(!pts_global::is_global_id($global_id))
 		{
 			gui_gtk::phoronix_global_id_entry_changed(true);
 			return;
@@ -1193,12 +1209,12 @@ class gui_gtk implements pts_option_interface
 		switch($action)
 		{
 			case "view_results":
-				gui_gtk::launch_web_browser(pts_global_public_url($global_id));
-				pts_run_option_next("gui_gtk");
+				gui_gtk::launch_web_browser(pts_global::get_public_result_url($global_id));
+				pts_client::run_next("gui_gtk");
 				break;
 			case "clone_results":
-				pts_run_option_next("clone_global_result", $global_id, array("AUTOMATED_MODE" => true));
-				pts_run_option_next("gui_gtk");
+				pts_client::run_next("clone_global_result", $global_id, array("AUTOMATED_MODE" => true));
+				pts_client::run_next("gui_gtk");
 				//Gtk::main_quit();
 				break;
 			case "run_comparison":
@@ -1211,8 +1227,8 @@ class gui_gtk implements pts_option_interface
 				$username = trim($username->get_text());
 				$password = md5(trim($password->get_text()));
 
-				$setup_success = pts_global_setup_account($username, $password);
-				pts_run_option_next("gui_gtk", null, array("PREV_GLOBAL_ACCT_SETUP" => "Phoronix Global Setup " . ($setup_success ? "Was Successful" : "Failed") . "."));
+				$setup_success = pts_global::create_account($username, $password);
+				pts_client::run_next("gui_gtk", null, array("PREV_GLOBAL_ACCT_SETUP" => "Phoronix Global Setup " . ($setup_success ? "Was Successful" : "Failed") . "."));
 				break;
 		}
 	}
@@ -1241,7 +1257,7 @@ class gui_gtk implements pts_option_interface
 			$url = "http://www.phoronix-test-suite.com/";
 		}
 
-		pts_display_web_browser($url, null, true, true);
+		pts_client::display_web_page($url, null, true, true);
 	}
 	public static function details_button_clicked()
 	{
@@ -1251,10 +1267,10 @@ class gui_gtk implements pts_option_interface
 		{
 			if(!is_dir(SAVE_RESULTS_DIR . $identifier . "/result-graphs/"))
 			{
-				pts_generate_graphs($identifier, SAVE_RESULTS_DIR . $identifier . "/");
+				pts_render::generate_result_file_graphs($identifier, SAVE_RESULTS_DIR . $identifier . "/");
 			}
 
-			pts_display_web_browser(SAVE_RESULTS_DIR . $identifier . "/index.html", null, true, true);
+			pts_client::display_web_page(SAVE_RESULTS_DIR . $identifier . "/index.html", null, true, true);
 		}
 		else
 		{
@@ -1270,8 +1286,6 @@ class gui_gtk implements pts_option_interface
 
 			if(pts_read_assignment("GTK_TEST_OR_SUITE") == "SUITE")
 			{
-				$identifier = pts_suite_name_to_identifier($identifier);
-
 				$label_tests = new GtkLabel("Suite Contains: " . implode(", ", pts_contained_tests($identifier, false, false, true)));
 				$label_tests->set_size_request(420, -1);
 				$label_tests->set_line_wrap(true);
@@ -1279,7 +1293,6 @@ class gui_gtk implements pts_option_interface
 			}
 			else
 			{
-				$identifier = pts_test_name_to_identifier($identifier);
 				$obj = new pts_test_profile($identifier);
 
 				$str = "Software Dependencies: ";
@@ -1308,14 +1321,15 @@ class gui_gtk implements pts_option_interface
 
 				$str = "Suites Using This Test: ";
 				$i = 0;
-				foreach(pts_suites_containing_test($identifier) as $suite)
+				foreach($obj->suites_containing_test() as $suite)
 				{
 					if($i > 0)
 					{
 						$str .= ", ";
 					}
 
-					$str .= pts_suite_identifier_to_name($suite);
+					$test_suite = new pts_test_suite($suite);
+					$str .= $test_suite->get_title();
 					$i++;
 				}
 				if($i == 0)
@@ -1336,7 +1350,9 @@ class gui_gtk implements pts_option_interface
 	}
 	public static function notebook_selected_to_identifier()
 	{
-		$identifiers = pts_read_assignment("GTK_SELECTED_ITEMS");
+		return $identifiers = pts_read_assignment("GTK_SELECTED_ITEMS");
+
+/*
 		$selected = array();
 
 		foreach($identifiers as $identifier)
@@ -1356,7 +1372,7 @@ class gui_gtk implements pts_option_interface
 			array_push($selected, $identifier);
 		}
 
-		return $selected;
+		return $selected;*/
 	}
 	public static function update_run_button()
 	{
@@ -1477,7 +1493,7 @@ class gui_gtk implements pts_option_interface
 	{
 		$editable_preferences = array(
 		// User Settings
-		P_OPTION_USAGE_REPORTING, P_OPTION_DEFAULT_BROWSER, P_OPTION_PHODEVI_CACHE, P_OPTION_DISPLAY_MODE, P_OPTION_EXTRA_REFERENCE_SYSTEMS, 
+		P_OPTION_USAGE_REPORTING, P_OPTION_HARDWARE_REPORTING, P_OPTION_SOFTWARE_REPORTING, P_OPTION_DEFAULT_BROWSER, P_OPTION_PHODEVI_CACHE, P_OPTION_DISPLAY_MODE, P_OPTION_EXTRA_REFERENCE_SYSTEMS, 
 		P_OPTION_LOAD_MODULES,
 		P_OPTION_TEST_REMOVEDOWNLOADS, P_OPTION_CACHE_SEARCHMEDIA, P_OPTION_CACHE_SYMLINK,
 		P_OPTION_PROMPT_DOWNLOADLOC, P_OPTION_TEST_ENVIRONMENT, P_OPTION_CACHE_DIRECTORY,
@@ -1515,7 +1531,9 @@ class gui_gtk implements pts_option_interface
 
 		foreach($editable_preferences as $preference)
 		{
-			if(($h = pts_extract_identifier_from_path($preference)) != $previous_heading)
+			$heading = substr(($d = dirname($preference)), strrpos($d, '/') + 1);
+
+			if($heading != $previous_heading)
 			{
 				if($pages > 0)
 				{
@@ -1524,19 +1542,27 @@ class gui_gtk implements pts_option_interface
 					$notebook->append_page($vbox_page_{$pages}, new GtkLabel($page_prefix . gui_gtk::caps_to_spaces($previous_heading)));
 				}
 
-				if($previous_heading == "BatchMode")
+				if($previous_heading == "Networking")
 				{
 					$config_type = "graph";
 					$page_prefix = "Graph ";
 				}
 
-				$previous_heading = $h;
+				$previous_heading = $heading;
 				$pages++;
 				$page_items = array();
 			}
 
 			$pref = basename($preference);
-			$current_value = pts_read_user_config($preference, null, ($config_type == "graph" ? $graph_config : $read_config));
+
+			if($config_type == "graph")
+			{
+				$current_value = pts_config::read_graph_config($preference, null);
+			}
+			else
+			{
+				$current_value = pts_config::read_user_config($preference, null);
+			}
 
 			if($current_value == "TRUE" || $current_value == "FALSE")
 			{
@@ -1544,7 +1570,7 @@ class gui_gtk implements pts_option_interface
 				$hb[$i]->pack_start(($radio_true[$i] = new GtkRadioButton(null, "TRUE", true)));
 				$hb[$i]->pack_start(($radio_false[$i] = new GtkRadioButton($radio_true[$i], "FALSE", false)));
 
-				if(pts_string_bool($current_value))
+				if(pts_strings::string_bool($current_value))
 				{
 					$radio_true[$i]->set_active(true);
 				}
@@ -1674,15 +1700,15 @@ class gui_gtk implements pts_option_interface
 				}
 				else if($object instanceOf GtkComboBox)
 				{
-					$preferences_set[$preference] = pts_config_bool_to_string($object->get_active() == 0);
+					$preferences_set[$preference] = pts_config::bool_to_string($object->get_active() == 0);
 				}
 				else if($object instanceOf GtkButton)
 				{
 					$preferences_set[$preference] = $object->get_label();
 				}
 			}
-			pts_user_config_init($preferences_set);
-			pts_graph_config_init($preferences_set);
+			pts_config::user_config_generate($preferences_set);
+			pts_config::graph_config_generate($preferences_set);
 		}
 
 		$window = pts_read_assignment("GTK_OBJ_PREFERENCES_WINDOW");
@@ -1707,8 +1733,8 @@ class gui_gtk implements pts_option_interface
 		$main_window->destroy();
 
 		$identifier = pts_read_assignment("GTK_LAST_SELECTED_ITEM");
-		pts_run_option_next("upload_result", $identifier, array("AUTOMATED_MODE" => true));
-		pts_run_option_next("gui_gtk");
+		pts_client::run_next("upload_result", $identifier, array("AUTOMATED_MODE" => true));
+		pts_client::run_next("gui_gtk");
 	}
 	public static function show_generate_pdf_interface()
 	{
@@ -1735,8 +1761,8 @@ class gui_gtk implements pts_option_interface
 			$main_window->destroy();
 
 			$identifier = pts_read_assignment("GTK_LAST_SELECTED_ITEM");
-			pts_run_option_next("result_file_to_" . strtolower($type), $identifier, array("SAVE_TO" => $save_file));
-			pts_run_option_next("gui_gtk");
+			pts_client::run_next("result_file_to_" . strtolower($type), $identifier, array("SAVE_TO" => $save_file));
+			pts_client::run_next("gui_gtk");
 		}
 		$dialog->destroy();
 	}
@@ -1763,11 +1789,11 @@ class gui_gtk implements pts_option_interface
 		switch($operation)
 		{
 			default:
-				pts_run_option_next($operation, $identifier, array("AUTOMATED_MODE" => true));
+				pts_client::run_next($operation, $identifier, array("AUTOMATED_MODE" => true));
 				break;
 		}
 
-		pts_run_option_next("gui_gtk");
+		pts_client::run_next("gui_gtk");
 	}
 	public static function show_dependency_info_interface()
 	{
@@ -1777,12 +1803,12 @@ class gui_gtk implements pts_option_interface
 		$notebook = new GtkNotebook();
 		$notebook->set_size_request(540, 250);
 
-		$installed_dependencies = array_map("pts_external_dependency_generic_title", pts_external_dependencies_installed());
+		$installed_dependencies = pts_external_dependencies::installed_dependency_titles();
 		sort($installed_dependencies);
 		$installed = pts_gtk_table(array(""), $installed_dependencies, null, "No software dependencies are installed.", false);
 		pts_gtk_add_notebook_tab($notebook, $installed, "Installed Dependencies");
 
-		$missing_dependencies = array_map("pts_external_dependency_generic_title", pts_external_dependencies_missing());
+		$missing_dependencies = pts_external_dependencies::missing_dependency_titles();
 		sort($missing_dependencies);
 		$missing = pts_gtk_table(array(""), $missing_dependencies, null, "No software dependencies are missing.", false);
 		pts_gtk_add_notebook_tab($notebook, $missing, "Missing Dependencies");
@@ -1798,16 +1824,16 @@ class gui_gtk implements pts_option_interface
 		$window->set_size_request(540, 250);
 
 		$rows = array();
-		foreach(pts_available_modules() as $module)
+		foreach(pts_module_manager::available_modules() as $module)
 		{
-			pts_load_module($module);
+			pts_module_manager::load_module($module);
 
 			$enable_module[$module] = new GtkCheckButton();
 			$enable_module[$module]->set_active(true);
 			//$enable_module[$module]->set_sensitive(false); // Enabling / disabling modules from the GUI is currently not supported
 
 			// $enable_module[$module] should be passed for enabling toggling of the module, but not yet implemented
-			array_push($rows, array(null, pts_module_call($module, "module_name")));
+			array_push($rows, array(null, pts_module_manager::module_call($module, "module_name")));
 		}
 
 		$modules_table = pts_gtk_table(array(null, "Modules"), $rows, null, "No modules available.", false);
@@ -1826,18 +1852,16 @@ class gui_gtk implements pts_option_interface
 		$notebook->set_size_request(540, 250);
 
 		pts_set_assignment("GTK_SYSTEM_INFO_NOTEBOOK", "Hardware");
-		$hw = pts_gtk_table(array("", ""), pts_array_with_key_to_2d(pts_hw_string(false)), null, "No system information available.", false);
+		$hw = pts_gtk_table(array("", ""), pts_array_with_key_to_2d(phodevi::system_hardware(false)), null, "No system information available.", false);
 		pts_gtk_add_notebook_tab($notebook, $hw, "Hardware");
 
-		$sw = pts_gtk_table(array("", ""), pts_array_with_key_to_2d(pts_sw_string(false)), null, "No system information available.", false);
+		$sw = pts_gtk_table(array("", ""), pts_array_with_key_to_2d(phodevi::system_software(false)), null, "No system information available.", false);
 		pts_gtk_add_notebook_tab($notebook, $sw, "Software");
 
-		$sensors = pts_gtk_table(array("", ""), pts_array_with_key_to_2d(pts_sys_sensors_string(false)), null, "No system information available.", false);
-		pts_gtk_add_notebook_tab($notebook, $sensors, "Sensors");
+		//$sensors = pts_gtk_table(array("", ""), pts_array_with_key_to_2d(pts_sys_sensors_string(false)), null, "No system information available.", false);
+		//pts_gtk_add_notebook_tab($notebook, $sensors, "Sensors");
 
-		$copy_button = new pts_gtk_button("Copy To Clipboard", array("gui_gtk", "system_info_copy_to_clipboard"), null);
-
-		pts_gtk_array_to_boxes($window, array($notebook, $copy_button), 3);
+		pts_gtk_array_to_boxes($window, array($notebook), 3);
 
 		$window->show_all();
 		Gtk::main();
@@ -1854,13 +1878,10 @@ class gui_gtk implements pts_option_interface
 		switch(pts_read_assignment("GTK_SYSTEM_INFO_NOTEBOOK"))
 		{
 			case "Hardware":
-				$to_copy = pts_hw_string();
+				$to_copy = phodevi::system_hardware(true);
 				break;
 			case "Software":
-				$to_copy = pts_sw_string();
-				break;
-			case "Sensors":
-				$to_copy = pts_sys_sensors_string();
+				$to_copy = phodevi::system_software(true);
 				break;
 		}
 
@@ -1879,20 +1900,23 @@ class gui_gtk implements pts_option_interface
 		$window = new pts_gtk_window("Phoronix Test Suite - User Agreement");
 		$window->set_position(Gtk::WIN_POS_CENTER_ALWAYS);
 
-		$textview_agreement = new pts_gtk_text_area(trim($user_agreement), 540, 250);
+		$textview_agreement = new pts_gtk_text_area(trim($user_agreement), 540, 280);
 		$return_button = new pts_gtk_button("Quit", array("gui_gtk", "process_user_agreement_prompt"), "quit", -1, -1, Gtk::STOCK_CANCEL);
 		$continue_button = new pts_gtk_button("Accept Terms", array("gui_gtk", "process_user_agreement_prompt"), "yes", -1, -1, Gtk::STOCK_APPLY);
 
 		$usage_reporting_button = new GtkCheckButton("Enable anonymous usage / statistics reporting.");
 		$usage_reporting_button->set_active(true);
 
-		pts_gtk_array_to_boxes($window, array($textview_agreement, new GtkLabel("Do you agree to the user terms listed above?"), $usage_reporting_button, array($return_button, $continue_button)), 1);
+		$hwsw_reporting_button = new GtkCheckButton("Enable anonymous hardware / software reporting.");
+		$hwsw_reporting_button->set_active(true);
+
+		pts_gtk_array_to_boxes($window, array($textview_agreement, new GtkLabel("Do you agree to the user terms listed above?"), $usage_reporting_button, $hwsw_reporting_button, array($return_button, $continue_button)), 1);
 
 		pts_set_assignment("GTK_USER_AGREEMENT_WINDOW", $window);
 		$window->show_all();
 		Gtk::main();
 
-		return array(pts_read_assignment("AGREED_TO_TERMS"), $usage_reporting_button->get_active());
+		return array(pts_read_assignment("AGREED_TO_TERMS"), $usage_reporting_button->get_active(), $hwsw_reporting_button->get_active());
 	}
 	public static function redraw_main_window()
 	{
