@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2008 - 2009, Phoronix Media
-	Copyright (C) 2008 - 2009, Michael Larabel
+	Copyright (C) 2008 - 2010, Phoronix Media
+	Copyright (C) 2008 - 2010, Michael Larabel
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -29,15 +29,13 @@ class install_dependencies implements pts_option_interface
 	public static function argument_checks()
 	{
 		return array(
-		new pts_argument_check(0, "!pts_empty", null, "The name of a test, suite, or result file must be entered.")
+		new pts_argument_check(0, "!empty", null, "The name of a test, suite, or result file must be entered.")
 		);
 	}
 	public static function run($r)
 	{
 		$r = array_map("strtolower", $r);
-		$display_mode = pts_get_display_mode_object();
-		$passed_tests = array();
-		pts_install_package_on_distribution($display_mode, $r, $passed_tests);
+		pts_external_dependencies::install_dependencies($r);
 	}
 }
 
