@@ -24,19 +24,17 @@ class list_installed_tests implements pts_option_interface
 {
 	public static function run($r)
 	{
-		echo pts_string_header("Phoronix Test Suite - Installed Tests");
-		$installed_tests = pts_installed_tests_array();
+		$installed_tests = pts_tests::installed_tests();
+		pts_client::$display->generic_heading(count($installed_tests) . " Tests Installed");
 
-		if(count($installed_tests) == 0)
+		if(count($installed_tests) > 0)
 		{
-			echo "\nNo tests are currently installed.\n\n";
-		}
-		else
-		{
-			foreach(pts_installed_tests_array() as $identifier)
+			foreach($installed_tests as $identifier)
 			{
-				$xml_parser = new pts_test_tandem_XmlReader($identifier);
-			 	echo (($name = $xml_parser->getXMLValue(P_TEST_TITLE)) != false ? sprintf("%-18ls - %-30ls\n", $identifier, $name) : null);
+				$test_profile = new pts_test_profile($identifier);
+				$name = $test_profile->get_title();
+
+			 	echo $name != false ? sprintf("%-18ls - %-30ls\n", $identifier, $name) : null;
 			}
 			echo "\n";
 		}
