@@ -22,18 +22,11 @@
 
 class list_possible_dependencies implements pts_option_interface
 {
-	public static function required_function_sets()
-	{
-		return array("install_dependencies");
-	}
 	public static function run($r)
 	{
-		echo pts_string_header("Phoronix Test Suite - Possible External Dependencies");
-
-		$dependencies = array_map("pts_external_dependency_generic_title", pts_external_dependency_generic_packages());
-		sort($dependencies);
-
-		echo pts_text_list($dependencies);
+		$all_dependencies = pts_external_dependencies::all_dependency_titles();
+		pts_client::$display->generic_heading(count($all_dependencies) . " External Dependencies Available");
+		echo pts_user_io::display_text_list($all_dependencies);
 		echo "\n";
 	}
 }
