@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2008 - 2009, Phoronix Media
-	Copyright (C) 2008 - 2009, Michael Larabel
+	Copyright (C) 2008 - 2010, Phoronix Media
+	Copyright (C) 2008 - 2010, Michael Larabel
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -25,7 +25,7 @@ class module_setup implements pts_option_interface
 	public static function argument_checks()
 	{
 		return array(
-		new pts_argument_check(0, "pts_is_module", null, "No module found.")
+		new pts_argument_check(0, array("pts_module", "is_module"), null, "No module found.")
 		);
 	}
 	public static function run($r)
@@ -36,14 +36,14 @@ class module_setup implements pts_option_interface
 
 		if(!class_exists($module))
 		{
-			pts_load_module($module);
+			pts_module_manager::load_module($module);
 		}
 
-		$module_name = pts_module_call($module, "module_name");
-		$module_description = pts_module_call($module, "module_description");
-		$module_setup = pts_module_call($module, "module_setup");
+		$module_name = pts_module_manager::module_call($module, "module_name");
+		$module_description = pts_module_manager::module_call($module, "module_description");
+		$module_setup = pts_module_manager::module_call($module, "module_setup");
 
-		echo pts_string_header("Module: " . $module_name);
+		pts_client::$display->generic_heading($module_name . " Module Configuration");
 		echo $module_description . "\n";
 
 		if(count($module_setup) == 0)
@@ -52,36 +52,45 @@ class module_setup implements pts_option_interface
 		}
 		else
 		{
+			if(($module_presets = pts_client::read_env("PTS_MODULE_SETUP")) != false)
+			{
+				$module_presets = pts_client::parse_value_string_double_identifier($module_presets);
+			}
+
 			$set_options = array();
 			foreach($module_setup as $module_option)
 			{
 				if($module_option instanceOf pts_module_option)
 				{
-					do
+					$option_identifier = $module_option->get_identifier();
+
+					if(isset($module_presets[$module][$option_identifier]) && $module_option->is_supported_value($module_presets[$module][$option_identifier]))
 					{
 						echo "\n" . $module_option->get_formatted_question();
-						$input = pts_read_user_input();
+						echo $module_presets[$module][$option_identifier] . "\n";
+						$input = $module_presets[$module][$option_identifier];
+					}
+					else
+					{
+						do
+						{
+							echo "\n" . $module_option->get_formatted_question();
+							$input = pts_user_io::read_user_input();
+						}
+						while(!$module_option->is_supported_value($input));
 					}
-					while(!$module_option->is_supported_value($input));
 
 					if(empty($input))
 					{
 						$input = $module_option->get_default_value();
 					}
 
-					$this_input_identifier = $module_option->get_identifier();
-					$set_options[$this_input_identifier] = $input;
+					$set_options[$option_identifier] = $input;
 				}
 			}
 
-			$set_options = pts_module_call($module, "module_setup_validate", $set_options);
-
-			$formatted_options = array();
-			foreach($set_options as $option => $value)
-			{
-				$formatted_options[$module . "__" . $option] = $value;
-			}
-			pts_module_config_init($formatted_options);
+			$set_options = pts_module_manager::module_call($module, "module_setup_validate", $set_options);
+			pts_module::module_config_save($module, $set_options);
 		}
 		echo "\n";
 	}
