@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2009, Phoronix Media
-	Copyright (C) 2009, Michael Larabel
+	Copyright (C) 2009 - 2010, Phoronix Media
+	Copyright (C) 2009 - 2010, Michael Larabel
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -22,10 +22,6 @@
 
 class reference_comparison implements pts_option_interface
 {
-	public static function required_function_sets()
-	{
-		return array("merge", "comparisons");
-	}
 	public static function argument_checks()
 	{
 		return array(
@@ -36,7 +32,7 @@ class reference_comparison implements pts_option_interface
 	{
 		$result = $r["result"];
 
-		$reference_test_globals = pts_result_file_reference_tests($result);
+		$reference_test_globals = pts_result_comparisons::reference_tests_for_result($result);
 
 		if(count($reference_test_globals) == 0)
 		{
@@ -67,16 +63,15 @@ class reference_comparison implements pts_option_interface
 
 			}
 
-			echo pts_string_header("Reference Comparison");
-			$merge_index = pts_text_select_menu("Select a reference system", $comparable, false, true);
+			$merge_index = pts_user_io::prompt_text_menu("Select a reference system", $comparable, false, true);
 
 			array_push($merge_args, $reference_test_globals[$merge_index]);
 		}
 
 		pts_set_assignment("REFERENCE_COMPARISON", true);
-		$merged_results = call_user_func_array("pts_merge_test_results", $merge_args);
+		$merged_results = call_user_func_array(array("pts_merge", "pts_merge_test_results_array"), $merge_args);
 
-		pts_save_result($r[0] . "/composite.xml", $merged_results);
+		pts_client::save_test_result($r[0] . "/composite.xml", $merged_results);
 		pts_set_assignment_next("PREV_SAVE_RESULTS_IDENTIFIER", $r[0]);
 
 		if(($title = pts_read_assignment("PREV_SAVE_NAME_TITLE")) == false)
@@ -87,7 +82,7 @@ class reference_comparison implements pts_option_interface
 
 		pts_set_assignment_next("PREV_SAVE_NAME_TITLE", $title . (strpos($title, "Comparison") === false ? " Comparison" : null));
 
-		pts_display_web_browser(SAVE_RESULTS_DIR . $r[0] . "/composite.xml");
+		pts_client::display_web_page(SAVE_RESULTS_DIR . $r[0] . "/composite.xml");
 	}
 }
 
