@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2008 - 2009, Phoronix Media
-	Copyright (C) 2008 - 2009, Michael Larabel
+	Copyright (C) 2008 - 2010, Phoronix Media
+	Copyright (C) 2008 - 2010, Michael Larabel
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -22,14 +22,8 @@
 
 class result_file_to_suite implements pts_option_interface
 {
-	public static function required_function_sets()
-	{
-		return array("run");
-	}
 	public static function run($r)
 	{
-		echo pts_string_header("Test Suite Creation Utility");
-
 		$result_file = false;
 		if(count($r) != 0)
 		{
@@ -38,13 +32,13 @@ class result_file_to_suite implements pts_option_interface
 
 		while(($result_file = pts_find_result_file($result_file)) == false)
 		{
-			$result_file = pts_text_input("Enter name of result file");
+			$result_file = pts_user_io::prompt_user_input("Enter name of result file");
 		}
 
-		$suite_name = pts_text_input("Enter name of suite");
-		$suite_test_type = pts_text_select_menu("Select test type", pts_subsystem_test_types());
-		$suite_maintainer = pts_text_input("Enter suite maintainer name");
-		$suite_description = pts_text_input("Enter suite description");
+		$suite_name = pts_user_io::prompt_user_input("Enter name of suite");
+		$suite_test_type = pts_user_io::prompt_text_menu("Select test type", pts_types::subsystem_targets());
+		$suite_maintainer = pts_user_io::prompt_user_input("Enter suite maintainer name");
+		$suite_description = pts_user_io::prompt_user_input("Enter suite description");
 
 		$xml_writer = new tandem_XmlWriter();
 		$xml_writer->addXmlObject(P_SUITE_TITLE, 0, $suite_name);
@@ -73,7 +67,7 @@ class result_file_to_suite implements pts_option_interface
 		}
 
 		// Finish it off
-		$suite_identifier = pts_input_string_to_identifier(str_replace(" ", "-", strtolower($suite_name)));
+		$suite_identifier = pts_test_run_manager::clean_save_name_string(str_replace(" ", "-", strtolower($suite_name)));
 
 		if(is_file(XML_SUITE_LOCAL_DIR . $suite_identifier . ".xml"))
 		{
