@@ -34,10 +34,10 @@ class show_result implements pts_option_interface
 
 		if(!is_dir(SAVE_RESULTS_DIR . $r[0] . "/result-graphs/"))
 		{
-			pts_generate_graphs($r[0], SAVE_RESULTS_DIR . $r[0] . "/");
+			pts_render::generate_result_file_graphs($r[0], SAVE_RESULTS_DIR . $r[0] . "/");
 		}
 
-		pts_display_web_browser($URL, null, false, true);
+		pts_client::display_web_page($URL, null, false, true);
 	}
 }
 
