@@ -24,9 +24,9 @@ class system_info implements pts_option_interface
 {
 	public static function run($r)
 	{
-		echo pts_string_header(pts_title(true) . "\nSystem Information");
-		echo "Hardware:\n" . pts_hw_string() . "\n\n";
-		echo "Software:\n" . pts_sw_string() . "\n\n";
+		pts_client::$display->generic_heading("System Information");
+		echo "Hardware:\n" . phodevi::system_hardware(true) . "\n\n";
+		echo "Software:\n" . phodevi::system_software(true) . "\n\n";
 	}
 }
 
