@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2008 - 2009, Phoronix Media
-	Copyright (C) 2008 - 2009, Michael Larabel
+	Copyright (C) 2008 - 2010, Phoronix Media
+	Copyright (C) 2008 - 2010, Michael Larabel
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -22,10 +22,6 @@
 
 class upload_result implements pts_option_interface
 {
-	public static function required_function_sets()
-	{
-		return array("run");
-	}
 	public static function argument_checks()
 	{
 		return array(
@@ -36,24 +32,24 @@ class upload_result implements pts_option_interface
 	{
 		$use_file = $r["result_file"];
 
-		if(!pts_global_allow_upload($use_file))
+		if(pts_global::result_upload_supported($use_file) == false)
 		{
 			return false;
 		}
 
 		if(!pts_is_assignment("AUTOMATED_MODE"))
 		{
-			$tags_input = pts_prompt_user_tags();
+			$tags_input = pts_global::prompt_user_result_tags();
 			echo "\n";
 		}
 
-		$upload_url = pts_global_upload_result($use_file, $tags_input);
+		$upload_url = pts_global::upload_test_result($use_file, $tags_input);
 
 		if(!empty($upload_url))
 		{
 			echo "\nResults Uploaded To: " . $upload_url . "\n\n";
 			pts_set_assignment_next("PREV_GLOBAL_UPLOAD_URL", $upload_url);
-			pts_module_process("__event_global_upload", $upload_url);
+			pts_module_manager::module_process("__event_global_upload", $upload_url);
 		}
 		else
 		{
