@@ -22,7 +22,7 @@
 */
 
 setlocale(LC_NUMERIC, "C");
-define("PTS_PATH", dirname(dirname(__FILE__)) . "/");
+define("PTS_PATH", dirname(dirname(__FILE__)) . '/');
 
 // PTS_MODE types
 // CLIENT = Standard Phoronix Test Suite Client
@@ -37,7 +37,7 @@ if(PTS_MODE == "CLIENT" && ($open_basedir = ini_get("open_basedir")))
 {
 	$is_in_allowed_dir = false;
 
-	foreach(explode((IS_WINDOWS ? ';' : ':'), $open_basedir) as $allowed_dir)
+	foreach(explode(':', $open_basedir) as $allowed_dir)
 	{
 		if(strpos(PTS_PATH, $allowed_dir) === 0)
 		{
@@ -46,7 +46,7 @@ if(PTS_MODE == "CLIENT" && ($open_basedir = ini_get("open_basedir")))
 		}
 	}
 
-	if(!$is_in_allowed_dir)
+	if($is_in_allowed_dir == false)
 	{
 		echo "\nERROR: Your php.ini configuration's open_basedir setting is preventing " . PTS_PATH . " from loading.\n\n";
 		return false;
@@ -70,23 +70,24 @@ $sent_command = strtolower(str_replace("-", "_", (isset($argv[1]) ? $argv[1] : n
 $quick_start_options = array("dump_possible_options", "task_cache_reference_comparison_xml");
 define("QUICK_START", in_array($sent_command, $quick_start_options));
 
-pts_client_init(); // Initalize the Phoronix Test Suite (pts-core) client
+pts_client::init(); // Initalize the Phoronix Test Suite (pts-core) client
+//stream_wrapper_register("phoronix", "pts_phoronix_stream") or die("Failed To Initialize The Phoronix Stream");
 
 if(!is_file(PTS_PATH . "pts-core/options/" . $sent_command . ".php"))
 {
 	$replaced = false;
 
-	if(pts_module_valid_user_command($sent_command))
+	if(pts_module::valid_run_command($sent_command))
 	{
 		$replaced = true;
 	}
 	else
 	{
-		$alias_file = pts_file_get_contents(STATIC_DIR . "lists/option-command-aliases.list");
+		$alias_file = pts_file_io::file_get_contents(STATIC_DIR . "lists/option-command-aliases.list");
 
-		foreach(pts_trim_explode("\n", $alias_file) as $alias_line)
+		foreach(pts_strings::trim_explode("\n", $alias_file) as $alias_line)
 		{
-			list($link_cmd, $real_cmd) = pts_trim_explode('=', $alias_line);
+			list($link_cmd, $real_cmd) = pts_strings::trim_explode('=', $alias_line);
 
 			if($link_cmd == $sent_command)
 			{
@@ -106,52 +107,61 @@ if(!is_file(PTS_PATH . "pts-core/options/" . $sent_command . ".php"))
 }
 
 define("PTS_USER_LOCK", PTS_USER_DIR . "run_lock");
-$pts_fp = null;
-$release_lock = true;
 
 if(!QUICK_START)
 {
-	if(!pts_create_lock(PTS_USER_LOCK, $pts_fp))
+	if(pts_client::create_lock(PTS_USER_LOCK) == false)
 	{
-		echo pts_string_header("WARNING: It appears that the Phoronix Test Suite is already running.\nFor proper results, only run one instance at a time.");
-		$release_lock = false;
+		pts_client::$display->generic_warning("It appears that the Phoronix Test Suite is already running.\nFor proper results, only run one instance at a time.");
 	}
 
-	register_shutdown_function("pts_shutdown");
+	register_shutdown_function(array("pts_client", "process_shutdown_tasks"));
 
-	if(($proxy_address = pts_read_user_config(P_OPTION_NET_PROXY_ADDRESS, false)) && ($proxy_port = pts_read_user_config(P_OPTION_NET_PROXY_PORT, false)))
+	if(($proxy_address = pts_config::read_user_config(P_OPTION_NET_PROXY_ADDRESS, false)) && ($proxy_port = pts_config::read_user_config(P_OPTION_NET_PROXY_PORT, false)))
 	{
 		define("NETWORK_PROXY", $proxy_address . ":" . $proxy_port);
 		define("NETWORK_PROXY_ADDRESS", $proxy_address);
 		define("NETWORK_PROXY_PORT", $proxy_port);
 	}
-	else if(($env_proxy = getenv("http_proxy")) != false && count($env_proxy = explode(':', $env_proxy)) == 2)
+	else if(($env_proxy = getenv("http_proxy")) != false && count($env_proxy = pts_strings::colon_explode($env_proxy)) == 2)
 	{
 		define("NETWORK_PROXY", $env_proxy[0] . ":" . $env_proxy[1]);
 		define("NETWORK_PROXY_ADDRESS", $env_proxy[0]);
 		define("NETWORK_PROXY_PORT", $env_proxy[1]);
 	}
 
-	define("NETWORK_TIMEOUT", pts_read_user_config(P_OPTION_NET_TIMEOUT, 20));
-
-	if(ini_get("file_uploads") == "Off")
-	{
-		echo "\nThe file_uploads option in your PHP configuration must be enabled for network support.\n\n";
-	}
+	define("NETWORK_TIMEOUT", pts_config::read_user_config(P_OPTION_NET_TIMEOUT, 20));
 
 	if(ini_get("allow_url_fopen") == "Off")
 	{
 		echo "\nThe allow_url_fopen option in your PHP configuration must be enabled for network support.\n\n";
 		define("NO_NETWORK_COMMUNICATION", true);
 	}
-	else if(pts_string_bool(pts_read_user_config(P_OPTION_NET_NO_NETWORK, "FALSE")) || pts_http_get_contents("http://www.phoronix-test-suite.com/PTS", false, false) != "PTS")
+	else if(pts_config::read_bool_config(P_OPTION_NET_NO_NETWORK, "FALSE"))
 	{
-		// TODO: possibly be smarter than to bang PTS server on each run, perhaps each day and use PTS_CORE_STORAGE for remembering
 		define("NO_NETWORK_COMMUNICATION", true);
-		echo "\nNetwork Communication Is Disabled.\n\n";
+		echo "\nNetwork Communication Is Disabled For Your User Configuration.\n\n";
+	}
+	/* else
+	{
+		$server_response = pts_network::http_get_contents("http://www.phoronix-test-suite.com/PTS", false, false);
+
+		if($server_response != "PTS")
+		{
+			define("NO_NETWORK_COMMUNICATION", true);
+			echo "\nNetwork Communication Failed.\n\n";
+		}
+	}*/
+
+	if(!defined("NO_NETWORK_COMMUNICATION") && ini_get("file_uploads") == "Off")
+	{
+		echo "\nThe file_uploads option in your PHP configuration must be enabled for network support.\n\n";
 	}
 
-	pts_module_startup_init(); // Initialize the PTS module system
+	if(pts_client::read_env("PTS_IGNORE_MODULES") == false)
+	{
+		pts_client::module_framework_init(); // Initialize the PTS module system
+	}
 }
 
 // Read passed arguments
@@ -163,19 +173,20 @@ for($i = 2; $i < $argc && isset($argv[$i]); $i++)
 
 if(!QUICK_START)
 {
-	pts_user_agreement_check($sent_command);
+	pts_client::user_agreement_check($sent_command);
+	pts_client::user_hardware_software_reporting();
 }
 
-pts_run_option_next($sent_command, $pass_args);
+pts_client::run_next($sent_command, $pass_args);
 
-while(($current_option = pts_command_run_manager::pull_next_run_command()) != null)
+while(($current_option = pts_client::next_in_run_queue()) != null)
 {
-	pts_run_command($current_option->get_command(), $current_option->get_arguments(), $current_option->get_preset_assignments()); // Run command
+	pts_client::execute_command($current_option->get_command(), $current_option->get_command_arguments(), $current_option->get_preset_assignments()); // Run command
 }
 
-if(!QUICK_START && $release_lock)
+if(!QUICK_START)
 {
-	pts_release_lock($pts_fp, PTS_USER_LOCK);
+	pts_client::release_lock(PTS_USER_LOCK);
 }
 
 ?>
