@@ -13,8 +13,6 @@ rm -rf lzma-4.32.6
 
 cat > compress-lzma <<EOT
 #!/bin/sh
-\$TIMER_START
 ./lzma_/bin/lzma -q -c ./compressfile > /dev/null 2>&1
-\$TIMER_STOP
 EOT
 chmod +x compress-lzma
