@@ -12,8 +12,6 @@ cd ..
 rm -rf lame-398-2/
 
 echo "#!/bin/sh
-\$TIMER_START
 ./lame_/bin/lame -h \$TEST_EXTENDS/pts-trondheim.wav /dev/null 2>&1
-echo \$? > ~/test-exit-status
-\$TIMER_STOP" > lame
+echo \$? > ~/test-exit-status" > lame
 chmod +x lame
