@@ -1,7 +1,7 @@
 #!/bin/sh
 
-tar -xvf iozone3_323.tar
-cd iozone3_323/src/current/
+tar -xf iozone3_347.tar
+cd iozone3_347/src/current/
 
 case $OS_ARCH in
 	"x86_64" )
@@ -14,6 +14,6 @@ esac
 echo $? > ~/install-exit-status
 
 echo "#!/bin/sh
-iozone3_323/src/current/iozone \$@ > \$LOG_FILE 2>&1
+iozone3_347/src/current/iozone \$@ > \$LOG_FILE 2>&1
 echo \$? > ~/test-exit-status" > ~/iozone
 chmod +x ~/iozone
