@@ -3,8 +3,6 @@
 g++ sample-pi-program.cpp -o sample-pi-program
 
 echo "#!/bin/sh
-\$TIMER_START
-./sample-pi-program 2>&1
-\$TIMER_STOP" > sample-program
+./sample-pi-program 2>&1" > sample-program
 chmod +x sample-program
 
